;;; turkish.el --- Convert to Turkish characters on-the-fly

;; Copyright (C) 2006, 2010 Deniz Yüret
;; Author: Deniz Yüret
;; Maintainer: Emre Sevinç <emre.sevinc@gmail.com>
;; Keywords: turkish, languages, automatic, conversion
;; URL: http://www.denizyuret.com/2006/11/emacs-turkish-mode.html

;; This file is not part of GNU Emacs.

;; This file is free software (MIT License)

;;; Commentary:

;; This is for people trying to type Turkish documents on a U.S.
;; keyboard.
;;
;;; Installation:
;;
;; If you have `melpa' and `emacs24' installed, simply type:
;;
;; 	M-x package-install turkish
;;
;; Add following lines to your init file:
;;
;;     (require 'turkish)
;; Then turn on the turkish mode:
;;       M-x turkish-mode


;; Emacs Turkish Extension (c) Deniz Yuret, 2006, 2010

;; In turkish-mode your words should be automatically corrected
;; whenever you hit space.  Alternatively you can select a region and
;; use M-x turkish-correct-region.  If the program makes a mistake
;; you can toggle a character's accent using C-t.

;; The program was inspired by Gokhan Tur's deasciifier:
;;       http://www.hlst.sabanciuniv.edu/TL/deascii.html

;; The program uses decision lists (included at the end of this file)
;; which was created based on sample Turkish news text using the GPA
;; algorithm.  For more information on GPA:
;;       http://www.denizyuret.com/pub/iscis06

;; Current test set accuracy is approximately 1 error every 214
;; corrections, or every 140 words.  (Using 1000000 training, 100000
;; validation instances for each letter, and 100000 out of sample
;; words for testing) Details on each ambiguous character is given
;; below.  Columns are:

;; (1) ambiguous character
;; (2) number of instances
;; (3) number of errors
;; (4) error period = (2/3)
;; (5) number of rules.

;; (c 10503 46 228 2547)
;; (g 11316 14 808 752)
;; (i 66470 322 206 2953)
;; (o 17298 57 303 1621)
;; (s 23410 151 155 3198)
;; (u 24395 124 196 2394)
;; (all 153392 714 214 13465)

;; Making emacs work with foreign characters is tricky business. You
;; need to set the coding system for three things:
;; (1) file coding system is set with prefer-coding-system.  Each
;; call adds a coding system at the front of the priority list for
;; automatic detection.  The last one is used for new files.
;; (2) set-terminal-coding-system for the terminal output.
;; (3) set-keyboard-coding system for keyboard input.
;; The following uses utf-8 as default, but will recognize latin-5
;; files as well:

;; (prefer-coding-system 'iso-latin-5)
;; (prefer-coding-system 'utf-8)
;; (set-terminal-coding-system 'utf-8)
;; (set-keyboard-coding-system 'utf-8)

;;; Code:

(eval-when-compile
  (require 'cl))

(define-minor-mode turkish-mode
  "Toggle Turkish mode.
With no argument, this command toggles the mode.  Non-null prefix
argument turns on the mode.  Null prefix argument turns off the mode.

When Turkish mode is enabled, the space and TAB keys correct the previous
word by adding Turkish accents.  For corrections use C-t to toggle the
accent of the character under cursor."
  ;; The initial value.
  nil
  ;; The indicator for the mode line.
  " Turkish"
  ;; The minor mode bindings.
  '((" " . turkish-correct-last-word)
    ("\t" . turkish-correct-last-word)
    ("\C-t" . turkish-toggle-accent)
    ("\M-t" . turkish-toggle-last-word)
    ))

(defun turkish-correct-last-word ()
  "Adds necessary accents to the last word when a space is typed."
  (interactive)
  (if (= ?\r last-command-event)
      (newline)
    (self-insert-command 1))
  (save-excursion
    (let ((p (point)))
      (turkish-backward-word)
      (turkish-correct-region (point) p))))

(defun turkish-correct-region (start end)
  "Adds necessary accents to the words in the region."
  (interactive "r")
  (save-excursion
    (goto-char start)
    (while (< (point) end)
      (if (turkish-need-correction-p)
	  (turkish-toggle-accent))
      (forward-char))))

(defun turkish-asciify-region (start end)
  "Replaces turkish letters with ascii equivalents in region."
  (interactive "r")
  (save-excursion
    (goto-char start)
    (while (< (point) end)
      (let ((tr (aref turkish-asciify-table (following-char))))
	(if (not tr) (forward-char)
	  (delete-char 1)
	  (insert tr))))))

(defun turkish-correct-buffer ()
  "Adds necessary accents to the words in the whole buffer."
  (interactive)
  (turkish-correct-region (point-min) (point-max)))

(defun turkish-asciify-buffer ()
  "Replaces turkish letters with ascii equivalents in the whole buffer."
  (interactive)
  (turkish-asciify-region (point-min) (point-max)))

(defun turkish-toggle-last-word ()
  "Toggles the last word correction, so that one can undo without losing place."
  (interactive)
  (save-excursion
    (let ((end (point))
	  (start nil)
	  (accent 0))
      (turkish-backward-word)
      (setq start (point))
      (while (< (point) end)
	(let ((tr (aref turkish-asciify-table (following-char))))
	  (if (not tr) (forward-char)
	    (delete-char 1)
	    (insert tr)
	    (incf accent))))
      (if (= 0 accent)
	  (turkish-correct-region start end)))))

(defun turkish-toggle-accent ()
  "Adds or removes turkish accent at the cursor."
  (interactive)
  (let ((alt (aref turkish-toggle-accent-table (following-char))))
    (if alt
	(progn
	  (delete-char 1)
	  (insert alt)
	  (backward-char)))))

(defun turkish-need-correction-p ()
  "Determine if char at cursor needs correction."
  (let* ((ch (following-char))
	 (tr (or (aref turkish-asciify-table ch) ch))
	 (pl (assoc (downcase tr) turkish-pattern-table))
	 (m (and pl (turkish-match-pattern (cdr pl)))))
    ;; if m then char should turn into turkish else stay ascii
    ;; only exception with capital I when we need the reverse
    (if (= ?I tr)
	(if (= ch tr) (not m) m)
      (if (= ch tr) m (not m)))))

(defvar turkish-context-size 10)

(defun turkish-get-context (size)
  (save-excursion
    (let ((s (make-string (1+ (* 2 size)) ?\ ))
	  (p (point))
	  i c x space)
      (aset s size ?\X)
      (setq i (1+ size))
      (while (and (< i (length s)) (not space) (not (eobp)))
	(forward-char)
	(setq c (following-char))
	(setq x (aref turkish-downcase-asciify-table c))
	(if (not x)
	    (if space t
	      (setq i (1+ i))
	      (setq space t))
	  (aset s i x)
	  (setq i (1+ i))
	  (setq space nil)))
      (setq s (substring s 0 i))
      (goto-char p)
      (setq i (- size 1))
      (setq space nil)
      (while (and (>= i 0) (not (bobp)))
	(backward-char)
	(setq c (following-char))
	(setq x (aref turkish-upcase-accents-table c))
	(if (not x)
	    (if space t
	      (setq i (1- i))
	      (setq space t))
	  (aset s i x)
	  (setq i (1- i))
	  (setq space nil)))
      s)))

(defun turkish-match-pattern (dlist)
  (let ((rank (* 2 (hash-table-size dlist)))
	(str (turkish-get-context turkish-context-size))
	(start 0)
	len s r)
    (setq len (length str))
    (while (<= start turkish-context-size)
      (let ((end (1+ turkish-context-size)))
	(while (<= end len)
	  (setq s (substring str start end))
	  (setq r (gethash s dlist))
	  (if (and r (< (abs r) (abs rank)))
	      (setq rank r))
	  (setq end (1+ end))))
      (setq start (1+ start)))
    (> rank 0)))

(defun turkish-test-buffer ()
  "Test the algorithm on a buffer of correct Turkish text and report percent accuracy."
  (interactive)
  (setq mark-ring nil)
  (set-mark (point))
  (save-excursion
    (let ((cnt (make-vector 128 0))
	  (err (make-vector 128 0))
	  (t0 (float-time))
	  ch tr)
      (goto-char (point-min))
      (while (not (eobp))
	(setq ch (following-char))
	(if (null (aref turkish-toggle-accent-table ch)) t
	  (setq tr (aref turkish-downcase-asciify-table ch))
	  (aset cnt ?a (1+ (aref cnt ?a)))
	  (aset cnt tr (1+ (aref cnt tr)))
	  (if (not (turkish-need-correction-p)) t
	    (push-mark nil t t)
	    (aset err ?a (1+ (aref err ?a)))
	    (aset err tr (1+ (aref err tr)))))
	(forward-char))
      (princ
       (mapcar (lambda (x)
		 (list (string x)
		       (aref cnt x)
		       (aref err x)
		       (if (= (aref err x) 0) 0
                         (/ (aref cnt x) (aref err x)))
		       (let ((h (assoc x turkish-pattern-table)))
			 (if h (hash-table-count (cdr h)) 0))))
	       '(?a ?c ?g ?i ?o ?s ?u)))
      (princ (- (float-time) t0)))))

(defun turkish-backward-word ()
  (backward-word 1)
  (while (and (/= ?\  (char-syntax (preceding-char)))
	      (not (bolp)))
    (backward-word 1)))

;; I don't know why there is more than one multibyte representation
;; for Turkish characters but there is.  This table lists them.
;; Columns: ascii, unicode, utf8, latin5, multibyte latin5
;; '((?c 231 2279 231 3815)
;;   (?C 199 2247 199 3783)
;;   (?g 287 331839 191 3824)
;;   (?G 286 331838 190 3792)
;;   (?i 305 331857 209 3837)
;;   (?I 304 331856 208 3805)
;;   (?o 246 2294 246 3830)
;;   (?O 214 2262 214 3798)
;;   (?s 351 331903 255 3838)
;;   (?S 350 331902 254 3806)
;;   (?u 252 2300 252 3836)
;;   (?U 220 2268 220 3804))))

(defvar turkish-char-alist
  ;; emacsen before 23 use utf8, latin5 etc.
  (if (string< emacs-version "23")
      '((?c 2279 231 3815)
	(?C 2247 199 3783)
	(?g 331839 191 3824)
	(?G 331838 190 3792)
	(?i 331857 209 3837)
	(?I 331856 208 3805)
	(?o 2294 246 3830)
	(?O 2262 214 3798)
	(?s 331903 255 3838)
	(?S 331902 254 3806)
	(?u 2300 252 3836)
	(?U 2268 220 3804))

    ;; deniz 20100217: Emacs 23 seems to have changed its internal
    ;; representation to unicode.

    '((?c 231)
      (?C 199)
      (?g 287)
      (?G 286)
      (?i 305)
      (?I 304)
      (?o 246)
      (?O 214)
      (?s 351)
      (?S 350)
      (?u 252)
      (?U 220))))

(put 'turkish-char-table 'char-table-extra-slots 0)

;; (defun turkish-char-table (alist)
;;   "Creates a char table from an association list."
;;   (let ((ct (make-char-table 'turkish-char-table)))
;;     (dolist (entry alist ct)
;;       (aset ct (car entry) (cdr entry)))))

(defvar turkish-asciify-table
  (let ((ct (make-char-table 'turkish-char-table)))
    (dolist (lst turkish-char-alist ct)
      (mapc (lambda (x) (aset ct x (car lst))) (cdr lst))))
  "Converts turkish characters into ascii equivalent.")

(defvar turkish-toggle-accent-table
  (let ((ct (make-char-table 'turkish-char-table)))
    (dolist (lst turkish-char-alist ct)
      (aset ct (car lst) (cadr lst))
      (mapc (lambda (x) (aset ct x (car lst))) (cdr lst))))
  "Converts turkish characters into ascii equivalent and appropriate
ascii characters to utf-8 turkish accented versions.  This will also
work if the file is latin-5, emacs will automatically convert utf-8
characters to latin-5 when saving.")

(defvar turkish-upcase-accents-table
  (let ((ct (make-char-table 'turkish-char-table))
	(ch ?a))
    (while (<= ch ?z)
      (aset ct ch ch)
      (aset ct (upcase ch) ch)
      (setq ch (1+ ch)))
    (dolist (lst turkish-char-alist)
      (let ((u (upcase (car lst))))
	(mapc (lambda (x) (aset ct x u)) (cdr lst))))
    (aset ct ?i ?i)
    (aset ct ?I ?I)
    (mapc (lambda (x) (aset ct x ?i))
	  (cdr (assoc ?I turkish-char-alist)))
    (mapc (lambda (x) (aset ct x ?I))
	  (cdr (assoc ?i turkish-char-alist)))
    ct)
  "Lowercase the string except for Turkish accented characters which
are converted to uppercase ascii equivalent.  Useful for pattern
matching.  Handles all 3 encodings.  The confusing case of i is as
follows: i => i, dotted I => i, dotless i => I, I => I")

(defvar turkish-downcase-asciify-table
  (let ((ct (make-char-table 'turkish-char-table))
	(ch ?a))
    (while (<= ch ?z)
      (aset ct ch ch)
      (aset ct (upcase ch) ch)
      (setq ch (1+ ch)))
    (dolist (lst turkish-char-alist)
      (let ((u (downcase (car lst))))
	(mapc (lambda (x) (aset ct x u)) (cdr lst))))
    ct))

(defun turkish-pattern-hash (alist)
  "Compiles a decision list into a hash where keys are patterns and
values give the rank and the classification of the decision list.  The
sign of a value gives the classification (positive implies t, negative
implies nil), and the absolute value gives the rank (smaller rank
means higher priority)."
  (let ((pt (make-hash-table :test 'equal :size (length alist)))
	(r 1))
    (dolist (entry alist pt)
      (if (not (gethash (car entry) pt))
	  (puthash (car entry) (if (cdr entry) r (- r)) pt))
      (setq r (1+ r)))))

(defun turkish-make-pattern-table (alist)
  "Compiles the turkish pattern alists into hash tables for efficiency"
  (mapcar (lambda (x) (cons (car x) (turkish-pattern-hash (cdr x)))) alist))

(defvar turkish-pattern-table
  (turkish-make-pattern-table
   '((?c ("bu aXa") ("Cki Xi") ("na Xog" . t) ("ram Xo" . t) ("gol aX" . t) ("huyu X") ("m Xars" . t) ("Ik Xip") ("ncu X " . t) ("zay Xo" . t) ("Xincik" . t) ("vre aX" . t) ("mUS aX") ("ie Xol") (" eva X") ("im teX") ("kriz X" . t) ("k Xipl" . t) ("Ir 1 X") ("Xamdal" . t) ("mem Xi") ("tI Xat" . t) ("I Xalt") ("elinde Xop") ("e Xopu" . t) ("zi Xat" . t) ("ube aX" . t) ("sis Xa" . t) ("n selX" . t) ("rgIXiy" . t) ("n mUXt" . t) ("rIS uX" . t) ("kireXe" . t) ("Xiklid") ("lave X" . t) ("i minX" . t) ("es Xin") ("re Xat" . t) ("yhin X") ("az haX") ("mi Xar" . t) ("orge X") ("kovaX ") ("ak Xat" . t) ("Or aXa") ("rpar X") ("da teX") ("de Xeb") ("yarInX") ("eXeres") ("fon aX" . t) ("ri Xem") ("tino X") ("5 i aX" . t) ("1 00 X") ("i dolX" . t) ("rarInX") ("kIS aX" . t) ("I penX") ("n aXim") ("va aXi" . t) ("iz Xik" . t) ("olma X" . t) ("g un X" . t) (" reXet" . t) ("Xalisk" . t) ("u seXi" . t) ("uXular") ("birinX") ("n Xocu" . t) ("aXlari" . t) ("s uX ") ("n OXe") ("USXus") ("boraX") ("laXo " . t) ("Xookt" . t) ("Xamca" . t) ("ikXik") ("penXo" . t) ("elaXo" . t) ("Xubak" . t) ("ikelX") ("Xolly") ("I c X" . t) ("Xivid" . t) ("eXvir" . t) ("teviX") ("konXi" . t) ("tiniX" . t) ("boriX") ("refaX" . t) ("a gaX" . t) ("as tX" . t) ("clisX") ("0 Xul") ("riraX" . t) ("Con X" . t) (" bulX" . t) ("Xuyoz") ("Xuyo ") ("r d X" . t) ("oXano" . t) ("eXon " . t) ("Xitra" . t) ("he uX") ("4 akX" . t) ("269 X" . t) ("a uXe" . t) (" Cu X" . t) ("laniX" . t) ("iCaXa") ("nXars" . t) ("  dX " . t) ("Xambe" . t) ("dad X") ("51 Xb") ("romaX") ("zXak ") ("kuXar" . t) ("Ximbl") ("fdarX") ("Xerag" . t) ("Xoret") ("sXiml" . t) ("krosX" . t) ("Xagay") ("5 Xi " . t) ("Xikig" . t) ("Xabac") (" leXe" . t) ("Xokk ") ("zI X " . t) ("heriX") ("CiviX") (" kunX") ("raviX") ("yo X " . t) (" Xies" . t) ("zeliX" . t) ("t Xa " . t) ("u daX" . t) ("Xopea") ("U ruX") ("GdaSX") ("Xont " . t) ("n h X" . t) ("I h X" . t) ("Xilea") ("juiXi" . t) ("IXiyo" . t) ("iyteX" . t) ("eXemd") ("GdI X" . t) ("Xinyu" . t) ("Xoruw") ("yanXe" . t) ("Xogit") ("Xarip") ("rXal " . t) ("e Xeg" . t) ("kapuX" . t) ("s aXk") ("  Xi " . t) (" Ci X" . t) ("kuSXa") ("az X " . t) ("kanXe" . t) ("oXanl" . t) ("ily X") ("lpenX" . t) ("Xinn " . t) ("Xarpo") ("Xails" . t) ("rSi X") ("rdziX") ("gariX") ("roXel" . t) ("ay X " . t) ("UzgUX" . t) ("aXise") (" ka X" . t) ("liXic" . t) ("c Xit") ("hraXe" . t) ("tmuSX") ("menkX") ("od Xu" . t) ("ylk X") ("m y X" . t) ("Xiroz" . t) ("utXun") ("oniXl") ("l aXd" . t) ("uXins" . t) ("borXi" . t) ("Xormo") ("Xokan") ("hotiX" . t) ("rXent") (" liX " . t) ("Xopol" . t) ("GaXay" . t) (" Xova") ("mka X" . t) ("rIlIX" . t) ("mihaX" . t) ("voriX") ("faXas" . t) ("cur X") ("m aSX") ("umiXi" . t) ("1 3 X" . t) ("lfo X") ("nXalo" . t) ("usiXi" . t) ("ta Xk" . t) ("UkXil") ("t U X" . t) ("katiX" . t) ("ikaXt") ("m Xoo" . t) ("gur X" . t) ("Xorai") ("Xamga" . t) ("0 uX ") ("Xapo ") ("mamiX") ("un OX") ("viXka") ("Xolen" . t) ("bow X") ("ebiXe") ("visiX") ("GretX") ("33 uX") ("Xizek") ("bereX") ("ep X " . t) ("In X " . t) ("lk X " . t) ("Xike " . t) ("parXe") ("sUrXe") ("olXel" . t) ("Xolat") ("zunX ") ("daXay" . t) ("maXhu" . t) ("u Xa " . t) ("Xano") (" iXan" . t) ("grgIX") ("Xapuc") ("ub Xa" . t) (" Xite") ("Xayet") (" Xikk") (" nunX" . t) ("a Xau" . t) ("UmUSX" . t) ("Xamye") (" Xamy" . t) ("U O X" . t) (" aaXi" . t) ("gUniX" . t) ("Xhir " . t) ("Xaliz") (" os X") ("bu X " . t) ("SI X " . t) ("Xonac" . t) ("aht X" . t) (" s Xr" . t) (" aXkl" . t) ("aXarb") ("31 Xa" . t) ("gb Xi") ("OkXis") ("urtIX" . t) ("edeXa" . t) ("ure X") ("p Xul" . t) ("ni X " . t) ("IlkIX" . t) ("riciX" . t) ("Xolad") ("b Xal") ("u Xe " . t) ("Xulli") ("y Xip") ("lasaX" . t) ("C Xav") (" kliX" . t) ("emoX ") ("Xasit" . t) ("fle X" . t) ("biXek") ("Xopel") ("2 Xiy") ("C Xo " . t) ("enseX") ("UleXo" . t) (" iXre" . t) ("Xecel") ("filiX") ("dre X") ("ulenX") ("Xides") ("I e X" . t) ("ulaXi") ("IrmiX") ("p paX" . t) ("i Xod") ("Xukad" . t) ("piriX" . t) ("dy Xa") ("nXuh") ("manXu" . t) ("mra X") ("S Xi " . t) ("h Xi " . t) ("Xifle") ("Xigan" . t) ("erkeX" . t) ("otXul") ("p erX") ("uXarm") ("vcanX" . t) (" aXih" . t) ("Xapsh") ("Xabul") ("b aX ") ("rasiX") ("Xetla") (" Xays") ("nXiko" . t) ("deXel" . t) (" aXa " . t) ("  Xrp" . t) (" hp X") ("li OX" . t) ("rXas ") ("S Xa " . t) ("gio X") ("Xobur") ("zIk X" . t) ("ep Xo" . t) ("y ahX") ("em X " . t) ("guk X") ("I Xo " . t) ("  SuX" . t) ("m Xut" . t) ("haXla" . t) ("  e X") ("Xinis") ("Xinta" . t) ("nlatX") ("Sok X") ("k Xe " . t) (" kiXh" . t) ("pinXi" . t) ("fi aX" . t) ("skeXi") ("liXek") ("uro X") ("tCa X" . t) ("p liX" . t) ("nakiX") ("ty Xe") (" feXe" . t) ("biXir") ("asalX") ("erkaX" . t) ("n poX" . t) ("5 Xur") ("aXare") ("saXid") ("nXan ") ("dinXa" . t) ("nXag " . t) ("seXev") ("S Xeb") (" okaX") ("kit X" . t) ("  orX" . t) ("ekkeX") ("n puX") ("erenX") ("aCkIX" . t) ("o uXa" . t) ("pe Xo") ("Xalgo") ("laaaX" . t) ("eniXi") ("z Xuc" . t) ("f Xul") ("kukiX") (" ngoX") ("koiXi" . t) ("Xitak" . t) ("Xiste" . t) ("maniX" . t) ("e boX") ("Xino ") ("hXan ") ("eXiog") ("fa X " . t) ("panXo" . t) ("saXim" . t) (" daXa" . t) ("lXugi" . t) ("ed Xa") ("saXan" . t) ("Guk X" . t) ("garXi") (" apaX" . t) ("bataX") ("b eyX" . t) ("i z X" . t) ("i s X" . t) ("Xoptu") ("Xiban" . t) ("Xogam") ("anXic" . t) ("ikaCX") ("S Xoc" . t) ("of aX") ("Xilav" . t) ("nXerl" . t) ("e Xib") ("Xileg" . t) ("Xayiv") ("eji X" . t) ("Xopli") ("llaXi") ("u erX") ("I Xeb") ("iXiye") ("45 Xa" . t) ("m Xep") ("isXi " . t) ("smuSX") ("f Xil" . t) ("Xolga") ("aXada") ("GmaXi") ("mes X") ("a baX") ("Xinga" . t) ("rpenX" . t) ("C Xe " . t) ("Xilab" . t) ("ar X " . t) ("Xayam") ("jevaX") ("omanX") ("eberX") ("iskoX" . t) ("oy Xo" . t) ("kaniX" . t) ("arXak") ("amaXa") ("karXe" . t) ("C Xoc" . t) ("stanX") ("ranXe") ("orveX" . t) ("leriX") ("maXis") ("Xamag" . t) ("aS iX" . t) ("a uXa" . t) ("anXin") ("Xerel") ("rt aX" . t) ("Xalig") ("ediXi") ("t ilX" . t) ("myonX") ("Xetes" . t) ("retiX") ("Xanli") (" Xesa") ("bovaX") ("pis X") ("Xecen" . t) ("UreXe") ("U miX") ("urmaX") ("Xceg" . t) ("vereX") ("rdUnX") ("acatX" . t) ("ndy X") ("lerXe") ("layaX") ("laXag") ("mumXi" . t) (" aCaX") ("n Xik" . t) ("Xesit" . t) ("Xerek" . t) ("a Xik" . t) ("SXeg") ("tavX" . t) ("amXl" . t) ("dstX") ("Xolw") ("zkUX" . t) ("erIX") ("Xrec" . t) ("Xsit" . t) ("yodX" . t) ("tXeg") ("bseX") ("goXn" . t) ("Xlah") ("Xolb") ("hXur") ("edoX") ("umXe" . t) ("geXu" . t) ("usuX") ("rXee" . t) ("etcX" . t) ("Xiok" . t) ("Xogh") ("iXma") ("koXr" . t) ("hefX") ("fXad") ("moXl") ("gliX") ("skUX" . t) ("tiyX" . t) ("vyaX" . t) ("C X " . t) ("koXc" . t) ("vniX" . t) ("Xaeb" . t) ("IlXu" . t) ("CelX") ("SXig") ("piXl" . t) (" Xoi") ("uicX" . t) (" UXc" . t) ("girX") ("Xoct") ("keXc" . t) ("ruXi") ("pUrX" . t) ("pIrX") ("nkXl") ("CiaX" . t) ("yaIX") (" UlX" . t) ("iy X" . t) ("eetX") ("blIX") ("aveX") ("rnuX") ("Xtif") ("feXl" . t) ("oXev") ("ljuX" . t) ("Xorf") ("tabX") ("geaX" . t) ("kUCX" . t) ("kUXc" . t) ("OnXi" . t) ("iXet") ("tXas") ("mlaX") ("wo X") ("apiX" . t) ("hiXd" . t) ("Xagr" . t) ("uy X") ("Xebl" . t) ("rilX") ("Xelv") ("y Xk" . t) ("Xsu ") ("peXk") ("ukuX" . t) (" uzX" . t) ("x Xo") ("yaXm") ("IXaa") ("OzaX" . t) ("Xech") ("OrtX") ("oXko") ("kXah" . t) ("uliX") ("lilX") ("CliX") ("Xipt") ("Xal1" . t) ("oyXa" . t) ("CiXc" . t) ("rokX") ("lasX" . t) ("iXoc" . t) ("morX") ("boXo") ("ouaX") ("Xamt" . t) ("dIrX") ("buCX" . t) ("nXov" . t) ("nXs " . t) ("Xirn") ("onX ") ("e Xg") ("Xatr") ("ondX" . t) ("nXez" . t) ("odiX") ("Xork") ("Xoum" . t) ("inkX") ("utuX") ("uXcu" . t) ("yuhX") ("Xnae" . t) ("Xao ") ("umcX" . t) ("Xve " . t) ("uXea") ("Xayy" . t) ("kiXd" . t) ("udoX") (" gXu" . t) ("gneX" . t) ("Xesz") (" Xcs" . t) ("ruXr" . t) ("Xozy") ("lviX") ("Xibr") ("Xlur") ("ulXi" . t) (" nIX") ("sezX" . t) (" isX") ("raXd" . t) ("isaX") ("srtX") ("leXa" . t) ("pelX") ("tXem" . t) ("I Xg") ("zilX") ("vasX") ("4 yX") ("uzUX" . t) ("gelX") ("Xuan" . t) ("nviX") ("lguX") ("Xcag" . t) ("ureX") ("agaX") ("imXa" . t) ("muXa") ("guXu") ("tXce" . t) ("Xucg" . t) ("nXvi" . t) ("veXk") ("Xavk") ("liXl" . t) ("Xadu" . t) ("my X") ("Xdis" . t) ("pmeX") ("lseX") ("oduX") ("uSuX") ("iXev" . t) ("Xulh" . t) ("Xiol") ("paSX" . t) ("UziX" . t) ("Xot ") ("uXit") ("ikiX") ("kiXa" . t) (" zUX") ("omeX") ("kkeX" . t) ("aXif") ("I dX" . t) ("fuXk") ("cInX") ("hunX") ("almX" . t) ("Xirv") ("eXig") ("punX") ("msiX") ("syaX") ("aIrX") ("Xinh" . t) ("oXea") ("ierX") ("usaX") (" gIX") ("dluX") (" aXc") ("fliX") ("suXo" . t) ("ssoX") ("puXu") ("fXan") ("fInX") ("heXe") ("nCIX") ("Xin1" . t) ("a Xb") ("mXak" . t) ("halX") ("Xesc") ("gIXa") ("umaX") ("breX") ("Xatf") ("Xevt") ("iXig") ("Xuls" . t) ("vaXt" . t) ("Xlaf") (" yeX" . t) ("elaX") ("reXo") ("rlaX") ("danX") ("nXur") ("ibiX") (" UXk" . t) ("USXe") ("uziX") ("nduX") ("zXes") ("Xaz ") (" aSX" . t) ("Xoco") ("proX") ("plIX") ("Xenn") ("lXam" . t) ("betX" . t) ("Xagn") ("Xigd" . t) ("Xesm" . t) ("IkIX") (" bIX" . t) ("asaX") ("hiiX" . t) ("Xabu" . t) ("ekeX") ("rliX") ("rkIX") ("Xmil") ("UnUX" . t) ("SUnX") ("ImaX") ("Xade") ("Xatc") ("Xilm" . t) ("marX") ("rXus") ("porX") ("Xtik" . t) ("kaXt" . t) ("enXi") ("eteX") ("eXeg") ("silX") ("yrIX") ("Xozu" . t) (" iXi" . t) ("UXn" . t) ("yXp" . t) ("Xbc") ("aXj" . t) ("Xgw") ("tXp" . t) ("IeX") ("Xcg" . t) ("Xzo" . t) ("hXp") ("Xsc") ("Xo2") ("kXp") (" X1") ("aXf") ("weX") ("kcX" . t) ("dXg" . t) ("wrX") ("znX") ("jnX") ("ueX") ("Xth") ("iXp") ("Xzy") ("Xej") ("tXb") ("SCX") ("SXc" . t) ("Xeu") ("uXv" . t) ("UbX") ("sOX" . t) ("chX") ("Xix") ("voX") ("lcX" . t) (" SX") (" lX") ("tCX") ("UXv" . t) (" hX") (" fX") ("euX") ("jeX") ("4aX") ("eXg") ("llX") ("ylX") ("rzX" . t) ("GuX") ("thX") ("yXb" . t) ("rXh") ("jlX" . t) ("iXm" . t) ("IXt" . t) ("Xd ") ("iuX") ("Xlo") ("Xah") ("yIX") ("Xks") ("Xok" . t) ("qX") ("Xx") ("X2" . t) ("X5" . t) ("X7") ("abilme gUXune" . t) ("imin sonuXud" . t) ("0 stankoviX") ("i smeonoviX") ("n mijatoviX" . t) ("I silah gUX" . t) ("layan saraX" . t) ("k halilagiX" . t) ("zlar polisX") ("i halilagiX" . t) (" elindeki X" . t) ("nlarInIn Xo" . t) ("n de aXikt") ("a ivanoviX") ("Iyla baliX" . t) ("ar ve Xam " . t) ("i raftingX" . t) ("k markoviX") ("rIlmayan X" . t) ("asInda Xop") ("i bir Xam " . t) ("nin Xanlar" . t) ("i sonuXudu" . t) ("r dolara X" . t) ("a aXisini") ("I Xanlar " . t) ("kan a aXi") ("u da Xaba") ("a aXiyord") ("i de Xaba") ("e vlaoviX" . t) ("i adI geX" . t) ("ne ve Xog") ("an aXilar") ("na geXeli" . t) ("e keynesX") ("ka bir aX" . t) ("lara aXiy") ("zeki Xab") ("e armutX") ("a aXisiy") ("unda Xos" . t) ("r aXisid") (" aXisin ") ("men Xop ") ("okanoviX") ("n genXel" . t) ("Cek kauX") ("son haXi" . t) ("bi dostX") ("an mahXu") ("  bu Xos" . t) ("ulu Xam " . t) ("im aXim ") ("bin Xam " . t) ("tU saraX" . t) ("I kuruXa" . t) ("nce Xamd" . t) ("vaS aXis") ("e pen X") ("n Xiler " . t) ("ek aXili" . t) ("emiS Xin") ("isini Xo" . t) ("eki Xim " . t) (" de Xam " . t) ("zasIna X" . t) (" Xandik" . t) ("joroviX") ("n kukoX" . t) ("Xandarl" . t) ("nobil X" . t) ("nuna iX") ("in Xad " . t) ("  barXa" . t) ("a avdiX") ("kada X " . t) ("ecep Xi") ("ir haX " . t) ("aXiklis") ("panoviX") (" tarXin" . t) ("oXanind" . t) ("t Xilar" . t) ("er Xayi" . t) ("lI saX ") (" ta Xam" . t) ("lit Xam" . t) ("ri Xaml" . t) ("batIXim" . t) ("lsa Xam" . t) ("an nahX") ("ok aXiy") (" paXin " . t) (" Xinlik") ("ri Xat " . t) ("m saraX" . t) (" Xurumd") ("a arXa " . t) ("lan akX" . t) ("un akXa" . t) ("ol Xin ") ("usam aX" . t) ("ma Xaml" . t) ("da faXa" . t) ("aS aXi ") ("trafI X" . t) ("bu Xin ") ("ze aXiy") (" un aX ") ("t Xarsi" . t) ("i o gUX" . t) ("niGde X" . t) ("tekli X" . t) ("hce maX") ("t urumX" . t) ("dada Xa" . t) ("in aXiy") ("Um aXis") ("lis Xe " . t) ("ve aXim") ("ce Xop ") ("  Xamla" . t) ("le Xosu" . t) ("et genX" . t) ("S aXil ") ("ni aXis" . t) (" Sen X " . t) ("rlIk Xa" . t) ("Xarcal") ("kut Xu" . t) ("d maX ") ("urem X" . t) ("8 Xarm") ("afa aX") ("kentiX" . t) ("Xollez") ("I Xor ") ("si Xop") ("ner X " . t) ("aloviX") ("z aXiz" . t) ("Xatanz") ("cop Xo") ("haraXo") ("Xemred" . t) (" maXak" . t) ("ru Xam" . t) ("Xallin") ("In Xi " . t) ("Xilesu") ("Xagiva") ("Xarine") ("eXeme ") ("zon X " . t) ("yin X " . t) ("l Xirc" . t) ("aolo X") ("Xogani") ("uzoviX") ("uroviX") ("Xivit " . t) ("fiye X" . t) ("borXul" . t) ("n Ximm") ("zangoX" . t) ("ste aX" . t) ("ri uXl" . t) ("Xentik" . t) ("Xopluy") ("arakaX" . t) ("Xapule") ("Xucukl" . t) (" Xerme") ("eXemin") (" geXi " . t) ("Xorvan" . t) ("Xelebr") (" Xelli" . t) ("atoriX" . t) ("rk Xu " . t) (" Xello" . t) ("Xevri ") (" meXim" . t) ("Xiple ") ("rm Xan" . t) ("yaratX") ("aya X " . t) ("iteliX" . t) ("li teX") ("g Xole") ("enXayd" . t) ("ol Xul") ("on Xim" . t) ("gin X " . t) ("vaXev ") ("Xevriy") ("a aXim") ("Xisimi" . t) ("Xelil ") ("as Xil") ("t Xinc" . t) (" aXinm") ("eramiX") (" Can X" . t) ("  Xop ") ("m aXiy") ("Xorduk" . t) (" Xinim") ("l Xars" . t) ("k Xars" . t) ("i momX" . t) ("un Xat" . t) ("unXell" . t) ("p Xars" . t) ("Xalis " . t) (" iC aX" . t) ("hayalX") ("Xanakk" . t) ("Xolas ") ("da taX") ("OGrenX") ("aXiss") ("Xorel") ("poreX") ("Xars ") ("6 akX" . t) ("5 akX" . t) ("s Xip") ("Xopta") ("SilXe") ("uto X") ("Xapou") ("lIXag") (" OlUX" . t) ("oXanl" . t) ("Xalib") ("C Xop") ("iXolu") (" eXci" . t) ("iadiX") ("eXhil" . t) ("vehiX") ("giniX" . t) ("Xidam" . t) (" iXha" . t) ("uk X " . t) ("SarkX") ("UnXer" . t) ("Xayil") ("kXel ") ("nn Xi" . t) ("aXipa") ("mrsIX" . t) ("s Xi " . t) ("Xuzum" . t) ("Xallu") ("saXu " . t) ("mleX " . t) ("Xesim") ("ehiXe") ("za X " . t) ("izaX " . t) ("k Xo " . t) (" Xibu") ("uXal ") (" baXe" . t) ("Xarei") ("Xatic") ("beliX" . t) ("v Xam" . t) ("GraXi" . t) ("Xipol") ("dahiX") (" Xabo") (" Xyp " . t) ("Xadas" . t) ("dIXal" . t) ("hXenl" . t) ("odziX") (" Xaaa" . t) (" peXi" . t) ("roliX") ("g Xii" . t) ("pamiX") ("n gaX" . t) ("aselX" . t) ("lingX" . t) ("o Xi " . t) ("Xorey") ("perXe" . t) ("i iXk" . t) ("Xitat") ("Xoraz") ("Xelia") ("kuXuk") ("adXek" . t) ("CalIX" . t) ("k Xul" . t) ("banXe" . t) ("OlgeX") ("liXeg") ("erhaX" . t) ("foXal" . t) ("dalXa" . t) ("kmiSX") (" Xicc") (" Xic ") ("Ximbo") ("i Xu " . t) ("Xold ") ("teXko" . t) ("ymISX") ("daliX") ("Xall ") ("nXika" . t) ("k kuX") ("i daX" . t) ("juriX") ("rie X") (" aXme") ("Xeter") ("U Xul") ("hIrXi" . t) ("eXme " . t) ("ilXi ") ("IlXi ") ("Xeber") ("anXos" . t) ("oiniX" . t) ("Xelal") ("UXunc" . t) ("nsu X" . t) ("raliX" . t) ("mayaX") ("Xitie") ("Xipp") ("a Xg") ("suXh") ("OXel") ("ekX " . t) ("etuX") (" bXe") ("Xcok" . t) ("oseX") ("mXat" . t) ("abXi" . t) ("tUlX") ("seXn" . t) ("olIX") ("iCX ") ("iXc " . t) ("Xegs") ("delX") ("Xec ") ("nXai" . t) ("eguX") ("Xizv") ("filX") ("Xlag") ("aiXi" . t) ("Xave") ("rreX") ("auXk") ("oyiX" . t) ("lkIX") ("Xalh") (" imX" . t) ("paXu" . t) ("akUX" . t) ("ameX") (" ihX") ("hilX") ("  OX") (" oXi" . t) ("gasX") ("cXis" . t) ("oaXi" . t) ("Xatu") ("praX") ("aCXa") ("Xipr") ("braX") ("liXk") ("naXt" . t) ("zalX") ("cilX") ("teXl" . t) ("Xlea") ("lriX") (" vuX") ("yriX") ("ImIX") ("Xab ") ("juiX") ("Xii ") ("farX") ("dviX" . t) ("heXk") (" aXu") ("CXeg") ("Xceg" . t) ("Xso ") ("Xopo") (" raX") (" InX") ("anIX") ("Xaru") ("llIX") (" keX" . t) ("truX") ("tirX") ("derX") ("denX") ("aXta" . t) ("nmaX") ("Xats") (" muX") ("Xagl" . t) ("Xobo") ("piXi" . t) ("UrUX") ("nriX") (" CiX" . t) ("chiX") ("Xisl" . t) (" CeX" . t) ("riXk") ("sveX" . t) ("kinX") ("uraX") ("yunX") ("bahX" . t) ("yiXe") ("leXe") ("uXp") ("0X ") ("Xgt") ("Xgp") ("Xsh") ("pXh") ("Xoj") ("Xbk") ("Xaw") ("ncX" . t) ("cnX") ("eXu") ("eaX") ("xoX") (" kX") ("hOX") ("Xei") ("Xiw") ("Xb ") ("Xae") ("Xts") ("Xk ") ("Xho") ("Xw") ("a halilagiX" . t) ("en bregoviX") ("6 petroviX") ("  bregoviX") ("e aXiyorum") ("menin aXis") ("virdiGi Xa" . t) ("edeki Xam" . t) ("i aXisini") (" Xurumu ") ("har korX" . t) ("lise Xan" . t) ("nra Xam " . t) ("ha Xook " . t) ("te tunXa" . t) ("i aXiniz" . t) ("1 ladiX") ("tanoviX") ("jatoviX") ("ir Xim " . t) (" Xildim") ("aXisiyd") ("k aXimi") (" sUrXu " . t) ("ni aXar" . t) ("Xiklet ") ("  aXisi") ("  Xad " . t) ("UC Xim" . t) ("akapaX" . t) (" daciX" . t) ("Xakimi") ("gazetX") ("n Xilo") ("Xaball") ("I Xad " . t) ("raXk") ("aXken " . t) ("za Xam" . t) (" sam X") ("a in X") ("Ik Xa " . t) ("ilitiX" . t) ("U aXar" . t) ("r aXim") ("tatUrX" . t) (" basiX") (" Xilik") (" kanXi" . t) ("Xitico") ("i Xipi") ("Xoplu ") (" Xinde" . t) ("k aXar" . t) ("k Xile" . t) (" Xorle") ("olaXan" . t) ("o Xe " . t) ("yra X" . t) (" laXm") ("Xavas" . t) ("obuXi" . t) ("demaX" . t) ("us X " . t) ("sliXe") ("lXime" . t) ("Xubai" . t) ("ruXam" . t) (" anXu" . t) ("nCXi ") ("aXely" . t) ("Xusok" . t) ("Xorbu") ("hoviX") ("Xigna") ("Xenem" . t) ("ekliX") ("balIX") ("gamiX") (" Xis " . t) ("Xorbe") ("Xeney" . t) ("Xibik" . t) ("taXam") (" Ximc") ("Xungu" . t) ("pereX") ("iiriX" . t) ("iaXik" . t) ("aoviX") ("im X " . t) ("t Xe " . t) ("Xoper") ("rXakl") ("Xakas") ("ollaX") ("garXo" . t) ("tUk X" . t) (" Xadl" . t) ("eXem ") ("iCinX") ("Xurac" . t) ("e soX") ("Xeng " . t) ("mariX") ("ndiXt" . t) ("06 aX") ("poGaX" . t) ("d Xil" . t) ("o Xol") ("Xarib") ("utreX") (" OzXe" . t) ("the X") ("Xara ") (" Xert") (" Xibi") ("iXre " . t) ("Xatal" . t) ("Xeleb" . t) (" sanX") ("ael X") ("CIkaX") ("iXin " . t) ("gorX" . t) ("paiX") ("Xhc " . t) ("i Xb") ("njiX" . t) ("geXr" . t) ("kuXc" . t) ("Xicl") ("hXak") (" uXo" . t) ("SliX") ("oXel") ("Xkow") ("GaXd" . t) ("Xazo" . t) ("Xotu" . t) ("nXka" . t) ("onUX" . t) ("komX" . t) ("oboX") (" yX " . t) ("mUlX") ("UnXa" . t) ("Xorg") ("turX") ("pheX") ("naXy" . t) ("adaX") ("Xuli") ("tXeb") ("Ximo") ("iXla") ("reXk") ("relX") ("zorX") ("Xif ") ("corX") ("  Xb") ("Xolm") ("Xorv") ("meXk") ("tXig" . t) ("Xaog") ("eduX") ("n Xb") ("Xinar" . t) ("liXi") ("nlIX") ("UXet") (" Xeg") ("Xoda" . t) ("ny X") ("avaX") ("lIXk" . t) (" baX") ("uXuz") ("unuX") ("luXu") ("IlaX") ("yaXa") ("sXv" . t) ("plX") ("Xoq") ("Xgr") ("OhX") ("Xaj") ("CuX") ("coX") ("Xyu" . t) ("In da Xab" . t) ("e aXisini") ("urhan OX" . t) (" Xisini " . t) ("men Xe " . t) (" Xatani") (" Xinlig") ("araXali" . t) ("na Xop ") ("r Xarsi" . t) ("aXiktik") ("Sin Xab") ("na Xivi" . t) (" aXimi ") ("laXayi" . t) ("omoviX") (" ganiX" . t) ("Xarni " . t) ("uloviX") ("venXer" . t) (" abaXa" . t) ("k mesX") ("Xankat") ("Xapra ") ("p Xile" . t) ("genXog" . t) (" Xelie") ("s Xile" . t) (" Xemis" . t) ("ureviX") ("miraX " . t) ("rteXin" . t) (" Xult") ("zeviX") ("tlaXi") ("Xarst") ("ohaX " . t) (" aXag" . t) ("Xalme") ("Xates" . t) (" uXul" . t) ("ymiSX") ("suXug") ("geraX") ("opaXi") ("Xiyak") ("alXis") ("e Xa " . t) ("Xore ") ("Xobai") ("suriX" . t) ("haXam") ("k Xi " . t) ("IlXay" . t) (" kuXu" . t) ("4 aX ") ("Xenen" . t) ("Xciog" . t) ("Xopu ") (" piX " . t) ("aXill") ("Xollo") ("rmuSX") ("rpaXi") ("Xuruf") ("aXars" . t) ("n Xeb") ("Xizme" . t) ("abanX") ("yapaX") ("dereX") ("IaX ") ("iseX") ("Xirr") ("CIrX" . t) ("Xtus") ("Xopa") ("e Xb") (" Xoy") ("egiX") ("aXlu") ("rUlX") ("afuX") ("Xova" . t) ("Xopy") (" auX") ("Xolt") (" Xaa") ("Xoch") ("kXad" . t) (" y X") ("Xarv") ("mXav" . t) ("fusX" . t) ("Xecc") ("uXay" . t) ("rCaX") ("Xach") ("uniX") ("Xace") ("Xabl") ("ksiX") (" guX") ("eXka") ("zeXi") ("melX") ("iXio") ("traX") ("zXak" . t) ("rviX") ("Xopp") ("dilX") ("carX") ("ralX") ("iXid") ("risX") ("Xalo") ("utuX") ("Xaye" . t) ("osiX") ("neXe") ("resX") ("niXk") ("Xage") ("Xlau") ("ruXu") ("dtX") ("0Xs") ("cuX") ("Xee") ("ioX") ("Xiu") ("oeX") ("Xkb") ("hX ") ("Xgo" . t) ("cIX") ("hoX") ("pIX") ("Xh ") (" nX") ("e aXisiy") ("ptIGI aX" . t) ("Xarlest" . t) ("u 5 geX" . t) (" Xarlar" . t) ("eXekles" . t) ("tar taX") ("rkaXin ") ("et aXar" . t) ("et Xile" . t) ("erda X" . t) (" cIk X") ("eroviX") ("Xelep ") ("Xhisar" . t) (" reXin" . t) (" aXlan") ("aXimiy") ("eXeniz") ("gUlXe ") ("  aXim") ("nda X " . t) (" aXiyd") (" Xole " . t) ("aXisiz") ("i Xars" . t) ("Xarnac" . t) ("Xoldi") ("rIXak") ("Xopei") ("Xamol" . t) ("araXc" . t) ("kvenX") ("indaX") ("Xopen") ("Xarpe") ("Xalai") ("Xarso") (" mXp " . t) ("ikeXi") ("Xasla" . t) ("aXide") ("hiXan" . t) ("palaX") ("Xomel" . t) (" Xeri") (" eliX" . t) ("zIl X" . t) ("IlIXh" . t) ("balXa") ("Xibal") (" tUrX" . t) ("harXi") ("Xaris") (" olaX") ("Xobh") ("iXun" . t) (" iXd" . t) ("guXi" . t) ("Xisu") ("InXo" . t) ("phiX") ("naXl" . t) ("Xalp") ("Xcam" . t) ("Xevv") ("IXer" . t) ("Xav ") (" Xug" . t) ("gsiX") ("yIrX") ("Xizz") ("rdiX") ("Xerp") ("mliX") ("obiX") ("miXi") ("Xat ") ("lXy") ("nXd" . t) ("Xkn") ("ouX") ("iCX" . t) ("tIX") ("Xhe") ("Xez") ("k aXisini") ("aXikmist") ("cili biX") ("lI haX " . t) ("r aXar " . t) ("enoviX") ("oger X") (" anaX " . t) ("haXin " . t) (" erXeg") ("slamiX") ("Xarli ") ("  Xars" . t) ("eniXag" . t) ("a Xars" . t) ("Xerny") ("Xalte") ("lerX ") ("l Xim" . t) (" Ximi") ("ukXev") ("kolXa" . t) ("doviX") ("illaX") (" aXas" . t) ("Ximis") ("CinXi" . t) (" aXiv" . t) ("Xubur") ("rnaXa" . t) (" Xaci") ("Xilde") ("Xilas") ("Xagiz") (" CerX" . t) ("ukoX") ("Xac ") ("eiXe") ("Xoge") ("Xirc") ("kleX" . t) ("Xapc") ("dXi " . t) ("asXi" . t) ("Xorc") ("Xtiv") ("bilX") ("Xess") ("Xaat") ("Xuko" . t) ("chIX") (" OnX") ("UsX" . t) ("Xyp") ("vIX") ("CoX") ("zIX") ("1X") (" Xeltik" . t) ("zIl haX" . t) ("pantiX" . t) ("Xapaci") ("arIXam" . t) (" Xeles") (" Xanag" . t) (" Xire") ("balXe") ("aliXo" . t) (" Xun " . t) (" arX ") ("Xeka ") (" iXac" . t) ("Xayim" . t) (" Xery") ("jeviX") (" Xise" . t) ("naXiz" . t) ("oniXe" . t) ("Xatta") ("dansX" . t) ("Xivr" . t) ("Xeca") ("Xapp") (" Xod") (" iXn" . t) ("skeX" . t) ("lXat") ("Xori") ("Xabe") ("kXam" . t) ("itaX") ("uCiX" . t) ("Xelt") ("psaX" . t) ("Xurp" . t) ("terX") ("Xau") ("Xof") (" Xf") ("eeX") ("Xph") ("alil Xi") (" penXe " . t) ("adi Xam" . t) (" Xortu" . t) ("saraXh" . t) ("isi X " . t) ("haXan " . t) (" kIlXi" . t) (" Xelin") (" Xular") ("eXeyim" . t) ("nUlaX" . t) (" Xed " . t) ("Xomez" . t) ("f Xim" . t) ("buXug" . t) ("Xerez" . t) ("ykelX") ("Xaka ") ("Xiviy" . t) (" Xabi") ("aXiki") ("Xikan" . t) ("pXan") ("UXur") ("iiXi" . t) (" Xhd" . t) (" UXd" . t) ("atXu") ("aXte") ("plaX") ("Xcik" . t) ("Xkov") ("rpiX" . t) ("taXm") ("Xubi") ("luXi") ("yiX " . t) ("ogiX") ("Xift" . t) (" viX") (" pX") (" rX") ("wiX") ("oiX") ("aeX") ("Xj") (" aXilarindan" . t) ("n aXisiy") ("dinXel " . t) (" deneX " . t) ("t Xine" . t) (" Xenel" . t) (" Xaril") (" Xado" . t) ("parX ") ("mXeli" . t) ("ick X") ("Xalde") ("joviX") (" aXir") ("gUXer" . t) ("Xengi") ("Xepn" . t) ("Xevz") ("imiX") ("IrXe") ("Xelp") ("Xilk") ("Xock") ("SXan") ("Xiz ") ("kiXe") ("nkaX") ("galX") (" iXe" . t) ("hXr") ("brX") ("Xkm") ("huX") ("loX") ("jiX") ("Xalgar") ("Xalabr") (" Xigim") ("Xaptag") (" Xinin") (" Xecil") ("us Xar" . t) ("cem Xo" . t) ("Xamli ") ("holiX") ("aXay " . t) ("Xizir") (" Xary") ("ceviX") (" troX" . t) ("Xomle" . t) ("OnetX") ("Xasod" . t) ("nXev " . t) ("larXa") ("Xaly") ("SXen") ("uXer") ("Xlai") ("varX") ("uXe ") (" unX") ("veXi") ("Xevr" . t) ("akaX") ("ebX") ("Xkv") (" tX") ("yuX") (" de Xabas") (" aXind") ("iXisi ") ("u aXar" . t) ("jukiX") ("civiX") ("erXam" . t) ("Xupi " . t) ("CariX" . t) ("deriX") (" arXa") (" orXu" . t) ("edriX") ("elXa") ("imaX") ("mpaX") ("vilX") ("buXl" . t) ("yXan") ("lnX") ("ieX") ("iaX") ("Xaf") ("Xoe") (" uXla ") ("GanXay" . t) ("lIXasi") ("Xarmin") ("a aXar" . t) ("e Xars" . t) ("bortaX" . t) ("Xollec") ("sIXan" . t) ("laXik") ("ulusX" . t) (" Xak ") ("selXi") ("Xenko" . t) ("Xapri") (" peXe" . t) ("biliX") ("falX") ("diX " . t) ("siXi") ("speX") (" Xt") ("Xox") ("Xq") ("Xandar " . t) ("penXel" . t) ("kemenX" . t) ("I Xars" . t) ("eXemiz") ("Xinto") (" uXa ") ("Xariy") (" Xibo") (" Xiga") ("t Xi " . t) (" Xio") (" Xea") ("kaXc" . t) ("Xlav") ("Xepe" . t) ("Xkt") ("kX ") (" IX") ("Xyi" . t) (" oX") ("xX") ("ike Xan" . t) ("Xingir" . t) ("Xiliye") ("inalX") ("Xapon") ("leiXi" . t) (" Xaym") ("s Xop") ("Xivis" . t) ("Ximbi") (" CaXa" . t) (" sIrX" . t) ("inciX" . t) ("IrmaX") ("Xobr") ("pOrX" . t) ("nXko" . t) (" InX") ("Xelb") ("omiX") (" Xorun") (" aXina") ("n Xars" . t) (" Xory") ("Xocu ") ("anrIX" . t) ("metiX" . t) ("d inX") (" alXi" . t) (" Xink" . t) ("IlhaX" . t) ("aXev" . t) ("roXi" . t) ("lXio") ("abiX") ("Xamk" . t) ("CXi " . t) ("eXiv" . t) ("Xarn") ("I aXar" . t) (" Xene " . t) ("Xarey ") ("felXi") ("UteX " . t) ("ssiX") ("Xort") ("Xabb") ("niXo") (" anX") ("reXci" . t) ("maXik") (" uXuc" . t) ("Xince" . t) ("Xips") ("Xors") ("Xur " . t) ("tliX") ("mUX") ("Xohacopu" . t) (" Xarda" . t) (" aXini") ("SaXik ") ("Xayag") (" Xara") (" koXu" . t) ("Xaret") ("agiX") (" Xeo") ("yaXo" . t) ("Xalv") ("Xice" . t) ("SiX") ("noX") (" da Xabas") (" antiX " . t) (" Xuruml") ("Xitib") ("blanX") ("Xerva") ("bliX") ("CiXi") ("aaX") ("Xagalo") (" paXi") ("viXe ") (" aliX") ("peX ") ("Ximr") ("Xeho" . t) ("blaX") ("SmaX") ("oXi " . t) ("UtX" . t) ("Xakarta ") (" Xiliv") (" Xarli" . t) ("eXinde") ("UrgeX") (" Xot") ("Xitr") ("maXb") ("Xera") ("alaXat" . t) (" reXel" . t) ("Xabr") ("Xid ") ("Xoro") (" Xiler") (" parXa" . t) ("kalXa" . t) ("iXan") ("upaX") ("nXb" . t) ("wX") ("Xv") (" Xici") ("Xooo" . t) ("Xesm" . t) ("Xivile" . t) (" saXi " . t) ("siXe") ("paXk") ("fIrX" . t) ("jX") (" aXilarda" . t) ("ehiriX" . t) ("kIrXa") ("Xarg") ("aXle") ("enXk" . t) ("ruXa") ("isXi" . t) ("zOlX" . t) (" Xp") ("nXc" . t) ("Xkl") ("dX") ("karaXi " . t) (" Xildin") (" serXe" . t) ("Xolleg") ("Xomak" . t) (" aXal" . t) ("rusX" . t) ("aXib") ("emiX") ("lXo") ("Xyd" . t) (" Xy") (" burXa" . t) (" maXo" . t) ("Xuha" . t) ("ciX") ("roX") ("Xengel" . t) ("musiX ") ("Xanko") (" Xini" . t) ("suXuk") ("Xoli") (" aXiyl") ("gOXek") ("Xals ") ("Xubay" . t) ("rayiX" . t) ("manXo" . t) ("irkaX" . t) ("tehX") ("feX") ("foXa " . t) ("raXog") ("sXis" . t) ("buX " . t) ("kXem" . t) ("Xebi " . t) ("Xorr") ("Ximn") ("triX") (" Xurum ") (" Xildi ") ("salXa" . t) (" kaXi" . t) ("eliX") ("uXup" . t) ("fiX") ("koXan " . t) ("Xolum") ("Xonga" . t) ("Xavc") (" Xed") ("skaXi") (" ilX" . t) ("kiXi") ("Xef") ("ceX") ("IsaXi") (" Xeyi" . t) ("eXhiz" . t) ("sXe " . t) ("fIX" . t) ("yol aX" . t) ("Xelim" . t) ("Xenes" . t) ("Xipla" . t) ("Xath") ("nXoi" . t) ("koXas " . t) (" Xinle") ("Xapit") ("UleX " . t) ("IXd" . t) ("faX") ("zXeli" . t) (" luX") ("Xikli ") ("iXeri" . t) ("Xok" . t) ("Xolli") ("Xels") (" Xe ") ("eseX") ("naX") (" aXidi") ("Xorn") ("Xorp") (" Xayir ") ("Xalla") ("farsX" . t) ("iniX") ("Xehr" . t) (" eX") ("Xilarak" . t) ("tekelX") ("eXilik") ("Xarme") ("konXe" . t) (" Xis") ("nXm" . t) ("Xove") (" kamX" . t) ("Xirit") ("Xks") (" saXa" . t) ("Xilv") ("Xava") ("rUXh" . t) ("Xai") (" yolaX" . t) ("Xole") ("Xt ") ("caX") ("aXiya") ("bruX") (" kIX" . t) (" Xs") ("Xurcic" . t) ("CurX" . t) ("Xky ") ("Xiliz") ("Xanku") ("Xamli" . t) ("Xalt" . t) (" Xivi " . t) ("Xie") ("penXes" . t) (" ayX" . t) ("aXiyi") ("Xoca") ("koXak " . t) ("lXam" . t) (" Xul" . t) ("Xape") ("Xetv") ("aXli" . t) (" Xelil") ("gaXi") ("IoX") ("S aXi" . t) ("aXisi ") ("anXer" . t) ("rXil " . t) (" seXik" . t) ("piX") ("aXit") ("gX") (" paXa" . t) ("verX") ("rXin " . t) (" Xila") ("Xinge" . t) ("Xubu" . t) ("Xity") ("Xuyo" . t) ("IXe") ("koXar" . t) ("sXila" . t) ("marX") (" liX") ("eveX") (" Xarsi ") ("Xeviz") ("daXi") ("Xolo") ("Xopla") ("Xtio") ("Xs ") ("Xalif") ("akarX") ("deX") ("aXili ") ("Xola ") ("telX") ("ortaXag" . t) ("lIXak") ("Xizr") ("Xoa") ("aXam" . t) ("IlX") ("niX ") ("Xy ") ("baliX") ("riXe") (" Xari ") (" aXiz") ("n aXisini") ("Xart") ("CeXi") ("fX ") ("pX ") (" aXar ") (" Xevd") ("sXi " . t) ("beX") ("rXasina") ("Xoh") (" veX") ("elXe") ("uXat") (" uXa" . t) ("Xaro") ("aXile") (" Xere") (" biX" . t) (" iXi" . t) ("Xarr") ("luXa") ("alXil") ("olX") ("Xinsel") (" Xard") ("nXs" . t) ("fX" . t) ("Xord") ("baXi") ("inXer" . t) (" seXe" . t) ("vaXi") (" Xm") (" keX" . t) ("Xavi") (" Xeket") ("rXes") ("zliX") ("Xell") ("perinX" . t) ("Xembe" . t) (" eriX") ("ilaXi") ("bOX") (" UXe" . t) ("barX") ("Xuv" . t) ("Xilt") ("Xige") ("diX") ("uXur" . t) (" Xaydi") (" Xumr" . t) (" aXar" . t) ("eXete" . t) ("Xkh") ("Xate") ("Xevh") (" Xim ") ("GaXi") ("urtiX" . t) ("Xn") (" Xoo") ("urXa") ("GXi") ("iraX") ("OXa") ("gOX" . t) ("bilanX" . t) ("hX" . t) (" Xadir" . t) ("Xou") ("riXi") ("meXhu" . t) ("bX ") ("Xke") ("yeX") ("tXa " . t) ("Xinar" . t) ("aziX" . t) ("Xerr") (" Xarl") ("yX") (" Xamas" . t) ("eXenin ") ("eXem" . t) ("Xaf") ("IXal") ("eXebi" . t) ("harXa") (" reX") ("kXan") ("sIXr" . t) ("Xinl" . t) ("Xamur" . t) ("aXima") ("Xo ") ("ikaXi") ("aXabi" . t) (" Xesu") ("Xiro") ("nXt" . t) ("Xeh") ("Xanta" . t) ("aXilig") ("Xeyr" . t) ("meXi") ("jaX") ("Xto") ("Xogr") ("niXe") (" maXa " . t) (" gerX" . t) ("tXu" . t) (" merX") (" Xela") ("uXuk" . t) (" Xese") ("taXi") (" Xanak" . t) ("Xon") ("cX") ("Xah") ("Xc") (" uXus" . t) ("aXil ") ("zaX") ("Xuku" . t) ("leX") (" Xeb") ("parX" . t) ("kuXa") (" muX") ("Xuru" . t) ("aXilik") (" Xey") ("iXa") ("yaXi") (" Xesa") (" Xas") (" Xank" . t) ("elX" . t) ("buX") ("Xom") ("iXil") ("aXac" . t) (" X ") (" aXan" . t) ("pX" . t) (" iXi" . t) ("haX") ("Xih") ("Xia") ("sviX" . t) ("Xos") ("Xaz") ("eXik") ("eXec" . t) ("neX") ("Xiv") ("suX" . t) ("Xz") ("tX ") ("Xd") (" maXi" . t) (" Xin " . t) ("sX") ("UXe") ("zX") ("Xep") (" Xin") ("reXi") ("sIX") ("yiX") ("aXe") ("SX" . t) ("aXilar") (" Xeva") (" Xl") ("raXi") ("geXer" . t) (" OlX" . t) (" kaX" . t) ("ilXi") (" UXu" . t) (" Xen") ("vX") ("IXi") ("Xem") ("Xk ") ("rXe ") ("amaXi") (" Xid") ("tXi" . t) ("teX") ("Xam") ("rXi") ("Xunk" . t) ("Xr") ("nXl" . t) ("Xad") (" kUX" . t) ("kX" . t) ("mX") ("oXa") (" meX") ("eXen" . t) ("Xez") ("Xan") ("nX " . t) ("tiX") ("Xa ") ("Xh") ("Xi ") ("Xu") ("eXe") ("aXa") ("nX") ("X" . t) )
     (?g (" s iX" . t) (" oraX") ("loXi " . t) ("itelX" . t) ("zilXi" . t) ("r oXr") ("aroXu") ("teXes") ("Ig aX") ("zdIX ") ("i teX" . t) ("p leX" . t) ("b OXe") ("boruX") ("dayIX") ("moraX") ("saXik") ("h OXe") ("o taX") ("e eX ") ("h maX" . t) ("aediX") ("C veX" . t) ("padoX") ("r aXn") ("idiXu" . t) ("raXbi") ("Xaini" . t) ("diXis" . t) ("dedeX") ("remiX") (" tuXu") ("rbuXu") ("ihaXa" . t) ("reXle") ("imilX" . t) ("akbuX") ("Xayan") ("atsaX") ("y OXe") ("nuraX") ("seXis") ("eXeti" . t) (" IcoX") ("saXat" . t) ("tlukX" . t) ("z edX" . t) ("azbeX") ("ndaXa") ("gOrXe" . t) ("ereX " . t) ("Ge aX" . t) ("beliX" . t) ("coXal") ("aldiX") ("attiX") ("Xard ") ("aXall") ("niXir") ("viraX") ("istiX" . t) ("tanoX" . t) ("zaXra" . t) ("eolaX") ("guluX") (" toXr" . t) ("baXal" . t) (" e aX" . t) ("yeleX" . t) ("reneX" . t) ("maXal") ("Xarde") ("erlaX") (" asaX") ("ediXe") ("dIXil") ("boXan" . t) ("olleX") (" triX") (" blaX") ("t aXr" . t) (" eXen" . t) ("aireX") ("hi OX" . t) ("Xers ") (" raXi") ("iSeXe") ("az aX" . t) ("lu aX" . t) ("Xulas") ("s aX ") (" i OX" . t) ("eXen5" . t) (" aXar" . t) ("oXlar") (" liXd") ("0 doX" . t) ("n SaX") ("Xusal") (" etiX" . t) ("gereX" . t) ("ca aX" . t) ("k daX" . t) (" eroX" . t) ("ikliX" . t) ("aXisl" . t) ("Gi OX" . t) ("Xute ") ("Xelir") ("Xlene" . t) ("irliX" . t) ("Xerce") ("ifeX") ("maaX") (" SuX") ("OliX") ("cagX" . t) ("naXl") ("huXu") (" dXe" . t) ("esaX") ("neX " . t) (" iIX") ("ylUX") ("laXn") ("siXb" . t) ("IXit") ("caXr" . t) ("OzUX") ("Xasv") ("SUlX" . t) ("toX " . t) ("vedX") ("ltaX") ("naXs") ("dbaX") ("nouX" . t) ("imXa" . t) ("CilX" . t) (" dIX") ("teXd") ("gcaX") ("Xcag") ("taIX") ("rOXe") (" dXu" . t) ("oldX") ("ysaX" . t) ("ovaX") (" cXr" . t) ("C iX" . t) (" iXe") ("i sX" . t) ("oneX") ("kreX") ("yaXr") ("CamX" . t) ("bOXl") ("badX") ("flaX") ("lulX" . t) ("sraX") ("taXl") ("leXl") ("moX " . t) ("SIlX" . t) ("Xva " . t) ("lilX" . t) ("vaXa") ("IbuX") ("Xnac") ("eXn ") ("Xanf") ("ebuX") ("ioXa") ("nbuX") (" rIX") ("hCeX") ("zuXd") ("aXia") ("kriX") ("ofaX") ("hoXa") ("Xann") ("aXaf") ("Xges") ("bruX") ("Xlai") ("vkiX") ("uyuX") ("biXe") ("Xnie") ("utIX") ("duXa") ("seeX") ("aleX") ("laiX" . t) ("Xlaj") ("Xgoz" . t) ("taXu") (" IXa") ("mleX" . t) ("lbaX" . t) ("kXi " . t) ("kiXi" . t) ("braX") ("uXuk") (" riX") ("rtXu" . t) (" uXa") ("rleX" . t) ("lXla" . t) ("duXi" . t) ("Xamo") ("zaiX" . t) ("Xlac" . t) ("Xado") ("apoX" . t) ("zcaX" . t) ("rluX" . t) ("eyoX" . t) ("baXr" . t) ("Xel ") ("sliX" . t) ("zliX" . t) ("Xame") ("icaX") ("nliX" . t) (" veX") ("aXe ") ("mliX" . t) ("Xerf") ("alIX" . t) ("doXu" . t) ("tIXi" . t) ("oXf") ("fUX") ("wIX") ("klX" . t) ("fOX") ("uXz") ("rdX" . t) ("sXl" . t) ("Xdy") ("GGX" . t) ("ocX" . t) ("zlX" . t) ("uIX") ("Xrk" . t) ("Xfo") ("bIX") ("Xce" . t) ("iGX" . t) ("IiX" . t) ("prX" . t) ("uXy") (" cX") ("ucX" . t) ("Xea") ("Xp ") ("Xve" . t) ("aGX") ("Xak") ("Xei") ("weX") ("UXi") ("mXy" . t) ("Xml") ("rgX" . t) ("odX") ("Xsy") ("Xgy") ("zeX") ("heX") ("Xba" . t) ("UXa") ("yIX" . t) ("Xfl") ("Xap") ("gOX" . t) ("gaX") (" tX") ("Xt ") ("IoX" . t) ("Xav") ("euX") ("soX" . t) ("OXr" . t) ("0X" . t) ("wX") ("Xq") ("sX") ("nX") ("rX") ("lI diyaloXun ") ("mla diyaloX") ("  fotoXrafe") ("0 da fotoX") ("ik OXeler ") ("i OXeleri ") ("s elekdaX") ("k liXini " . t) ("ve yaXin") ("una aXit" . t) ("a bu OXe") ("g civaoX") ("toXrafik") ("r buXu " . t) ("ir doXm") ("d baXir") ("aik liX" . t) ("aXusta ") (" eleXe " . t) ("tiracaX") ("ikoloXl") ("ngeliX") ("lo aXa") ("Xdatia") ("ar moX") ("a OXes") (" 8 liX" . t) (" yaXil") (" y doX") ("r OXel") ("gorduX") ("restiX") ("IXaray") (" buXu ") ("beSeX") ("pfluX") ("Xdela") ("aXaz ") ("capaX") ("naXan") ("Xunus" . t) (" naXr" . t) ("iXre " . t) (" Xini" . t) ("C S X" . t) (" bliX") ("dIXan") ("t OXe") ("luXus") ("etlaX") ("kaXir") ("OndeX") ("sadiX") ("aptiX") ("laXil") ("Xasio") ("meXip") ("5 liX" . t) ("iXlik" . t) ("solaX") (" aXil" . t) ("t oXa" . t) ("nz aX") ("oXlas") (" leXi") ("Ir aX" . t) ("arliX") ("praX ") ("saXar") ("inaXa") ("7 liX" . t) ("sa aX" . t) ("en OX" . t) ("OrneX" . t) ("a daX" . t) ("osiX") ("ktaX") ("Xnig" . t) ("graX") ("niXb" . t) ("beaX") ("ndXu" . t) ("udXu" . t) ("smiX") ("yelX" . t) ("roXa") ("maXm") ("doXn" . t) ("cilX" . t) ("claX") (" faX") ("naXr") ("Xse " . t) (" uXl") ("Xach") ("sceX") ("noXa") ("Xuti") ("aXgu" . t) ("aiXe") ("eXla") ("Xzan") ("oXda") ("saXl" . t) ("Xlin") ("ioXr") ("raXu") ("eluX") ("eXra") (" toX") ("ldiX" . t) ("baXi" . t) ("ttiX" . t) ("Xelm") ("Xast") ("IaXi") ("lduX" . t) ("gIX") ("oGX" . t) ("oXb") (" gX" . t) ("mcX") ("juX") ("Xiv") ("Xga") ("nUX") ("eXg") ("Xno") ("sIX" . t) ("iXa") ("oXy") ("CoX" . t) ("Xto") ("pX") ("an OXeler ") ("li OXes") (" leXeni" . t) ("iliXis") (" maXas") (" uXula") ("oyacIX") ("Xrafyo" . t) ("kanIlX" . t) ("leXenl" . t) ("ye aXi" . t) ("Xrafk") ("Xmayp") ("straX") (" laXa") ("maXad") ("malaX") ("Xlise") ("baliX" . t) ("eXida") ("baXaz" . t) ("apliX") ("moXal" . t) ("taraX" . t) ("e taX") (" oXan") ("litoX") ("bu aX" . t) ("oXman") ("bsaX") (" pOX") ("bOXe") (" giX") (" IX ") ("liXm" . t) (" mIX") ("otaX" . t) ("kilX" . t) ("yeX " . t) ("rilX" . t) ("Xing") ("kruX") ("druX") (" zoX") ("OceX" . t) ("taXi" . t) ("Xanu" . t) ("driX") ("roXr") ("lOX") ("Xaw") ("IXe") ("Xf ") ("iXc" . t) ("atX") ("Xd ") ("wiX") ("feX" . t) ("hiX") ("eXa") ("bX") ("kX") (" X") ("Xalass") ("ileXe " . t) ("baXan " . t) ("unaXa") (" aXik") ("beXel") (" raXa") (" oriX") ("aXrot" . t) ("ediX " . t) (" diX " . t) ("maXda") ("kuruX") ("eoloX") ("soluX" . t) ("ir aX" . t) ("Xarli") ("anuX") ("deXu") ("oXle") ("eXm ") ("truX") ("bUXe") ("niaX") ("iXes") (" vaX") ("sIlX" . t) (" ziX") ("ktiX" . t) ("fraX") ("rlX" . t) ("ntX") ("Xmi" . t) ("eXo") ("Xy ") ("aXandan " . t) ("poXrafi") ("im beX" . t) ("meneX") (" tiXe") (" iXde" . t) ("mireX" . t) ("iXida") ("matoX") ("baXa " . t) (" a aX" . t) ("oXli") ("iXib") ("viX " . t) ("taXn") ("Xdeb") (" hoX") ("siXn") (" ruX") ("rUlX" . t) ("elaX") ("proX") ("Xlo") ("er OXe") ("boXus ") ("rdiX " . t) ("leXer") ("oXano" . t) (" muXa") ("liXn" . t) (" eX " . t) ("yoXa") ("Xrap") (" CaX" . t) ("waX") ("Xt ") ("subuX") (" maXi") ("cIlXi" . t) ("neXer") ("SeXe " . t) (" beXi") (" oXd") (" iXi") ("uXle") ("Xiad") ("opaX") ("Xb ") ("eiX") (" maXa ") ("Xinat") ("oXlan" . t) (" eXt" . t) ("Xask") ("luXg") ("paXu") ("coiX") ("uXar") ("afX") ("irbaX") ("oXart") ("moXa") ("ruXg") ("nlX" . t) ("Xgs") ("aXasi " . t) ("Xment") (" buXs") ("bUXu") (" paX") ("taiX") ("gzaX") ("draX") ("mX") ("lIXil") (" IXl") ("IXaz") (" biX") ("Xro") ("Xland ") ("aXun") ("aXuc") ("aXle") ("guX") ("Xai") ("Xui") ("leXen " . t) (" naXa") ("bliXd" . t) ("Xmati") (" IXn") ("maX ") ("oXi") (" briX") ("Xlia") ("OXet") ("luiX") ("efiX" . t) ("OpeX" . t) (" yiX" . t) ("Xmo") (" OXer ") ("oXmala") ("gulaX") ("koXr") ("Xass") ("Xas ") ("mUX") ("ieX") ("oXn") (" naXi") (" reX") (" zaX") ("Xue") ("uXi") ("m aX ") ("Xanis") ("maXn") ("Xdi" . t) ("seXe" . t) ("uXan") (" saXan ") ("aXil ") (" diXi") ("Xgi") ("taX ") ("goX") ("CX") ("Xie ") ("Xs ") ("Xah") ("SX") ("bliXl" . t) (" CaXa" . t) ("aXac" . t) ("iXf" . t) ("moXr") ("voX") ("oXre") ("toXa") ("gaX") ("Xat") ("doXr" . t) ("iXel") (" moXo" . t) ("iXil ") ("aXip ") ("Xua") ("iXem") ("Xay ") ("reXe " . t) ("oX ") ("Xide") ("yun eX" . t) (" aXit ") ("dar tuXla ") ("aXne") ("auX") ("oXa " . t) ("aXg") ("rkeX" . t) (" tUX") ("noXr") (" iXr" . t) (" saXo" . t) ("iyoX") ("gX") ("eaXa") ("ouX") ("eoXr") ("aXul") (" eXr" . t) ("Xic") ("neXe " . t) ("iXen") ("CeXe" . t) ("deX" . t) ("aXre") ("uXe") ("sleX" . t) ("aXra") ("Xano") ("oXe") ("bliX " . t) (" baXa") ("CiX" . t) ("aXazi") ("IXu") ("teXe" . t) ("yeXe" . t) (" vuX") ("meXe " . t) ("niXd" . t) ("eXm" . t) (" oXun") (" praX") ("Xio") ("eceX" . t) ("oXu" . t) ("aXe") ("oXlu" . t) ("Xanda") ("araX") ("uXay") ("Xne" . t) ("Xh") ("haX") ("beXe" . t) ("eXl" . t) ("Xo") ("loX") (" liX") ("zX") ("vX") ("IX" . t) ("yX") ("oXram") ("iXe" . t) ("eXer" . t) (" buXun") ("UX" . t) ("nX") ("rX") ("OX" . t) ("lX") ("oX" . t) ("uX" . t) ("aX" . t) (" X") ("Xi" . t) ("X") )
     (?i ("n kXsan") (" nin Xn") ("tIyor X") (" armanX") ("Xstirab" . t) ("aktXgim" . t) ("eci Xsi" . t) ("er de X") ("ere Xsi" . t) ("ne takX" . t) ("ratan X") ("Uyen Xn" . t) (" alanXs") ("sI sXr ") ("ivan mX" . t) ("iran Xn" . t) ("na katX" . t) ("ka katX" . t) ("fsIz lX" . t) ("ble X " . t) ("fbI lX" . t) ("Cal mX" . t) (" otanX") ("yevarX") ("c k nX") ("when X" . t) ("ortarX") ("an e X" . t) ("  mXnc" . t) ("le rXo" . t) ("und Xn" . t) ("zaks X" . t) ("lain X" . t) ("daS lX" . t) (" laklX") ("endarX") ("rsal X") ("nat sX" . t) ("tovanX") ("Iz mXy" . t) ("ilallX") ("yanC X" . t) ("solarX") ("scu sX") ("gi acX") ("glantX") ("inlarX") ("glarXz") ("ikmamX") ("asadXg") ("k acXs") ("l acXk") ("c sayX") ("6 yasX") ("asamX ") ("asamXs") ("stayXm") ("sXnanm" . t) ("r cXne" . t) ("in deX" . t) ("ears X") ("nanayX") (" farX " . t) ("az Xnk" . t) (" aSXya") ("k stXn" . t) ("re dX " . t) ("ayaldX") (" arXs ") ("r mXri" . t) ("mhk nX") ("Ul clX" . t) ("ssa kX" . t) ("itladX") ("islarX") (" sXniz") ("tXciyd") ("Im dXr" . t) ("yara X") ("ol Xn " . t) ("ru bX " . t) ("al Xni" . t) ("bI Xnt") ("nike X" . t) ("sisasX") ("rodalX") ("InC Xn" . t) ("kuk tX" . t) ("rI rXf" . t) ("Ip mX " . t) ("sXzinc" . t) ("am akX") ("fXtild" . t) ("ur anX" . t) ("ah mX " . t) ("n hXr ") ("kal lX" . t) ("  kXng" . t) ("I aczX" . t) ("t mXst" . t) ("mu Xnt" . t) (" day X") (" nasX ") ("ars sX") ("4 takX" . t) ("miranX") ("mir nX" . t) ("an cX " . t) ("fayI X" . t) ("ayrXni" . t) ("  Xnfo" . t) ("cu Xl " . t) (" alXmd") ("partlX") ("non bX" . t) ("k pXli" . t) ("ISI lX" . t) ("trt lX") ("zans X" . t) ("oru tX") ("a asXa" . t) ("iGe Xs" . t) (" u adX") ("tman X") ("alXmid") ("morasX") ("rXlin ") ("rter X" . t) (" taS X" . t) ("gIt gX" . t) ("zal sX" . t) ("nI mXz" . t) (" I alX") ("gast X" . t) ("pper X" . t) ("UlmalX") ("inaldX") ("Uk Xnt" . t) ("ra fXs" . t) ("ften X" . t) ("ot Xsi" . t) (" Xsinc" . t) ("an Xmi" . t) ("side X" . t) ("zlU Xs" . t) ("el asX") ("i akXb") ("bIk mX" . t) ("nne sX") ("yder X" . t) ("imsalX") (" gandX") ("r lXkt" . t) ("st zXn" . t) ("amXss" . t) ("slamXs") ("virXl " . t) ("ar dX " . t) ("si rXf") ("rke X " . t) ("sXzliy" . t) (" cazX " . t) ("urantX" . t) ("Cta tX") ("sarfX " . t) ("ark X " . t) ("urlerX" . t) ("e falX") ("  dXsn" . t) (" may X") ("ni joX" . t) ("in Xso" . t) ("umentX" . t) ("CuvalX" . t) ("a Xce " . t) ("etallX") ("marXyi") ("ve fXf") ("rhallX" . t) ("Gi anX" . t) (" hatXm") ("sXnana" . t) ("ght X " . t) (" ceksX" . t) ("halabX") ("an cXv") ("ne Xmi" . t) ("dden X" . t) ("nap nX" . t) ("Xrayim" . t) ("ncam X" . t) ("saattX") ("n u sX") ("krem X" . t) ("rake X" . t) ("agI sX") ("gi sXz" . t) ("ns e X" . t) ("z tamX") ("rane X" . t) ("miS tX") ("dent X" . t) ("n pXrv" . t) ("tasXya") ("sinasX") ("lu asX") ("eans X") ("vaS mX" . t) ("justXn" . t) ("iryakX") ("nba nX") ("ay mXy" . t) ("eday X") ("dame X" . t) ("Ir tXp" . t) (" dandX") ("sUratX") ("Xsilip" . t) ("eraatX") (" fazX ") ("elallX") ("htarXk") ("tIn tX" . t) ("ras nX" . t) ("kIr kX") ("ast mX" . t) ("h lXdi" . t) ("habatX") ("a yXm " . t) ("Si kXr") ("sXllik") ("tehabX" . t) ("Xsinir" . t) ("mmer X" . t) ("sinanX") ("aC mX " . t) ("ksXyor" . t) ("e cXne" . t) (" mayX ") ("O parX") ("istamX") ("n Xnki" . t) ("or Xnk" . t) ("tahrX " . t) ("Xnirse") ("icanX ") ("ark mX" . t) ("s aslX") ("hire X" . t) ("al nXn" . t) ("entarX") ("iyov X" . t) ("ova Xn" . t) ("wn dX " . t) ("hhatsX") ("ha Xli" . t) ("Ca adX") ("lUz tX" . t) ("inyanX") ("garatX") ("zce Xn" . t) ("kite X" . t) ("2 hafX") ("zca dX") ("evallX") ("tan aX") ("hak kX" . t) ("markXm") ("a cXne" . t) ("ep tXr") ("ikat X") ("et asX") ("ersanX") ("b I kX") ("nda X " . t) ("ek CXg") ("kIr fX" . t) ("ehatXn") ("UlmasX") ("at tXp" . t) ("Xspana" . t) ("raz dX") ("e CXli" . t) ("lu ayX") ("unarX ") ("lplarX") ("rI tXp" . t) ("Ik mXy" . t) ("i astX") ("efrayX") (" tadXl") ("alI yX" . t) ("lI anX" . t) ("kers X") ("ce anX" . t) (" opalX") ("elds X") ("Xmpexb" . t) ("taktXm" . t) ("GI Xsr") ("bahatX") ("tar Xi") ("takXs ") ("i 8 kX") ("itarXs") ("n Xvan" . t) ("rksXz " . t) ("du sXn") ("eim Xn" . t) ("ap sXz" . t) ("garXn " . t) ("sen mX") ("e patX") ("hatXn ") ("GI anX" . t) ("Xlinik") ("b adlX") ("nar Xn" . t) ("sra sX") ("kXral " . t) ("ika lX") ("za anX" . t) ("tUn dX") ("tCXsiy") ("mli tX" . t) ("mak tX" . t) ("tiyarX") (" alXya") ("de agX" . t) ("rda Xn") ("lk kXz") ("IkantX" . t) ("h sXz " . t) ("jinalX") (" ki CX") ("Si akX") ("ak asX" . t) ("ubranX") (" ne tX") ("ki sXr" . t) ("  aStX") ("afXni " . t) ("Xsiliy" . t) ("alk mX" . t) ("zde dX") ("Xriste") ("arsa X") ("arIm X") ("Gar Xn" . t) ("C malX" . t) ("dere X") ("0 bayX") ("yuz yX") ("n dXsl" . t) ("k artX" . t) ("zun Xs" . t) ("iladX ") ("beralX") ("zi Xsi" . t) ("min Xn") ("enal X") ("havarX") ("ntartX") ("sakXnl") ("apardX" . t) ("klasXk") ("aens X" . t) ("eve X") ("ve Xn " . t) ("aten X") ("gat Xn" . t) ("ri tXp" . t) ("z katX" . t) ("SeranX") ("osmanX") ("talXma") ("l basX" . t) ("in dXr") ("falsXz" . t) ("la anX" . t) ("rat tX" . t) ("U takX" . t) ("dIk dX") ("Ip Xn " . t) ("Xninda" . t) ("zanovX" . t) (" yattX" . t) ("az kXl" . t) ("kanadX" . t) ("zalp X") ("gUn Xn") ("alXnda" . t) (" danX ") ("kesi X") ("otansX") ("larXna" . t) ("l da X") ("zel tX") ("l tXp " . t) (" ardXn" . t) (" olabX") ("okrasX") ("ler Xn") (" Xndir") ("nasrX") ("lakXr" . t) ("Xkkim") ("chapX") (" If X" . t) ("ims X") ("Xrkpa") ("er Xg" . t) ("ddahX" . t) ("i Xso" . t) ("sassX" . t) ("urtXd" . t) ("lXmis" . t) ("ach X" . t) (" Xnke" . t) ("a CX " . t) ("baf X" . t) ("eig X" . t) (" asXd") (" fXr " . t) ("mIs X" . t) ("liyXl" . t) ("sralX") ("slatX") ("lasXr") ("ogalX") ("imacX") ("payrX" . t) ("amm X" . t) ("  sX " . t) ("Xsrae" . t) ("klazX") ("atf X" . t) (" Xstr" . t) ("rammX") (" Xsto" . t) ("sXvan" . t) ("gayXr") ("wh nX" . t) ("hk yX") ("saskX") ("eu nX") ("natXg") ("w fbX") ("Xmano" . t) ("CXtas" . t) (" nXm " . t) ("acs X" . t) ("ih nX" . t) ("lfasX") ("lk X " . t) ("sXzis" . t) (" Xtar" . t) ("rhIrX") ("tInXk") ("I tXn") ("nharX") ("Xminy") ("dm lX" . t) ("ys X " . t) ("nty X" . t) ("ai tX" . t) ("rSadX") ("dXgma") ("rty X" . t) ("canXp") ("t Xro" . t) ("vhamX" . t) ("idalX") ("I fXf") ("dXraj" . t) ("cebXt" . t) ("nahXr" . t) ("uff X" . t) ("bIs X" . t) ("40 nX" . t) ("daSdX" . t) ("damsX" . t) (" Xrib" . t) ("ndt X" . t) ("ilavX" . t) ("ecalX") (" Xllo" . t) ("I vXp" . t) ("l dX " . t) ("Xrati" . t) ("a c X" . t) ("h ayX") ("akslX" . t) ("S Xm " . t) ("tarXt" . t) ("II sX") ("bst X" . t) ("ogarX" . t) ("nalmX") ("c mX " . t) ("kXvi ") ("d sXz" . t) ("dXmim" . t) (" arXo" . t) ("dasXl") ("msahX" . t) ("n lXy" . t) ("SamdX" . t) (" SasX") ("6 dXr" . t) ("pe fX" . t) (" fXtt" . t) ("a Xgl" . t) ("Xyars") ("rfatX") (" mXkl" . t) ("isatX") ("esamX") (" nXku" . t) ("zangX" . t) ("unasX") ("canXd") ("h mXt" . t) ("hs mX" . t) ("azatX") ("nXsiz") (" naSX") ("CaprX" . t) ("rXmad" . t) ("fhamX" . t) (" mXci" . t) ("UpabX" . t) ("ccarX" . t) ("k Xmi") (" epX " . t) ("0 ydX" . t) ("ack X" . t) ("aco X" . t) ("ib nX" . t) ("Xrizi") ("phy X" . t) ("bakrX" . t) ("ie tX" . t) ("U fXa" . t) ("ic Xc" . t) (" IrXs") ("ie Xr" . t) ("th Xc" . t) (" dXc " . t) ("S Xnk" . t) ("GartX" . t) ("ss kX" . t) ("CXtam" . t) ("i igX" . t) ("uus X" . t) ("icatX") ("antCX" . t) ("is tX") (" fXka" . t) ("unk X" . t) ("he X " . t) (" Xndy" . t) ("dangX" . t) ("badX ") ("m cXz" . t) ("ony X" . t) (" Xss " . t) ("I Xni" . t) ("  hXh" . t) ("usIkX") ("n tasX" . t) (" tasX") ("a zXm") ("i fXf") (" avXn" . t) (" adXa" . t) ("Xvarl" . t) ("itadX") ("lhadX") ("arXer" . t) (" lXym" . t) ("yahXm" . t) (" ag X" . t) ("hXzma" . t) ("lannX" . t) ("hasXp") ("6 ydX" . t) (" vXz " . t) ("CXtla" . t) ("IC mX" . t) ("t yXd" . t) ("pXlis" . t) ("th tX") ("aafXm" . t) ("hparX") ("cazXn" . t) ("lXnok" . t) ("CXtak" . t) ("IkatX" . t) ("Xsilk" . t) ("baksX" . t) ("UganX") ("  vXp" . t) ("CakSX" . t) ("C tXn" . t) ("adXlm" . t) ("halXk" . t) ("ein X" . t) ("y rXf") ("gallX") ("hi tX" . t) ("us kX") ("nXsab" . t) ("safXz" . t) ("rtXma" . t) ("fadX ") ("bXkir") ("iaf X" . t) ("Xncio") ("y CXt" . t) ("ryanX") ("Xrilo") ("uvafX" . t) ("f anX" . t) ("Sk Xn" . t) ("IC Xn" . t) ("rmXn ") ("oy nX" . t) ("rkXs ") (" nanX") ("r ahX" . t) ("  mbX" . t) ("h yX " . t) ("mazXm") ("cIlkX" . t) (" k rX" . t) ("igarX" . t) ("eyamX") ("utafX" . t) ("Xmper" . t) ("granX") ("ealdX") ("t lX " . t) ("tXnaz" . t) ("SahX " . t) ("2 asX") ("Xlivi" . t) ("kulXk" . t) ("a dXm" . t) ("bazXd") ("tacXm" . t) ("d Xll" . t) ("rdXnl") ("lamdX" . t) ("haldX") ("um fX") ("fcanX") ("abXk " . t) ("rz Xn" . t) ("e Xzg" . t) ("rnXzl") ("ad lX" . t) ("urakX" . t) ("htacX" . t) ("tip X") ("aIn X") (" Xlid" . t) ("yantX" . t) ("d Xnc" . t) ("saysX" . t) ("ap tX" . t) ("ku X " . t) (" SafX") ("C anX" . t) ("taatX") ("SahlX" . t) ("ke fX" . t) ("aph X" . t) ("85 kX") ("kc nX" . t) ("CXlav") ("uzXr " . t) ("Xsida" . t) (" Xsis" . t) ("tXlic" . t) ("u nXn" . t) ("hazmX" . t) ("stCX " . t) ("vrakX" . t) ("nS X " . t) ("stIkX") ("ocamX" . t) ("asmXn") ("uay X") (" Xsic" . t) ("94 dX" . t) ("Xvasl" . t) ("Xragi" . t) ("dalsX" . t) ("sakXl") ("naazX") ("raasX") ("r Xii") ("or Xi") ("hassX" . t) ("Is Xs") (" acXr" . t) ("v dXn" . t) ("si Xv" . t) (" SXkl" . t) ("ele X") ("dk sX" . t) ("nI lX") ("I lX " . t) ("hardX") ("ead X") ("Xllio" . t) (" tosX" . t) ("Xray ") ("lXnay") ("I ahX" . t) ("ibXl " . t) ("g h X" . t) ("CtakX") ("bXtas" . t) (" 6 lX" . t) ("tikXl" . t) ("sekXn" . t) (" Xcar" . t) ("tu tX" . t) ("e Xt " . t) ("Ik rX") ("s tXp" . t) ("usk X" . t) ("d asX") ("serbX" . t) ("n jXn" . t) ("masrX") ("aadXg" . t) (" Xnt " . t) ("Xtari") ("acIbX") ("UlayX") ("rstX " . t) ("r zXv" . t) (" nafX") ("afalX" . t) ("mazmX" . t) ("arlXd" . t) (" kXsl" . t) ("kXtan" . t) ("Xtma " . t) ("allXt") ("Xspon") ("tl sX" . t) ("oparX" . t) ("kXrti" . t) ("tchkX" . t) ("gXyim") ("mon X" . t) ("p anX" . t) ("lasXn" . t) ("tardX" . t) ("akXz " . t) (" gs X" . t) ("Xbler") ("garSX") ("ramdX" . t) ("var X") ("r hXy") ("etamX") ("Il X " . t) ("nalXk" . t) ("Xnine") ("ng Xt" . t) ("ory X" . t) ("a Xsa") ("nsarX") ("S atX" . t) ("rz X " . t) ("nrakX") ("Xtmas" . t) ("alkXs" . t) ("yI Xn") ("bim X") ("Xrla " . t) ("kXnde") ("vallX" . t) ("rXsik" . t) ("ktXla" . t) (" avX " . t) ("kXyam" . t) ("ma Xn") ("nla X") ("s sXl") ("samXm") ("lp Xn" . t) ("ttakX") ("nazXl") (" CXna" . t) ("acXni" . t) ("un Xn") ("rescX" . t) ("lahtX") ("lkXng") ("yku X" . t) ("ues X" . t) (" rasX") ("Xkla " . t) ("sXnli") ("Xmall") ("Xrtak") ("rattX" . t) ("sastX" . t) ("tlarX" . t) ("stakX") ("arXm " . t) ("lattX" . t) ("tIrdX" . t) (" fatX") ("aldXk" . t) ("rkasX" . t) ("yrXmi" . t) ("i Xns") ("Xtart" . t) ("Xktan" . t) ("yXlma" . t) ("ln X" . t) ("kkXo" . t) ("kXsr" . t) ("w X " . t) ("nIkX") (" bsX" . t) ("IytX" . t) ("Xdg " . t) ("cXls") (" Xnv" . t) ("fXgl" . t) ("vajX") ("IomX" . t) ("uzyX") ("Xcef" . t) ("Xonc" . t) ("oabX" . t) ("Xngv" . t) ("idlX") (" Xol" . t) (" SyX") ("nr X" . t) ("lunX" . t) ("mXg " . t) ("iGXi" . t) (" Xrn") ("cXss" . t) ("IdaX" . t) (" npX" . t) ("gp X" . t) ("rzdX" . t) ("hXzd" . t) ("rsXf" . t) ("yflX" . t) ("ngXt" . t) (" Xrs") ("fXch") ("rrrX" . t) ("yavX" . t) ("ryXm" . t) (" Xmc" . t) ("adXc") ("kXlk" . t) ("yXta") ("mXhi" . t) ("gXbt" . t) ("Xspu") (" Xyd" . t) ("uStX" . t) ("Xyig" . t) ("kl X" . t) ("kXpa" . t) ("tXnn" . t) ("epmX") ("ipmX") ("Xdoo") ("Xgam" . t) ("avmX" . t) ("kXlt" . t) ("Xmmu" . t) ("Xmia" . t) ("rSmX" . t) ("Xgab" . t) ("yXgs" . t) (" lmX" . t) (" zmX" . t) (" tmX" . t) ("nCXl") ("IteX" . t) ("rseX" . t) ("ozlX" . t) ("ysrX" . t) ("SktX" . t) ("hs X" . t) ("ibaX" . t) ("IsrX" . t) ("llXu" . t) ("jalX") ("ytXm" . t) ("mXzr" . t) ("Id X" . t) ("IsaX" . t) ("rSlX" . t) ("Xkut") ("lmCX" . t) ("ySrX" . t) ("ytXk" . t) ("htsX" . t) ("InCX" . t) ("cXag" . t) (" zX " . t) ("yfXf" . t) (" Xga" . t) ("Xle") ("wn X" . t) ("cXlg" . t) ("tXy ") ("rngX" . t) ("ckCX" . t) ("IGnX" . t) ("fXtr" . t) ("aXrc" . t) (" Xfm" . t) ("ahaX" . t) ("Xcbm" . t) ("Xvoj") ("anXf") ("hXzv" . t) ("rhaX" . t) ("aySX" . t) ("cXzz" . t) ("IGmX" . t) ("Xyav") ("nXny") ("asXv") (" Xaf" . t) ("IrvX" . t) (" Xrv" . t) (" hnX" . t) ("sXsy" . t) ("sr X" . t) ("yIhX") ("srXl") (" kXk" . t) ("GunX" . t) ("cXlk" . t) ("watX") ("bXc ") ("lXvi") ("xarX") ("Gr X" . t) ("pXtr" . t) ("ndoX" . t) ("ctXr" . t) ("Xnch") ("anCX" . t) ("SndX" . t) ("myoX" . t) ("rzCX" . t) ("iIGX") ("aCcX" . t) ("GahX" . t) ("aSrX" . t) ("zafX") ("dzaX" . t) ("jakX") ("zXlg" . t) (" lXp") (" vXi" . t) ("ktlX" . t) ("stdX") ("nSXr") ("nrXl" . t) ("mmXs" . t) ("SXps") ("Xdio") ("IzkX" . t) ("rXzk" . t) ("ynXk") ("sfX " . t) ("yCX " . t) ("llXm") ("aCCX" . t) ("Xyop") ("dIkX") ("isCX") ("sXku") ("IhlX" . t) ("Xppo") ("kXvo") ("fXba" . t) ("cXlo") ("yeCX" . t) ("eatX") ("Xgd " . t) ("Xbal") ("yXgm" . t) ("rIzX") ("Xpaz") (" yaX" . t) ("InoX" . t) ("tlmX" . t) ("olkX" . t) ("CmXn") (" aXp" . t) ("kXca" . t) ("tlXn") ("eIGX") ("nXar" . t) ("fSaX" . t) ("nclX" . t) ("cXga" . t) ("Xrij") ("d cX" . t) ("Xrst") (" Xh " . t) (" Xsu" . t) ("cXbi" . t) ("Xros") ("s Xh" . t) ("zXmn" . t) (" Xvi" . t) ("klXe" . t) ("G CX") ("we X" . t) ("ftXg") ("gXlg" . t) ("aGmX" . t) ("cXs ") ("Xkem") ("nXdo" . t) ("Xper") ("lkXb") ("shXg" . t) ("SXrg" . t) (" nXd") ("Xad ") ("Xpik") ("jXye") ("ncXc") ("mXkn" . t) (" abX") ("rXc ") ("mXnk") ("sXng") ("ts X") ("Xpek") ("lXll") (" Xlc") ("zXme") ("gXct" . t) ("cXld") ("nXka") ("Xch ") ("ecXc" . t) (" mXm") ("bXti") ("nXko") ("Xstl") ("zylX" . t) ("Xset") ("r Xo" . t) ("fXbr" . t) (" stX") ("ttXs") ("lXan") ("Xyaz") ("lImX" . t) ("Xst ") (" Xzl") ("Xzde") ("Xkit") ("Xkel") ("ldXz" . t) ("tXca") ("intX") ("engX") ("IzXl" . t) ("eskX") ("CatX" . t) ("o cX") ("surX") ("aynX" . t) ("Xdde") ("yXll" . t) (" lXr") (" Xbr") ("Xagi" . t) ("nlXs" . t) ("Xfak") ("kaCX" . t) ("yarX" . t) ("sXc ") ("Xkri") ("cgX" . t) (" uX" . t) ("GIX") ("CdX" . t) ("pnX" . t) ("Xsf") ("Xih") ("fmX" . t) ("Xlz") ("Xae" . t) ("jjX" . t) ("Xom" . t) ("jXv") ("kGX" . t) ("cXf") ("pcX" . t) ("Xho") ("fcX" . t) ("dSX" . t) ("SyX" . t) ("uGX" . t) ("Xbc" . t) ("jmX" . t) ("Xdc" . t) ("pfX" . t) ("Xzo") ("cXw" . t) ("kXi") ("egX") ("cvX" . t) ("Xmu") ("Xdr") ("cXp") ("Xzn") ("Xyy") ("SXf") ("zXb") ("guX") ("iXl") ("idX") ("Xze") ("IkX" . t) ("edX") ("ekX") ("iSX") (" Xc") ("2X" . t) ("slarIn yanX ") ("ve vicdanX ") ("letin malX " . t) ("ok hayatX ") ("den sXnirl") ("de insanX ") ("da hayatX ") ("ak hayatX ") ("Xnformatio" . t) ("an insanX ") (" inin yanX") ("kInda adlX") ("i sOmestrX" . t) ("lecek yanX" . t) ("nacak yanX" . t) ("senin malX" . t) ("gini artX") ("re ahlakX" . t) ("an moralX" . t) ("Cin yanX ") ("Il hayatX") ("er ahlakX" . t) ("sin yanX ") ("ban taktX" . t) ("ni sXnir ") ("ri sXnir ") ("si Xntern" . t) ("ve insanX") ("In firarX" . t) ("gar washX" . t) ("ukada nX") ("Xsrafin " . t) ("ordan kX") ("In kIsmX") ("in kastX") ("ise Xsin" . t) ("U Xntern" . t) ("se martX") ("ili Xsin" . t) ("r mimarX") ("ya malX " . t) ("mli yanX" . t) ("niz sakX" . t) ("rek adlX") (" alXmin ") ("na taktX" . t) ("unu adlX") ("i sakXn " . t) ("neden dX") ("ksek Xsi" . t) ("nIn adlX") ("itesi tX" . t) ("tak yanX" . t) (" In adlX") ("I ve Xnt" . t) ("men gazX" . t) ("hal malX" . t) ("zel yanX" . t) ("detli kX" . t) ("Xsitilme") ("after X" . t) ("basladX") ("am dXr " . t) ("ren Xnt" . t) ("ark Xn " . t) ("aktXrdi" . t) ("p camX " . t) (" Xlgin " . t) ("gemi dX") ("ter dX " . t) ("se sakX" . t) ("binalX ") ("Xversia" . t) ("tihbarX") ("sIz mXs" . t) ("CXnliyo" . t) ("ormandX") (" artXn ") ("din alX") ("Uk alXm") (" rahatX" . t) (" cumalX") ("dI sakX" . t) ("si kXt " . t) ("te Xnte" . t) ("adikalX") ("nin fXs" . t) ("dXsimi ") (" kXlli " . t) ("stner X" . t) ("uness X" . t) (" Xnter " . t) ("a dXsli") ("r dXsli") ("  dXsi ") ("aksXniz" . t) ("teryalX") ("dXsiyle") ("ne katX" . t) ("sanlXt") (" ast X" . t) ("camlXk") ("askanX") ("ilmasX") ("iklarX") (" karsX") ("rlanX ") ("eSkalX") ("ikadX ") ("dU ayX") ("Xrtill" . t) ("ans mX" . t) ("re Xnt" . t) ("baldX ") ("r fXs " . t) ("at mXs" . t) ("Xnayac" . t) ("maatsX") ("a lXk " . t) ("eftalX") ("Xrmanl") ("cadXll") ("or Xn " . t) ("asalsX" . t) (" arXti" . t) ("eles X" . t) ("kahXr " . t) ("vuz fX") ("sea nX") ("daG dX" . t) ("atXlid") ("imallX") ("ak tX " . t) ("dya mX" . t) ("dakatX") ("epal X") ("rhatlX" . t) ("hamasX") ("rI CXg") ("martX " . t) ("asch X" . t) ("si hXd" . t) ("as lX " . t) ("lganX ") ("play X") ("taktXn" . t) ("ay dX " . t) ("Ca sXn") ("prkacX") ("alamXz") ("ylanX ") (" aC mX" . t) (" sabX ") (" set X" . t) ("sarXn ") (" SarX ") ("n mXyd" . t) ("mbanX ") (" dalXd") ("uranX ") (" zatX ") ("a mXzi" . t) ("ak Xnt") ("Xmages" . t) (" nakXs" . t) ("Xsisi ") ("diyadX") ("I Xnte" . t) ("t tXr ") ("ille X") ("ismanX") ("of Xsl" . t) ("tXlin ") (" varX ") ("camXna" . t) ("e calX") ("ar lX " . t) ("kralcX" . t) ("ar mXd" . t) (" kamX ") ("alXya " . t) ("Xsabel" . t) (" platX") (" garX " . t) (" Xnkin" . t) ("arabX ") (" rakX " . t) ("  dXsl") ("bXckin" . t) ("rtre X" . t) ("azXni " . t) ("r Xni " . t) ("In sXl") ("erganX") ("ikal X") ("Iz Xn " . t) ("en Xnt") ("arabXn" . t) ("Xsinde") ("nvarX") ("tahXl" . t) ("zalcX" . t) ("ralXo" . t) (" sasX") ("UnafX" . t) ("g Xnt" . t) ("o nXn" . t) ("menkX" . t) ("60 nX" . t) ("Xvila" . t) ("Xhlam" . t) ("krazX") (" Xnaf" . t) ("larkX") ("ItkX " . t) ("m Xss" . t) ("Xmil " . t) ("edayX") ("rb X " . t) ("fXtig" . t) ("aS tX" . t) ("salcX" . t) ("cXlal") ("lI Xg" . t) ("icalX") ("Xfki " . t) ("drXa " . t) ("zaa X" . t) ("kXrad") ("nd X " . t) ("iSarX") ("Xzint" . t) ("Iz X " . t) ("oi nX" . t) ("ozayX") ("k Xso" . t) ("erptX") ("ck CX" . t) ("yvalX" . t) ("cXmbi" . t) ("fasXt") ("hhatX") ("zIkkX") ("balXr") ("zXlka" . t) ("Xnise") ("h kXl" . t) ("a cX " . t) ("sualX") ("SisXr" . t) ("bayXs") ("cXla ") ("saytX" . t) ("asbXh" . t) ("ac X " . t) (" zXri" . t) ("adXga") ("Xslav") (" gIlX") (" gXli" . t) ("fkatX") ("k lXy" . t) ("dXski" . t) ("a nXz" . t) ("gUnXs" . t) ("I Xme" . t) ("dXsit") ("Is lX" . t) ("thamX" . t) (" cXng" . t) ("galdX") ("shabX" . t) (" Xna " . t) ("brIsX") ("kaatX") ("bbXni" . t) ("Xndia" . t) ("keltX" . t) ("caalX") ("kahrX" . t) ("sXviy" . t) ("falcX" . t) ("I rXf") ("cardX") (" ramX") ("kXyos") ("fiG X") ("mp Xn" . t) ("Xvank" . t) ("gXdim" . t) ("Xrcal" . t) ("atXls" . t) (" Xdor" . t) ("vaklX" . t) ("CXnga" . t) ("CakcX" . t) ("h sXn" . t) ("aC X " . t) (" nXza") ("kXsip" . t) (" al X") ("Xbetl") ("Xnson") (" laCX") ("fXsir" . t) ("azXnd" . t) ("saksX" . t) ("kahlX" . t) ("t Xmi" . t) ("tch X" . t) ("kabX " . t) ("Xcki ") ("ndXs ") ("fahlX" . t) ("zXvan" . t) ("IC X " . t) ("Xpta " . t) ("kXsik" . t) ("fXtik" . t) ("kXrla" . t) ("Xrpik") ("IS X " . t) ("dattX" . t) ("Xsila" . t) ("lazgX") ("kbalX") ("klalX") ("labX " . t) ("ipatX") ("irasX" . t) ("k avX" . t) ("akanX" . t) ("Xnar " . t) ("InalX" . t) ("dIrdX" . t) ("allXs") ("asXna" . t) ("eratX") ("karlX" . t) ("rklX " . t) ("rtCX" . t) ("Xsbc" . t) ("rXg ") ("amaX" . t) ("kdXs" . t) ("ilGX") (" aXm" . t) ("mXsr" . t) ("msXe" . t) ("Xnaj") (" Xf " . t) (" 0 X" . t) ("Xstt") ("rktX" . t) (" pXh" . t) ("hsXm" . t) ("sXft") ("InnX" . t) ("j X " . t) ("mr X" . t) (" zXd" . t) ("akXd") ("v Xv" . t) ("zXrt" . t) ("nXsk") ("xanX") ("apSX" . t) ("tGX " . t) ("ICtX" . t) ("l Xv" . t) ("uadX") ("acXr") ("pXro") ("sXpr" . t) ("dXi ") ("5 tX") ("d Xs") ("rnX " . t) ("tXg " . t) ("dabX" . t) ("Xsch") ("0 Xs") ("rx X" . t) ("nXnn") ("spX " . t) ("lXki") ("ipCX") ("0 Xl") ("tXkk") ("Xmat") ("rXbi") (" zXp" . t) ("brXk") ("Xpak") ("gXla" . t) ("papX") ("IrtX" . t) ("plXn") ("iddX") ("Xns ") ("Xgit") ("rXa ") ("Xnce") ("layX" . t) (" Xzl") ("kdXr") ("IsXy" . t) ("amrX" . t) ("alXg" . t) ("Xyle") ("rXll") ("faSX") ("Xyet") (" Xmz") ("Xtat") (" Xki") ("Xkte") ("Xbg" . t) ("hcX" . t) (" Xq" . t) ("vvX" . t) ("GtX" . t) ("iXg" . t) ("tXj") ("IXc") ("Xkv") ("CrX" . t) ("jXt") ("Xol") ("Xd ") ("Xdz") ("eyX") ("aGX" . t) ("etX") ("irX") ("Xw") (" alan arkX") ("e mUtevazX") ("san hayatX" . t) ("an hayatX ") ("Sbakan lX") ("u hayatX ") ("el insanX") ("arker Xn" . t) ("r SakXr " . t) ("un aslX ") ("apital X") (" ve adlX") ("u SahsX " . t) (" dXstan " . t) ("ter katX") ("in aslX ") ("e kIsmX ") ("tralXnin") ("In sabrX" . t) ("an Xsin " . t) ("yasamXn") ("sakXni ") ("Xstirap" . t) ("kXstin ") ("di hacX") ("akikatX") ("a mXsin" . t) ("i aslX ") ("rice Xn" . t) ("az dXr " . t) ("a ayXni") (" bayXni") (" Xsiniy" . t) ("n mXsin" . t) ("ek tXr ") ("varXsi ") ("irladX") ("tylamX") ("c parX" . t) ("ap mX " . t) (" azXm ") ("n Xlia" . t) (" bay X") ("gray X") ("batXst") ("ivaldX") ("orallX") (" alXca") ("ytanX ") ("Xsitma" . t) (" kXlip" . t) ("rner X" . t) ("hael X" . t) ("taktX " . t) ("ant Xn" . t) ("n asrX") ("art mX" . t) ("ruhanX") ("elvarX") ("i sXr ") ("somalX") ("anklXk" . t) ("senarX") ("fkatlX") (" arSXn" . t) (" attXn" . t) ("stXnde") (" takXs" . t) ("ikmalX") ("ir anX" . t) ("etrafX" . t) (" Xlik " . t) (" natXk" . t) ("inalXn") ("af mX " . t) ("yalXst") ("dallX ") ("coachX" . t) (" hazXn") ("rangX" . t) (" cXc " . t) ("kXtas" . t) ("trahX" . t) (" kXlc" . t) (" Xndo" . t) ("att X" . t) ("CXngi" . t) ("val X") ("aj mX" . t) ("way X") ("anstX" . t) ("Xslat" . t) ("Xsita" . t) ("takXr" . t) ("namX ") ("ds Xn" . t) ("antlX" . t) ("sXvis" . t) ("zdarX") ("I ymX" . t) ("laldX") ("uk X " . t) ("yahXn" . t) ("Xkac ") (" SXki" . t) ("ihabX" . t) ("IbbXn" . t) ("ndXl ") (" Xone" . t) ("ktXra" . t) ("IlttX" . t) ("gXdik" . t) ("IsXsi" . t) ("Xnas ") ("ac Xn" . t) ("ass X" . t) (" matX") ("SkadX" . t) ("96 Xn" . t) ("yurdX" . t) ("or X " . t) ("Se dX") ("ibalX") ("CXtay" . t) (" alXo") (" aXs " . t) ("dXnal") ("kalsX" . t) ("ntatX" . t) ("av Xn" . t) ("sXdik" . t) ("iyamX") ("laatX") ("GdadX") ("camX ") (" savX" . t) ("haSXn") ("sXgan" . t) ("rmXna") ("rabX " . t) (" SXkt" . t) ("tankX" . t) ("k lXn" . t) ("navlX" . t) ("Xnist") ("azXna" . t) ("I sX " . t) ("amXzi" . t) ("stXya") ("barXz") (" vXdi" . t) ("barCX" . t) ("sXnai" . t) ("Xliye") ("Xsine") ("6 ncX" . t) ("argXn" . t) ("lasX " . t) ("Xlisk") (" Xnsa") ("urXu" . t) ("IfkX" . t) ("ykX ") ("naCX") ("OzXs" . t) ("ajcX" . t) (" usX" . t) ("amCX" . t) ("IngX" . t) ("amXc") ("IfsX" . t) ("InzX" . t) ("IftX" . t) ("mdXs" . t) ("I Xv" . t) ("rsmX" . t) ("atcX" . t) ("ItCX" . t) ("hajX") ("IssX" . t) ("IpsX" . t) (" SXp" . t) ("tXc ") ("Xmit") ("rClX" . t) ("lXme") ("Xkec") ("Xvas") ("kafX") ("aglX" . t) ("Xsaa" . t) ("taCX") ("rlXn") (" lXn") (" mXt") ("IklX" . t) ("Xyel") ("fXye") ("Xyat") ("Xdar") (" dXl") ("Xne ") ("csX" . t) ("IXs") ("IhX" . t) ("kXo") ("bXh") ("lGX" . t) (" Xh") ("dXt") ("IdX" . t) ("Xle") ("erX") ("SImIz Xsin " . t) ("sal islamX" . t) ("ve sXnir ") ("I taktXg" . t) ("center X" . t) (" rantX " . t) ("I sXni " . t) ("a sXnin" . t) ("cilarX") (" tXras" . t) ("kXrani") ("si fXs" . t) ("gazalX") ("bangXr" . t) ("basXl ") ("tal mX" . t) ("hatlX ") ("ak mXd" . t) ("ar tXp" . t) ("an dX " . t) ("camXn " . t) ("sXmsiy") ("I akXs") (" kXli " . t) ("galatX") ("ock Xn" . t) ("gle X " . t) ("at tX " . t) ("rahlX" . t) ("sXmil") ("sXrac") ("rd X " . t) (" SXma" . t) ("It Xn" . t) ("darXk") ("ardXs") (" macX") ("anCsX" . t) (" tXna" . t) ("etalX") (" azXl") ("anCtX" . t) ("UvarX") ("basrX") (" tXks") ("uassX" . t) ("sXvi " . t) ("InClX" . t) ("damdX" . t) ("etabX" . t) ("hazzX" . t) ("nallX") ("Xckir" . t) ("varkX") ("adXs ") ("kXray") (" asX ") ("matXg") ("y Xnn" . t) ("ihamX" . t) ("Xraye") ("hal X") ("Xzasy") (" tXni" . t) ("ann X" . t) ("on X " . t) ("gal X") ("Xsiti" . t) (" mXsa") ("bbanX") ("arslX" . t) (" aydX" . t) ("Xrej" . t) ("Xpca" . t) (" Xas" . t) ("aCsX" . t) (" Xvo" . t) ("IplX" . t) ("G X " . t) ("CXgr" . t) ("sXdd" . t) ("w Xn" . t) ("CXba" . t) ("iGlX") ("akXa" . t) ("lksX" . t) ("sXtk" . t) (" Xrm" . t) ("ayXh" . t) ("pXrl" . t) ("ozkX" . t) ("Xsbu") ("aGnX" . t) (" vXl") ("USkX" . t) ("tXme") ("SXka") ("askX" . t) ("jdX" . t) ("GsX" . t) ("nXj") ("Xfo") ("Xsh") ("Xgh") ("sXs") ("itX") ("a Xnternet " . t) ("n Xnternet " . t) ("lbert X" . t) ("an mXdi" . t) ("ar dXr " . t) ("halanX") ("myk nX") ("l Xnte" . t) ("I mXdi" . t) (" azlX ") ("edralX") ("Il Xn " . t) (" miamX") ("mUbaSX") ("rmallX") (" sadX ") ("Il mX " . t) ("dXsini") ("lvadX") ("lasXm") ("canXk") ("dartX" . t) ("Xrkil") ("kXras") ("bus X" . t) ("h lX " . t) ("ms Xn" . t) ("a lX " . t) (" hXsi" . t) ("zarfX" . t) ("arjX " . t) (" kXbl" . t) ("CXnla" . t) ("ap X " . t) (" Xnst" . t) ("erazX") ("a ydX" . t) ("yassX" . t) ("sXvay" . t) ("ldXnc") ("nnadX") ("artXc" . t) ("itamX") ("abrXm" . t) ("SanzX" . t) (" kakX" . t) ("Xsint" . t) ("navsX" . t) ("Xslak" . t) ("yakXt" . t) ("azmXs" . t) ("zXrva" . t) ("Xskir" . t) ("slahX" . t) ("tacX " . t) ("Xrgir" . t) ("kXlla" . t) ("ak nX") ("kXtay" . t) ("akXyo" . t) ("lIC X" . t) ("Xgna" . t) (" mfX" . t) (" fXf" . t) ("inCX") ("Xpis" . t) (" fXc" . t) ("sfXn" . t) ("rapX") ("Xmir") ("adsX" . t) ("pXrt" . t) ("yXc ") ("tXng") (" zXn") ("Xzir" . t) ("bXs ") ("Xbre") ("Xraz") ("Xtle") ("htXy") (" SXl") (" nXl") ("ercX") ("yarX" . t) ("Xlp" . t) ("dXb") ("Xkb") ("Xos") ("Cin hayatX ") ("inC yanX" . t) ("Gal gazX" . t) ("a mXdir" . t) ("I mXsin" . t) ("a sXni " . t) ("ak mXy" . t) (" aSXna") ("atia X" . t) ("ovladX") ("uralsX" . t) ("art X " . t) ("yahatX") ("rs Xn " . t) (" kXri ") ("IS mX " . t) ("lkantX" . t) ("ance X" . t) ("bXkin") (" Xra " . t) ("cXliz" . t) ("jam X") ("garcX") (" CXri" . t) ("bantX" . t) ("kadXm") (" fanX") ("ubalX") (" sXyi" . t) (" zatX" . t) ("nalXs") ("hmalX") ("Xmild" . t) ("aat X") ("StahX" . t) ("tl lX" . t) ("daktX") ("6 lXk" . t) ("bXcag" . t) ("ntazX") ("yamXn") ("enalX") ("Xspan") (" rXh" . t) (" Xai" . t) (" epX") ("fXrk" . t) ("IhtX" . t) ("azXh" . t) ("hXnz" . t) ("IvrX" . t) ("jamX") ("raCX") (" pXl") ("Xnma" . t) (" Xst") (" mXl") ("jsX" . t) ("IaX" . t) ("SXh" . t) ("zXf") ("Xmo") ("isX") ("eSX") ("Xle") ("eX") ("n taktXr" . t) ("rli malX" . t) ("selamX ") ("Xnterna" . t) ("sXgar " . t) (" SadX ") (" mXril" . t) ("ay mX " . t) ("transX") ("a dXr " . t) ("art Xn" . t) ("a tXp " . t) ("n tXp " . t) (" stalX") ("kXsilm" . t) ("irarX ") ("le Xn " . t) (" sXmsi" . t) ("farksX" . t) ("tles X" . t) ("tXlini") ("an nXn" . t) (" kXta " . t) (" hattX" . t) ("asXni " . t) ("Xndex" . t) ("I Xn " . t) (" Xlic" . t) ("balXs") ("iSahX" . t) ("zXmli") ("izahX" . t) (" tXpa" . t) ("nalXt") ("CXtir" . t) ("nk X " . t) (" hXya" . t) ("ikadX" . t) ("ylXn ") ("abXna" . t) ("a mXy" . t) ("sXro") ("Xph " . t) ("IClX" . t) ("fdXs" . t) ("hXsm" . t) ("Xstr") ("napX") ("aadX") ("tXz") ("aftX" . t) ("IzsX" . t) ("ICkX" . t) ("Xnge") ("gXrt" . t) (" amX") ("fXrc" . t) ("aygX" . t) ("kXye") ("Xbk" . t) (" gazXn " . t) (" 0 lXk" . t) ("saatCX") (" Xzdir" . t) ("UratlX") ("tikalX") ("kXsin " . t) (" 40 lX" . t) (" atXk " . t) ("merakX" . t) ("eid X" . t) ("faksX" . t) ("IrtmX" . t) ("Ir X " . t) ("Xsinm" . t) (" cXvi" . t) ("kXssa" . t) ("ab X " . t) ("nakXl") ("zantX" . t) ("narSX") ("as X " . t) (" zalX") ("Xrpan" . t) ("I mXy" . t) ("pXnar" . t) ("afXmi" . t) ("Xzda " . t) (" tXr " . t) ("aratX" . t) (" gXc" . t) ("nsXf") ("IddX" . t) ("atXb") ("optX") ("fXdi" . t) ("6 sX" . t) ("etCX") ("batX" . t) ("sCX" . t) ("barXs" . t) ("Xsn") ("kanI salX") (" bayX ") ("mutabX" . t) ("Im mX " . t) ("ar mXy" . t) ("zikalX") (" banlX") ("ekanXk") (" Xsmar" . t) ("opartX" . t) ("e tXp " . t) ("varXl ") (" anXma") ("Xring" . t) ("hapsX") ("ovalX" . t) ("okalX") (" apX ") ("faatX") ("I ydX" . t) ("Xndep" . t) ("dXnav") ("zabX " . t) ("alXci" . t) ("ianX ") ("safX ") ("kXya " . t) (" satX" . t) ("rkXr" . t) ("kdXv" . t) ("nkXr" . t) ("farX") ("Xkih" . t) ("IrzX" . t) ("dXda") ("aSsX" . t) ("azcX" . t) ("lkCX" . t) ("sXg " . t) ("CXra" . t) ("babX" . t) ("sXtm" . t) ("eGdX") ("Xsto") (" nXk") ("kImX" . t) (" nXc") ("Xko ") ("Xse ") ("Xrme") ("en yanX ") ("ak mXsin" . t) ("baybaSX") (" Xslik" . t) ("ab Xn " . t) ("  adlX") ("aC Xn " . t) ("Xsinla" . t) ("hatabX" . t) (" Xskal" . t) ("ang X" . t) ("maldX") ("ebalX") (" gXa " . t) (" astX" . t) ("accX" . t) ("aScX" . t) ("capX") (" Xky" . t) ("hXra") ("IflX" . t) ("cXt ") ("nXc ") ("lXla" . t) ("istX") ("dakX") (" rantXn" . t) (" yasXn ") ("eral Xn") ("at mX " . t) (" sarXo" . t) ("ahatX ") (" enayX") ("60 lX " . t) ("niyazX") ("kXtal" . t) (" narX") ("uvazX") (" CXt " . t) ("kXtli" . t) ("adXya" . t) ("astlX" . t) ("gharX") ("hallX") ("rdarX") ("hacXm") (" CXld" . t) (" vadX") ("asmX" . t) (" hXv" . t) ("IalX") (" kXc" . t) ("apCX" . t) ("yrXl" . t) ("ICX" . t) ("Xly") ("an yanX ") ("an dXr " . t) ("sancanX") ("coGrafX") ("an lX " . t) ("tilalX") ("finalX") ("I sXva" . t) (" pratX") ("Ik X " . t) ("efahX" . t) ("ganXk") (" anX ") ("Xslan" . t) (" Xsir" . t) ("Xslah" . t) ("  tXp" . t) ("haSXm") ("ndXc") ("IrkX" . t) ("IzmX" . t) (" Xlo" . t) ("IkkX" . t) ("tXvi") ("IrhX" . t) (" nXs") ("asrX" . t) ("Xlai") ("eptX") ("CXj" . t) ("Xfz" . t) ("atlantX") ("neralX") ("dli tX" . t) ("ans Xn" . t) ("misalX") ("ar mXs" . t) (" kXliy" . t) ("orantX" . t) ("sakXn ") ("kk lX " . t) ("In X " . t) ("fXsil" . t) ("90 lX" . t) ("UnahX" . t) ("darkX") ("abXni" . t) ("laysX" . t) ("Xnlar" . t) ("Xsina" . t) ("abXz" . t) ("ItmX" . t) ("arXt") ("6 yX" . t) ("katXli ") ("inyalX") ("and Xn" . t) (" sXni ") ("rd Xn" . t) ("hXzip") (" ganX") ("nazXk") ("bakX ") ("acayX") (" rXfa" . t) ("kXsla" . t) ("Xlif" . t) ("anSX" . t) ("InsX" . t) ("Xvao" . t) (" Xan" . t) ("iStX") ("cXu") ("Xbm" . t) ("gXp" . t) ("bzX" . t) ("sXb") ("Xle") ("S ahlakX" . t) (" Xsiya" . t) (" azamX") (" akXt ") ("avalX " . t) ("Ik mX " . t) (" stasX") (" kXlig" . t) ("sabrXn" . t) ("sXnam" . t) ("Xraci") ("katXp") ("arstX" . t) ("artlX" . t) ("rarSX") ("arXl " . t) ("hXnc" . t) (" Xrz" . t) ("Xoc" . t) ("Xo ") ("nXh") ("am mX " . t) ("lgazX" . t) (" fXst" . t) ("naatX") ("rartX" . t) (" kXst" . t) ("balXn") ("astXr" . t) (" raSX") ("IrCX" . t) ("IfzX" . t) ("ikmX") ("nsXk") ("Xkdp" . t) ("omXr" . t) ("ealX") ("sXza" . t) ("hXl") ("yonal X") (" SinasX") ("SahsXn" . t) ("mIS mX" . t) ("aksXn " . t) ("kkatsX") (" trajX") ("ramXk") ("k yX " . t) ("elafX") ("karnX" . t) ("40 X" . t) ("sXyr" . t) ("60 X" . t) ("Xgdi" . t) ("ahtX" . t) (" kXz" . t) (" Xc") ("bir yanX" . t) ("ografX") (" malXk") ("Im X " . t) ("balcX" . t) (" kXl " . t) ("yXgil" . t) ("italX") (" SXk " . t) (" tacX") ("ifakX" . t) ("90 X" . t) ("IbX" . t) (" barX ") ("In mX " . t) (" sXnin") ("IS Xn " . t) ("iramX") ("hlalX") ("icabX" . t) ("kXra ") ("nasXp") ("SgalX") (" zXt" . t) ("tXbb" . t) ("dafX") ("yayX" . t) ("fbX" . t) ("eCX") (" anadX") ("artsX" . t) ("alttX" . t) ("altmX" . t) ("alXc ") ("yankX" . t) ("uhtX" . t) ("dXsc") ("CXg " . t) ("Xyik" . t) ("yXrt" . t) ("eGlX") ("yXi") (" var mX" . t) ("ahsXz" . t) ("apkXn" . t) ("Xlgaz" . t) ("a sX " . t) (" sXzm" . t) ("azgX" . t) ("hasX" . t) ("francX") (" nazX ") ("selanX") ("zgarX" . t) ("atmXy" . t) ("IstX" . t) ("sXrk") ("Xgma" . t) ("dolabX" . t) ("moralX") (" asXt") ("Xspar" . t) (" nadX") (" akXf") ("gXya" . t) (" sXzdi" . t) ("I dXr " . t) ("IrslX" . t) ("yastX" . t) ("kastX" . t) ("am X " . t) (" lakX") ("6 sX" . t) ("IltX" . t) ("CXgi" . t) ("emal X") ("tXla ") (" atXf" . t) (" kXde" . t) ("aycX" . t) ("bektaSX") ("ht Xn" . t) ("ahCX" . t) ("IzgX" . t) ("Xkol") ("Xmle") (" kXlik" . t) (" asayX") (" fXnd" . t) ("IrhlX" . t) ("Xye ") (" allahX" . t) ("maatX") ("IymX" . t) (" bXk" . t) ("Xlle") ("rXo") (" arXk" . t) ("vaktX") ("amsXz" . t) (" sXca" . t) ("Xhh" . t) ("Xge") (" arSX") ("haydX") ("marXs") ("aymX" . t) ("alXf") ("aslX" . t) ("IvX" . t) (" naklX") (" kXniy" . t) (" nacX") (" latX") ("amdXr" . t) ("anClX" . t) ("artmX" . t) ("Xsah") ("ISsX" . t) ("IrgX" . t) ("dXya") ("iyX") (" yXgin" . t) ("saatlX") ("aSantX" . t) ("alsXn" . t) (" affX" . t) ("Ir mX" . t) ("IslX" . t) ("aSCX" . t) ("G Xn" . t) ("Xzla" . t) (" taklX") ("anslX" . t) ("IrttX" . t) ("abahX" . t) ("omasX") ("Xgli" . t) ("enazX") ("rdXn ") ("mpatX") ("kXsir" . t) ("isadX") ("IrcX" . t) ("iptX") (" akX" . t) ("Ir Xn " . t) ("ah X " . t) (" zabX" . t) ("al X " . t) ("IrrX" . t) ("barzanX") (" salXm") (" kXld" . t) (" Xsil" . t) ("Xrmak" . t) ("Xltu") ("Xfe") ("Xde") ("bXt") ("katXl ") (" fXri" . t) ("GazXc") ("ajlX" . t) (" pXril" . t) ("hafXz" . t) ("Xnle") ("Xce") (" kXlin" . t) (" sakX" . t) ("algX" . t) ("fXne") ("cazX") ("Xyla" . t) ("Xklar" . t) ("nssX" . t) ("CXlg" . t) ("afX " . t) (" Xi" . t) ("Iz mX " . t) (" hXz " . t) ("zXrh" . t) ("IrpX" . t) ("sXcr" . t) ("cXz") ("tXt") ("ak X " . t) ("pasXf") ("6 nXn" . t) ("afCX" . t) (" dXn") ("ISCX" . t) ("az mX" . t) ("aXds" . t) ("as Xn " . t) ("kkarX") (" marX") ("kXv" . t) ("timalX") ("IlcX" . t) ("CXrp" . t) ("ItsX" . t) ("Ik Xn " . t) ("az X " . t) ("Xpir" . t) ("ImdX" . t) ("In Xn " . t) ("azXz") ("lktX" . t) ("labanX") ("an mX " . t) ("kXral") ("IpX" . t) ("iptalX") ("on Xn " . t) ("saatX") ("altXn" . t) ("apsX" . t) ("IkCX" . t) (" Xlimli" . t) ("hatXp") ("at X " . t) ("fXrat" . t) ("Xstl") ("aGcX" . t) ("dIz X" . t) ("ay X " . t) ("elCX") ("ihtX") ("Xon") (" hXzi" . t) ("Xrna" . t) ("anrX" . t) ("GzX" . t) ("Xdv" . t) (" idarX") ("ap lX " . t) ("bartX" . t) ("rkCX" . t) ("Xpla" . t) ("hIrXs") (" kXlm" . t) (" tayX") ("gahX" . t) ("afsX" . t) (" hanX ") ("kadXr") ("azsX" . t) ("kkabX" . t) ("bXl") (" kXs " . t) ("kaybX" . t) ("arcX" . t) ("IlgX" . t) ("fXl") ("bank Xn" . t) (" bastX" . t) (" makX") (" fXrl" . t) (" cXa " . t) ("aS X " . t) ("cXv") ("inamX") ("IX" . t) ("fXkra" . t) (" kXna" . t) ("aflX" . t) ("Xnirle") ("ekmX") ("arazX") ("GdX" . t) ("Xno") ("Xnar " . t) ("afXn" . t) ("kXsim" . t) (" sXgi" . t) ("aCmX" . t) ("CakX" . t) ("SartX" . t) ("ISkX" . t) (" yXp" . t) ("ak mX " . t) (" panX") (" acXl ") ("kXlic" . t) ("kkatlX") (" Xlie" . t) ("Xnde") ("pahalX" . t) ("ap Xn " . t) ("ammX" . t) ("Im Xn " . t) (" harX") ("Xng ") ("ecatX") ("SahXs" . t) ("fXrt" . t) ("IncX" . t) ("IttX" . t) ("alCX" . t) ("yazmX" . t) (" gXda" . t) ("IksX" . t) ("vabX" . t) ("sXyon") (" Xrk" . t) ("rXza" . t) ("ar X " . t) ("aplX" . t) (" klasX") ("alXz") ("IlsX" . t) ("arzX" . t) ("kXsit" . t) (" Xsig" . t) (" hadX") ("kapXt") ("Xmar") ("hayalX") ("sarX" . t) ("rIs X" . t) ("zXran") ("gazX") ("silahX" . t) ("basXt") ("kXsk" . t) ("Xyle") ("I yX " . t) ("mXsir" . t) ("mXl") ("kampX" . t) ("ikkatX") (" adXl") ("ikahX" . t) ("am Xn " . t) ("tXll") ("InavX" . t) ("dXsk") ("Xpk" . t) (" malX ") ("ad X" . t) ("IpkX" . t) (" sXf" . t) ("mXr") ("ItlX" . t) ("attXn ") ("hamX") ("rasXm") ("caksX" . t) ("allX" . t) ("n yanX" . t) (" samX") ("haylX") (" tXk" . t) ("ISmX" . t) (" taktX") ("langX" . t) ("at Xn " . t) (" islamX ") ("dXka") ("ImlX" . t) ("garX") ("carX") (" mantX" . t) ("Xre") ("ganXz") ("IrakX" . t) ("amcX" . t) ("IzdX" . t) ("IsmX" . t) ("vakXf" . t) ("a mX " . t) (" manX") ("zayXr") ("k nXn " . t) (" yakX" . t) ("IfX" . t) ("Xe") ("ISlX" . t) ("parXs") ("sabX" . t) ("aSmX" . t) ("Xlat") ("aClX" . t) ("avrX" . t) ("dXsip") ("InmX" . t) ("kartX" . t) (" atXna") ("CarpX" . t) (" kXrl") ("tXrma" . t) ("rXf") (" yangX" . t) ("Xmf" . t) ("al Xn " . t) ("tdX" . t) ("I mX " . t) ("az Xn " . t) ("akCX" . t) ("Xsrar" . t) ("tavXr" . t) ("ahlX " . t) ("IrsX" . t) ("ak Xn " . t) ("atkX" . t) ("Xst ") ("valX") ("ah Xn " . t) ("Xcak" . t) ("ar mX " . t) ("itabX" . t) ("IrtX" . t) ("akfX" . t) ("hapXs") ("aS Xn " . t) ("ykX" . t) ("armX" . t) ("ay Xn " . t) ("atmXs" . t) (" talX") (" kXsm" . t) ("fadXm") ("arafX" . t) ("kmX" . t) ("Xrsa" . t) ("Xsyo") ("tatX") (" galX") (" yXk" . t) ("Xzm") ("aSkX" . t) (" hXr" . t) ("arsX" . t) ("hakX") ("arttX" . t) ("aylX" . t) ("Xa") ("pmX" . t) ("IrmX" . t) ("IydX" . t) ("amlX" . t) ("aksXz" . t) ("Xte") ("an X " . t) ("sanayX") (" Xsik" . t) ("ImsX" . t) ("aCtX" . t) ("azlX" . t) ("azdX" . t) ("tXf") ("ajX" . t) (" kXy" . t) ("ar Xn " . t) ("a yX " . t) ("IntX" . t) ("Xle") ("akXl" . t) ("aGrX" . t) (" Xl") ("Xnav" . t) ("atCX" . t) ("Xne") ("almX" . t) (" hakkX" . t) ("Xsle") ("hXzl" . t) ("atsX" . t) ("InlX" . t) ("alnX" . t) (" yanX ") ("arkX" . t) ("askX" . t) ("IllX" . t) (" kXr" . t) ("IndX" . t) ("dlX " . t) ("arklX" . t) ("Xstan") ("rXka") ("bakX" . t) ("kXsa" . t) ("avcX" . t) ("atlX" . t) (" camX") ("ImcX" . t) (" alX ") (" sXni" . t) ("aktX" . t) ("yargX" . t) ("ItX" . t) ("IyX" . t) ("aSlX" . t) ("IlmX" . t) ("aygX" . t) ("anmX" . t) ("IktX" . t) ("IrdX" . t) ("IrlX" . t) ("Xye") (" kXz" . t) ("atXk") ("IbrX" . t) ("IzlX" . t) ("kXbris" . t) ("aklX" . t) ("IklX" . t) ("Xlah") ("tartX" . t) ("akXm" . t) ("ansX" . t) ("IcX" . t) ("siyasX") ("lantX" . t) ("alkX" . t) ("akXn" . t) ("GlX" . t) ("attX" . t) ("halX") (" sXk" . t) ("okrasX") ("Xrak" . t) ("IdX" . t) ("altX" . t) ("ancX" . t) ("I nX" . t) ("aydX" . t) ("aynX" . t) ("IkX" . t) ("Xh") (" artX" . t) ("arlX" . t) ("an Xn " . t) (" ayrX" . t) ("a nXn" . t) (" sXr" . t) ("aStX" . t) ("IzX" . t) ("acX" . t) ("IStX" . t) (" dXs" . t) ("aCX" . t) ("ptX" . t) ("amX" . t) ("IldX" . t) ("ISX" . t) ("ardX" . t) ("apX" . t) ("aldX" . t) ("andX" . t) ("arSX" . t) ("azX" . t) ("IrX" . t) ("anlX" . t) ("IsX" . t) ("ImX" . t) ("atX" . t) ("aSX" . t) ("IlX" . t) ("alX" . t) ("yXl" . t) ("Xla" . t) ("aGX" . t) ("CXk" . t) ("ayX" . t) ("adX" . t) ("Xnda" . t) ("IGX" . t) ("anX" . t) ("asX" . t) ("InX" . t) ("arX" . t) ("X") )
     (?o ("uz kXr") ("ni kXt" . t) ("dir gX" . t) ("Il dXn" . t) ("an Xng" . t) ("lum kX") ("niS kX") ("Giz gX" . t) (" te gX" . t) ("rka kX") ("jIn Xn" . t) ("ki rXp" . t) ("Xnerek" . t) ("ezik X") ("dIn CX") ("ni Xng" . t) ("klI gX" . t) ("ran CX") ("ok Xn " . t) ("I Xrt " . t) ("m gXcu") (" efe X" . t) ("OSe dX" . t) ("Ge dXn" . t) ("ik dXk") ("bu sXn") ("ma sXk") ("e Xlup") (" Xlusm") ("Xyune " . t) (" la gX" . t) ("an rXm") ("ka yXn" . t) ("tacI X") ("nuGu X") ("Xnusma") ("nde rX") ("bin Xg" . t) ("zle gX" . t) ("dXnsa") ("Xktel") ("Xnalm" . t) ("kXley" . t) ("lXwen" . t) ("gakgX") ("sXnus" . t) ("ektX " . t) ("uyanX") ("0 Xz ") ("rI Xo" . t) (" Xnut" . t) (" us X" . t) ("jon X") (" lXm " . t) ("Xykoy" . t) ("l bXb") ("kXsog" . t) (" tXko" . t) ("bOksX" . t) ("a sX " . t) ("e Xt " . t) ("76 yX" . t) ("e Xmn" . t) ("CXpul") (" kXrv" . t) ("d gX ") (" dXb " . t) ("Xtana" . t) ("I Xes" . t) ("lerXn" . t) ("he Xp") ("Xrtuc") ("  Xdi" . t) ("i gyX") ("i lXw" . t) ("gXdek" . t) ("hektX") ("Xlumy" . t) ("th jX" . t) ("pt yX" . t) ("Xkse " . t) ("i i X" . t) (" setX" . t) ("arelX" . t) ("GI Xb") ("Xpece" . t) ("r m X") ("Xglel" . t) ("Xrfun" . t) ("b Xde") ("e I X") ("Xgdur" . t) ("rXdov" . t) ("Xseri") ("Xunen" . t) ("Xksen") ("ortrX" . t) (" Xrce" . t) ("Sii X" . t) ("mXren" . t) (" kXtl" . t) ("fritX" . t) ("yl X " . t) ("dirX " . t) ("lemX " . t) (" rXba" . t) ("b dXl") ("k sX " . t) ("k bX " . t) ("guadX" . t) ("Xrdev" . t) ("en aX" . t) ("rXney") ("dr Xv" . t) ("n gaX" . t) ("orn X" . t) ("Xrdio") ("ou gX") ("Ol gX" . t) ("i bX " . t) ("ny bX") ("11 kX") ("n dXt" . t) ("ga gX" . t) ("nCo X" . t) ("CXkes") ("Xsler" . t) ("Xyuym" . t) ("Xnlus") ("Xders" . t) ("Xryo " . t) ("Xnkin") ("os gX" . t) ("ilo X") ("5 yXk" . t) ("zu kX") (" sXv " . t) ("m Xr " . t) ("ukkXy" . t) ("s Xlv" . t) (" me X") ("bXles") ("CUn X" . t) (" hXrg" . t) ("  UrX" . t) ("4 kXy" . t) (" Xve " . t) (" d gX" . t) ("Xnkay" . t) ("Xnbaz") ("mis X") ("kXreb" . t) ("dXkse" . t) (" tetX" . t) (" b dX") ("7 yXk" . t) (" 1 Xz" . t) ("morkX" . t) ("romXr" . t) ("Xleme" . t) ("m y X" . t) ("Xtsun" . t) ("shi X") ("2 kXy" . t) ("C rXm") ("li Xe" . t) ("lu Xb") ("go gX" . t) ("bi lX") (" lXp " . t) ("tXral") ("gerlX" . t) ("inagX") ("i n X") ("cal X") ("s Xzi") ("nC Xd") ("ry kX") ("fe gX" . t) ("dI mX") (" dXle" . t) ("kUp X") ("ka Xg" . t) ("Or SX" . t) ("ad yX" . t) ("Xvern") (" bXnl" . t) ("dr gX" . t) ("Xluye" . t) ("ketXr" . t) ("r gX ") ("st gX" . t) ("tu dX") ("foklX" . t) ("Xvell") ("oza X" . t) ("Xzale") ("tXrki" . t) ("rk gX" . t) ("o dX " . t) ("Xrsen" . t) (" CXsu" . t) ("e yXe" . t) ("c bXl" . t) (" dXl " . t) ("tXron") ("Xrtla") ("ku kX") ("8 kXy" . t) ("ndXrt" . t) ("ov Xn" . t) ("S Xna") ("rXlov" . t) ("dyatX" . t) ("Xmuyo" . t) ("gI kX") ("Xzar ") ("Xlcen" . t) ("u Xst" . t) ("Xyser") ("Xlulu") ("na lX") ("Xvula") ("d Xlm") ("Um gX" . t) (" Xrun" . t) ("z rXm") ("ngXl " . t) ("CerdX" . t) (" Xnyu" . t) ("r Xme" . t) ("  tXb") ("bXluk" . t) ("Xsym " . t) ("Xzbek" . t) ("m Xtu") ("Xtusu" . t) ("n lXk") ("gXrsu" . t) ("13 kX") ("Xnely") ("Xlmun" . t) ("gXrta") ("ha Xb") ("gXnul" . t) ("Xrebi" . t) ("Xyuna") ("Xzenl" . t) ("n Xve") ("dXkuz") ("Xrcul") ("rXc") (" terX" . t) ("Xzgur" . t) ("Xzerk" . t) ("  Xrm") ("a Xne" . t) (" Xkta") ("Xkenl" . t) ("Xnlar") ("Xsunu") ("dXviz" . t) ("gXbl") ("n iX" . t) ("bXcu" . t) ("Xooy" . t) ("Xnm " . t) ("Xpem" . t) ("CdXk" . t) ("uerX") (" Xsu" . t) (" Xsr" . t) ("Xgge" . t) ("Xyre" . t) ("elXz" . t) ("Xzia") ("Xrrk" . t) ("objX" . t) ("ho X" . t) ("kyXd" . t) (" Xen" . t) ("lIdX" . t) ("rkXp" . t) ("eanX") ("Xk1 " . t) ("pXku" . t) ("gXlm" . t) ("Xnex") ("gXmo") ("dXlk" . t) ("tXve" . t) ("Xccu" . t) (" jXl" . t) ("InXz" . t) ("bXhl" . t) ("Xgrt" . t) ("kXkk") ("Xnnb" . t) ("ykXy" . t) ("nbXn" . t) ("bXnb" . t) ("ntXz" . t) ("Xzie") ("taXv" . t) (" G X" . t) ("Xlea") ("segX") ("uc X") ("rIXn" . t) ("nh X" . t) ("Xrso") ("esiX" . t) (" O X" . t) ("Xkuv" . t) ("lldX") ("Xnss") ("sXro") ("dXny") ("kyXn" . t) ("SXru" . t) (" Xkd" . t) ("Xzni") ("fosX" . t) ("yorX" . t) ("irXr" . t) (" IgX") ("Xrki") ("Xnra") (" Xnr" . t) ("Xyok" . t) ("zXme" . t) (" pnX" . t) ("Xnea") ("rOlX" . t) ("Xtov") ("Xvma") ("kXye" . t) ("Xbeg" . t) ("Xyti") ("gXvi") ("barX") ("Xpti") ("Xneb" . t) ("Xryu") ("9 Xc") ("Xket") ("Xrsi") ("Xril") ("vagX") ("tXbu") ("Xrph") ("hXni") ("Xnan") ("Xzit") ("stXk") ("gUnX" . t) ("1 Xc") ("viyX") (" kXg") ("Xro ") ("gXrm" . t) ("Xnda") ("Xrie") ("Xhn ") ("Xndr") ("Xrsk") ("Xndo") ("lkXg" . t) ("bXlg" . t) ("siyX") ("Xmis") ("Xrku") ("sXym") (" gXz" . t) ("Xnom") ("Xpla") ("Xmh") ("Xdv") ("Xmg" . t) ("Xem" . t) ("lXh" . t) ("GdX" . t) ("Xvt") ("jyX") ("Xtc") ("vXa" . t) ("Xez" . t) ("SXp" . t) ("Xdm") ("OyX" . t) ("Xdd") ("tuX") ("Xa ") ("Xgo") ("Xtl") ("cXb") ("maX") ("nXy") ("nyX") ("Xpa") ("Xma") ("plX") ("Xth") ("vXn") ("llX") ("Xga") ("ncX") ("Xmb") ("ve taksi SXforleri " . t) ("nesinin Xldugun" . t) ("n babasI Xldu " . t) ("elerinin yXk " . t) ("aSlarInIn Xld" . t) ("tan sonra Xlu" . t) ("er zaman Xn " . t) ("mlarInIn yXk" . t) ("i sonucu Xld" . t) ("i olarak Xld") ("Once de yXk " . t) ("Xlumsuzluge" . t) ("ilileri yXk" . t) (" ya da Xlur" . t) ("  kaptan Xl" . t) ("SIsInda dXn") ("vinde Xldu " . t) ("y iCinde yX" . t) ("atUrk Xldu " . t) ("tOrleri yX" . t) ("lInda Xlmu" . t) ("urduGu yXk" . t) ("lamIStI Xl" . t) ("mak ve yXk") ("GInda Xlum" . t) ("ilde Xldu " . t) ("saat sektX") ("kkInda yXk" . t) ("nra dXndur") ("irinin Xld" . t) ("nlerde Xn ") ("Once Xldu " . t) ("rinin Xnu ") ("ylerim Xl" . t) ("amIS Xlmu" . t) ("ede dXgus" . t) ("l bir Xn ") ("tedi yXk " . t) ("rden yXk " . t) ("arada yXk" . t) (" nun yXk " . t) ("lUyor Xlu" . t) ("ses Xldu " . t) ("lde Xlurk" . t) ("vil Xldu " . t) ("a dXkuman" . t) ("In Xlusun" . t) ("rIn Xdun ") ("a her kXy" . t) ("meden Xld" . t) ("ker Xldu " . t) ("rde gXlle" . t) ("ncak yXk " . t) (" ndan yXk" . t) ("cuk Xldu " . t) ("tadan Xn " . t) ("hir ve gX" . t) ("in dXnmus") ("dolayI Xl" . t) ("ra da Xn ") ("lerle Xn " . t) ("Coktan Xl" . t) ("rerek yXk" . t) ("i de dXnd") ("GInI yXk " . t) ("gUnde Xn ") ("arken yXk") ("rada Xlmu" . t) ("Xlduguyle" . t) (" in Xlums" . t) (" hem yXk " . t) ("amInda Xn" . t) ("Serek Xld" . t) ("asInI Xn ") ("nan Xdun ") ("nsana Xl" . t) ("yni Xlmu" . t) (" sIk gXl") ("Cin Xluy" . t) ("aya kXy ") ("lona Xnc") ("smen Xld" . t) ("r jXrgen" . t) ("ten Xluy" . t) ("niz gXl " . t) ("eye gXlu" . t) ("n 35 Xld" . t) ("In kXyu ") ("tiGi Xn ") ("san Xluy" . t) ("14 Xldu " . t) ("Iz kXyu ") ("gUnU Xn " . t) ("ki dXkum" . t) ("saG Xluy" . t) ("e ali Xl" . t) ("nciyi yX" . t) ("stUn kXr" . t) ("rIn Xluy" . t) ("ble ve X") ("InI Xlmu" . t) ("n in Xn " . t) ("duvar Xr" . t) ("kanIm dX") ("erde Xn " . t) ("3 te Xld" . t) ("rI sXkul" . t) ("e sol Xl" . t) ("rtInI dX" . t) ("IyI Xlum" . t) ("nun Xnu " . t) ("eGin yXk" . t) ("yata dXn" . t) ("ileri gX" . t) ("lUler kX") ("yine Xn " . t) ("Ilan Xn " . t) ("gibi Xn ") ("u dXnmu") ("kaCta X" . t) ("lIn Xn ") ("ul dXnd") ("nyol Xl" . t) ("ir dXnm") ("ldU Xld" . t) ("ldi yXk" . t) ("Xkulunm") ("mlili X" . t) ("Xlesiyu") ("ok kXyu" . t) ("isi Xn ") ("gUn Xn ") (" Xlunu " . t) ("zse Xlu" . t) ("mde Xn " . t) ("lim kXy") ("eli kXy" . t) ("n dXnu ") ("ater gX" . t) ("en kXk ") ("anat Xn" . t) ("ray Xn " . t) ("Xktukle" . t) ("Iz sXne" . t) ("iseye X" . t) ("fa majX" . t) ("re majX" . t) ("  Xluru" . t) ("r flXre" . t) ("kuGu gX" . t) ("kle Xgu" . t) ("k kXru " . t) ("86 da X" . t) ("na Xdun") ("rIlI Xn") ("llar gX" . t) (" Xludur" . t) ("halI dX") ("sen Xld" . t) ("dam Xn " . t) ("sIn dXn" . t) ("ortun X" . t) ("diki yX" . t) ("eli Xn ") ("  Xlmus" . t) ("nasI Xn" . t) ("n dXnuk") (" in Xn ") ("ttin gX" . t) ("  dXnmu") ("ir Xgun" . t) ("mIz Xna" . t) ("et kXyu") ("Xlduyse" . t) ("gton gX" . t) ("en kXr ") ("zeki CX") ("da dXn ") ("nIna kX") (" Un Xld" . t) ("dI kXyu" . t) ("sXkturu" . t) ("GIda dX" . t) ("aha CXk") ("eye sXk") ("stXriz" . t) ("xel kX" . t) ("rXlans" . t) ("lkU yX" . t) ("n Xle ") ("24 Xld" . t) ("aim gX" . t) ("mI Xn ") ("n cXnk" . t) ("ya Xl " . t) ("dXnuna") ("fa kXz" . t) ("buk Xp" . t) (" Xgunc" . t) ("n Xkce" . t) ("dXnele") ("co Xld" . t) ("ncar X" . t) ("Xmurla") ("uni gX" . t) ("Xyuyle" . t) ("m a Xr") ("yp kXk" . t) ("9 bXlu" . t) ("sXkum " . t) ("sXksa " . t) ("gXttin" . t) ("n Xpen" . t) ("I an X" . t) ("nt CXk") ("Xcunuy") (" Xlune" . t) ("fre kX") ("sol Xn" . t) ("CI Xn ") ("l Xpen" . t) ("rk kXt") ("Xktule" . t) ("furt X") ("Iz Xn " . t) ("liz yX" . t) ("nis kX") ("ha Xn " . t) ("l Xdun") ("ste Xn" . t) ("i sXle" . t) ("eva gX" . t) ("Xlurle" . t) (" Xper " . t) ("e Xrt " . t) ("Xnunce" . t) ("sXkun " . t) (" dXnel" . t) ("i Xrt " . t) ("Xrdule" . t) ("Ip Xn " . t) ("t kXru") ("i o X ") ("Xnukla") ("oca gX" . t) ("na sXk") (" I gX ") ("CIk gX" . t) ("pek CX") (" Xteb" . t) ("tXdef" . t) ("Xlyat" . t) ("rXlev" . t) ("Xoooy" . t) (" Xsko" . t) ("3 Xre") ("benkX" . t) ("Xlena") ("sOktX" . t) (" Xgdu" . t) ("ntenX" . t) ("kXri " . t) ("fkI X" . t) ("lokXr" . t) ("ekXyu" . t) ("Xrelm" . t) ("Xrulc" . t) ("eb yX" . t) ("sXnup" . t) ("eny X") ("r dX " . t) ("bXld ") ("34 yX") (" kXne") ("cXrdu" . t) ("5 kXy" . t) ("sXmer") ("On bX" . t) ("174 X") ("Xser ") ("bXll " . t) ("cok X") ("tXnuk" . t) ("veryX") ("Xcund") ("Xrtur") ("Xgune" . t) ("oy kX") (" dXk " . t) ("bXren") ("ym yX" . t) ("Xpeli" . t) ("sU SX" . t) ("likXr" . t) ("Xrsut" . t) ("Xkucu" . t) ("Xtuna") ("Xnurm" . t) (" lXk " . t) ("kXleo" . t) (" Xtec" . t) ("Xkluy") ("nXtr " . t) ("nXtra" . t) (" Xrik" . t) ("rXne ") ("Xrnel") ("esXrl" . t) ("7 kXy" . t) ("sXter" . t) ("Xkume" . t) ("Xrdeg" . t) ("Xnerk" . t) ("fXyun" . t) ("dXrtl" . t) ("Xrece" . t) ("Xdeme" . t) ("SutX" . t) ("Xror" . t) ("dXvr" . t) ("tOrX" . t) ("sXvs" . t) ("Xsec") ("IrdX" . t) ("hlXg" . t) ("gasX") ("ekXz" . t) ("mb X" . t) ("yOzX" . t) ("O dX" . t) (" Xnv" . t) ("mXbl" . t) ("UtXz" . t) (" gyX" . t) ("bXge" . t) ("Xyl " . t) ("ntgX") ("SXmi" . t) ("Xtet" . t) (" uCX" . t) ("Xntt") ("bagX") ("nkXn") ("rbjX" . t) ("Xyey" . t) (" jXt" . t) ("gXlp" . t) ("Xrea") ("bXlt") ("IkXz" . t) (" Xnp" . t) ("Xyel" . t) ("catX") ("dXpy" . t) ("Xfek" . t) ("eXrn" . t) (" f X" . t) ("mkXy" . t) (" iX " . t) ("CXrd" . t) ("Xyse" . t) ("hXcs" . t) ("aSXr" . t) ("ublX" . t) ("nXrl" . t) ("zXle") ("Xnt ") ("lkXn") ("hXdu" . t) ("Xcha") ("dXr ") ("gOzX" . t) ("Xri ") ("Xvi ") ("Xztu" . t) ("ekXr") ("Xlsu") ("argX") (" Xyu") ("Xrga") (" ekX") ("wXb" . t) ("eeX" . t) ("Xvc") ("Xds") ("cXr") ("liX") ("crX") ("iXn") (" zX") ("Xya") ("nXm") ("X2") ("kanlIGI yXk " . t) ("zalarInda Xl" . t) (" in Xldugun" . t) ("itelerin yX" . t) ("y yerinde X" . t) ("Sinin de Xl" . t) ("kerinin Xl" . t) ("e dXkumanl" . t) (" olan yXk " . t) ("da dXndurd") ("li dXkuman" . t) ("zasInda Xl" . t) ("en kiSi Xl") ("rdan yXk " . t) ("i kXyunun") ("sunda Xn " . t) ("lis Xldu " . t) ("leri sXku" . t) ("san Xldu " . t) ("n kim Xlm" . t) ("nce Xlmus" . t) ("ada Xldu " . t) ("SInda yXk" . t) (" ve gXre ") ("sitesi yX" . t) ("rlanan Xn" . t) ("cuGun Xld" . t) ("arak Xlur" . t) ("le kXyu ") ("ken kXyu" . t) ("san Xlmu" . t) ("kan kXk ") ("ri kXyun" . t) ("amlIk kX") ("Glarla X" . t) ("un kXyu ") ("in kXruk" . t) ("ilen Xn " . t) ("kXpuklu " . t) ("yIlI yXk" . t) ("mada Xn " . t) ("Cilen yX" . t) ("elere Xn" . t) ("dUn Xlmu" . t) ("Olen Xlu" . t) ("rtIk Xld" . t) ("imin Xnu" . t) ("edi Xn ") ("iyi Xn ") ("kle Xn " . t) ("uzla gX" . t) ("rda Xn " . t) ("sun Xn ") ("eve dXn" . t) ("anca gX" . t) ("Ica yXk" . t) ("bXldur ") ("hep Xn " . t) ("  Xldug" . t) ("  kXku " . t) (" gXlov" . t) ("7 Xrt " . t) ("sXylus") ("gut Xn" . t) ("Xkumuz") ("l bXn " . t) ("i Xpen" . t) ("Xpukte" . t) (" tXban" . t) ("kXruk " . t) ("l o bX") ("nal Xn" . t) ("dur gX" . t) ("tek Xp" . t) (" kXran" . t) (" Xgunl" . t) ("r CXkt") ("m tXr " . t) ("uat Xr") ("fer gX" . t) ("kXni " . t) ("Xnig " . t) ("sXmek" . t) (" Xrgo" . t) ("sXkto" . t) ("lstrX") ("brXta" . t) ("G Xn " . t) (" dXsu" . t) ("CXrus" . t) ("3 Xgu" . t) ("kXrug" . t) ("Xrteg") ("gXlko" . t) ("Xgusk" . t) (" Xsta" . t) ("Xreck") ("sistX" . t) (" Xter" . t) ("Xrdog" . t) ("ntrXn" . t) ("Xlsen") ("i gaX" . t) ("rkXz " . t) (" tXs " . t) ("duktX" . t) ("Xrmuk" . t) ("Xpus ") ("tUnkX" . t) ("Xnsez" . t) ("dikdX" . t) (" akXz" . t) ("Xlero") (" tXb " . t) ("Xmurt") ("onglX" . t) ("ardXn") (" o X " . t) ("Xrtec" . t) ("Xcuna") (" Xvus") (" inXn" . t) ("gesX" . t) ("ndXv" . t) ("gXss") ("zakX") ("hXh " . t) (" mfX" . t) (" Xhc" . t) (" asX") (" Xgm" . t) ("Xge " . t) ("hXch" . t) ("yyXr" . t) ("dXro") ("anXn") ("dXrf") ("Xng ") ("Xrla") ("Xgra") ("Xsev") ("gXf") ("gXh") ("Xiz") ("hXz") ("zgX" . t) ("Xyg") ("ana nIn Xl" . t) ("e sonra Xl" . t) ("rken Xldu " . t) ("elerin Xnu" . t) ("izinden X" . t) ("ler kXyun" . t) ("ana Xldu " . t) (" In Xldug" . t) ("Xndurulme" . t) ("kIn dXgus" . t) ("nserden X" . t) ("Once yXk " . t) ("celiyle X" . t) ("metin yXk" . t) ("ve Xldu " . t) ("zla kXyu") ("a da Xn " . t) ("yla yXk " . t) ("nra yXk " . t) ("Ore yXk " . t) ("ken yXk " . t) (" In yXk " . t) ("bir yXk " . t) ("nIn Xnu " . t) (" kXrle ") ("ani Xn ") ("zar gXl" . t) ("eman gX" . t) ("nde Xn " . t) ("Ina Xn " . t) ("k dXkuy") ("yas gX" . t) ("sli Xn") (" dXksu" . t) ("nI sX " . t) ("Xpukle" . t) ("kXrdov" . t) ("  kXk ") ("bat gX" . t) ("pardXs" . t) ("Xdunda") ("Un Xn " . t) ("a dXn " . t) ("vinatX") ("ora kX") (" Xver ") ("bXrtu" . t) ("Xkumc" . t) ("razXz" . t) ("ertXr" . t) ("gXmes") ("eryXn" . t) (" d Xr") ("Xruko" . t) ("kXstl" . t) ("the X") (" sXbu" . t) ("Xnces" . t) ("kXyk" . t) (" lX " . t) ("nrIX" . t) ("IgXl" . t) ("Xyli" . t) (" Xdi") ("CXle" . t) ("Xcek" . t) ("Xnoz" . t) ("Xnuv" . t) ("dXnl") ("kXye" . t) ("dXra") ("Xnez") ("Xrto") (" tXy") ("Xzla") ("Xnta") (" fXr") ("Xley") ("Xzle" . t) ("gXst" . t) ("Xyy" . t) ("SXo" . t) ("cXz") ("gkX") ("CgX" . t) ("Xt ") ("dXy") ("Xbb") ("fXn") (" jX") ("babasI Xlmu" . t) ("Xlumsuzdur" . t) ("arak Xlmus" . t) ("asInda Xn " . t) ("sunda yXk " . t) ("Cin Xldu " . t) ("ucu Xldu " . t) (" ile yXk " . t) (" iCin yXk" . t) ("ClIktan X" . t) ("de kXyu ") ("iden Xn " . t) ("Glam yXk" . t) ("I sXkup" . t) (" Xrdugu" . t) ("rI dXnd") (" en kXy") (" hXrt " . t) ("pXrsum" . t) (" Xluyu" . t) (" Xker" . t) ("presX" . t) (" Xnis" . t) ("Xlusp") ("gXne ") ("dXnay" . t) (" Xkse" . t) ("nkXr " . t) ("tXzum" . t) (" sXre") ("Xmuri") ("rXves" . t) ("gXmez") ("rkXru" . t) ("etXr " . t) (" Xtem" . t) ("dXven" . t) ("CXpur") ("bu Xn ") ("u Xn " . t) (" Xtuy" . t) ("dXrdu" . t) ("Xngor" . t) ("iXk " . t) ("kXko") ("Xrod") ("Xmea" . t) ("bXgr" . t) ("dXri") ("gXp ") (" ihX" . t) ("Xdeo") ("Xdug") ("izXr" . t) ("rXme") ("Xska") ("fiX") ("Xti") ("Xbi") ("Xrr") ("yaSInda Xldu " . t) ("an kXyun " . t) (" kiSi Xlu" . t) (" yeni yXk" . t) ("ogan gX" . t) ("ler Xn " . t) ("laya gX" . t) ("dnan CX") ("  kXyu ") ("Xlmusle" . t) ("orce X") ("un Xn " . t) ("Xburlu") ("baS dX" . t) ("ye dXn" . t) ("Xverm") ("Xdesa") (" ikX " . t) ("kXktu") (" Xpey" . t) ("Xngoz" . t) ("IlXte" . t) ("rXmiy" . t) (" Xrer" . t) ("Xkunt" . t) ("Xcunm") ("sXvd" . t) ("hXne") ("Xvid") ("jisX" . t) (" SXy" . t) ("gXru" . t) ("Xlv") ("OnX" . t) ("sanlar Xlu" . t) (" Xlunun " . t) (" kale Xn" . t) ("Xldugune" . t) ("Xldukle" . t) ("geri dX" . t) ("Xtariu") ("rXlant" . t) (" Xngur" . t) ("Xldule" . t) ("Xteler" . t) ("Xrdub" . t) ("schXn" . t) ("l Xke" . t) ("kXrpe" . t) ("Xguto" . t) ("Xgutl" . t) ("Xlcek" . t) ("Xntma") ("Xkule" . t) ("jXrk " . t) ("lpXz" . t) ("OrdX" . t) ("Xldo") (" Xrl") ("gXv ") ("rkXy" . t) ("Xvgu" . t) ("agXl" . t) ("fXz") ("Xsp") ("Xlk") ("Xdy") ("a dXnduruld" . t) (" van gXl" . t) ("nin Xnu " . t) ("  gXre ") ("sXnuyo" . t) ("k pXrc" . t) ("la Xn " . t) ("Xkulup" . t) ("Xrunde" . t) (" Xgud" . t) ("kXpug" . t) (" m X " . t) ("minXr" . t) ("Xnesc") ("Xtary") (" Xnge" . t) ("Xleg") ("yXng") ("CXml" . t) ("dXrn") ("sXvu" . t) ("Xniz") ("erXn") ("larak Xn " . t) ("l kXyun " . t) (" ile Xn " . t) ("n sXkup" . t) ("lIk Xn " . t) ("  kXyun" . t) ("Xnkolo") (" Xnsec" . t) ("173 X") ("kXper") ("mirXz" . t) (" Xsyo") ("Xksur" . t) ("Xkpit") ("Xregi" . t) (" Xnel" . t) ("kXyis" . t) ("sXgus" . t) ("kkeX" . t) ("CXme" . t) ("Xnev") ("SbXl" . t) (" fkX" . t) ("efkX") ("dXnk") ("Xnec" . t) ("IrXz" . t) ("Xdo") (" pX") ("Xno") ("r kXyunu") ("dXndurur" . t) ("n kXku " . t) ("ik Xn " . t) ("kOk sX" . t) ("isarX" . t) ("Xlude" . t) ("schrX" . t) (" Xruy" . t) (" Xrfi" . t) (" mXsy" . t) ("bXgur" . t) (" Xkke" . t) ("CXlun" . t) (" yXne" . t) ("nSXr" . t) ("fXtr" . t) ("syXd" . t) ("OsyX" . t) ("Xnma") ("odX") ("gXk" . t) ("arak Xld" . t) (" van gX") ("tuz gX" . t) (" Xperi" . t) ("Xkulu ") ("opXrta" . t) ("trXst" . t) (" Xylu") ("dXkup" . t) (" Xlse" . t) ("Xdess") ("Xkuml" . t) ("rXmor" . t) ("gXve") ("Xkuk" . t) ("Xbek" . t) ("Xndurule" . t) ("Si Xlmu" . t) ("wim kX") ("Xnlis" . t) ("1 Xz ") ("CkinX" . t) ("valXr" . t) ("trXm " . t) ("CXlu " . t) (" Xttu" . t) ("dXkmu" . t) (" Xtv" . t) ("bXke" . t) ("Xntu") ("bUtX" . t) ("dXnm" . t) ("Xbp" . t) ("rXner ") ("nXtro" . t) ("Xrelt" . t) ("gXng") ("rjXr" . t) ("Xkug" . t) ("kXkm") ("kXlesi" . t) ("Xktur ") ("179 X") (" Xrtt" . t) ("grXnl" . t) ("Xsemi" . t) ("vatX") ("Xtme" . t) ("Xkez" . t) ("gXlb" . t) ("oX") (" Xkmey") ("sXylul") (" SXval" . t) ("rolXr" . t) ("CXld" . t) ("UzXl" . t) ("tXri") ("Xlumsuzle" . t) ("lar Xn " . t) ("Xndura") ("178 X") (" Xnsa" . t) ("CXlas" . t) ("sXmes" . t) ("Xkula") ("tXmu") ("tXhm" . t) ("Xlo") ("prX") ("ve yXk " . t) ("Xperek" . t) (" Xkuz" . t) ("77 X") ("negX" . t) ("rlXr" . t) (" SXr") ("j gX" . t) ("Xyku" . t) ("eXn") ("OX" . t) ("Xu") ("Xlurse" . t) (" kXrdu" . t) ("Xkulme" . t) (" dXlle" . t) ("sIk gX" . t) (" nXro" . t) ("mos X") ("dXrt " . t) (" Xcu" . t) ("UmXr" . t) ("kXly") ("cXn") ("Xldukte" . t) (" en Xn " . t) ("sXgut " . t) (" Xten" . t) ("rXtus" . t) ("kXyum" . t) ("dXge" . t) (" kXyunu" . t) ("kXyc" . t) ("Xldugunde" . t) ("bir Xn " . t) ("ber Xn") ("kXrlu" . t) ("anXr " . t) (" Xrum" . t) ("lmX " . t) ("76 X") ("sXve" . t) ("sXvm" . t) ("oyXz" . t) ("Xnayak" . t) ("portXr" . t) ("ki Xn ") ("Xzon ") ("dXrs") ("aXf" . t) ("SdX" . t) ("Xtt") ("sXnuk" . t) (" Xc " . t) ("Xrpu" . t) (" stX " . t) (" Xrme" . t) ("Xyuk" . t) ("syXv" . t) ("njXr" . t) ("dXrm") ("Xpur" . t) ("uafX" . t) (" Xgr" . t) (" gXlet" . t) (" Xmurg") ("sXnen" . t) (" dXn ") ("Xnel ") ("Xkla") ("gXd") ("Xe") (" al gXr") ("dXkuyo" . t) ("2 Xz ") ("mXlle" . t) (" mXnu" . t) ("CXlle" . t) (" Xrf " . t) ("i Xn " . t) (" tXre" . t) ("sXrf" . t) ("tXvb" . t) ("blXf" . t) (" kXle " . t) (" Xpm" . t) ("Xrdek" . t) ("kXhne" . t) ("angX") ("bXls") ("anliyX" . t) ("  yXk " . t) ("asXr" . t) ("ntXr" . t) ("CXkm" . t) ("tfXy" . t) ("OfX" . t) ("CXkul") ("Xlumc" . t) ("hXm") (" kan gX" . t) (" Xptu" . t) ("ntrX " . t) ("rXtar" . t) ("lXrt" . t) (" Xib" . t) (" Xnso" . t) ("Xnn") ("Xlunce" . t) ("ansXr" . t) ("UktX" . t) (" yXruk" . t) ("sXylu ") ("kXrog" . t) ("kXlel" . t) ("Xran") ("zXz") ("Xksuz" . t) ("itXr" . t) ("kgX" . t) (" Xrul" . t) ("dXkumu" . t) ("yXner") ("oksXr" . t) ("CXl " . t) (" Xlul" . t) ("Xrdo") ("iSinin Xld" . t) (" Xkte" . t) ("bXll") ("In Xn " . t) ("in Xn " . t) ("Xpen") ("Xla") ("myX") (" Xrte" . t) (" rXnt" . t) ("CXktu" . t) (" Xlumd" . t) ("Xry") ("Xlcuk" . t) ("I Xn " . t) (" Xnk" . t) ("dXnduru") ("kXkun" . t) ("Xnz") ("kXfte" . t) ("sXke" . t) ("Xrek" . t) ("yXrun" . t) ("Xdur") ("dXktu" . t) ("lXrl" . t) ("bXce" . t) (" Xnlu" . t) (" Xnal " . t) ("Xrb") ("bXylu") (" Xle" . t) ("Xrtb" . t) ("Xyune " . t) ("Xtey" . t) ("Xndurma") ("Xlca") (" Xrs" . t) ("lX") ("Xrune" . t) ("tXn") ("kXrukl" . t) (" Xlume" . t) (" kXr " . t) ("kiSi Xldu " . t) ("Xye " . t) (" Xgut" . t) (" Xcal" . t) ("kXln" . t) ("Xted" . t) ("nXz") ("dXkum " . t) (" Xys " . t) ("Xktey") ("kXka") (" Xpu" . t) ("kXk " . t) ("bXbre" . t) ("bingX" . t) (" Xrtm" . t) (" Xss " . t) ("dXz") ("gXlt" . t) (" Xturu " . t) ("dXke" . t) ("kXyt" . t) (" Xva") ("Xnes ") ("Xsko") ("kXyde" . t) ("Xbet" . t) ("Xnca") (" dXse" . t) ("kXku") ("hXgh " . t) (" Xlumle" . t) ("SXhr" . t) ("Xo") (" rXva" . t) (" Xsy" . t) ("gXlh" . t) (" Xnyar" . t) ("ndX") ("kXsk" . t) ("CXke" . t) (" Xge" . t) ("Xlye" . t) ("dXru") ("kXpe" . t) ("tXz") ("Xdt") ("Xyunde" . t) ("Xporta" . t) ("Xrtm") ("kXste" . t) ("Xzan") (" Xmr" . t) (" kXyu " . t) ("mX") ("bXn") ("bXlu ") ("Xsa") (" CXp" . t) ("Xkme" . t) ("SXrt" . t) ("CXku" . t) ("yXz") ("Xbur" . t) (" Xnunu" . t) ("trenX" . t) ("aratX") ("Xktas " . t) (" Xte " . t) ("dXkul" . t) ("Xyme" . t) (" Xlme" . t) (" Xlu " . t) ("rXz") ("atXr" . t) ("SgX" . t) ("kXrfe" . t) (" Xgle" . t) ("IldX" . t) ("aktXr" . t) (" Xrtu" . t) ("yXre" . t) ("SofX" . t) ("gXlg" . t) (" Xv" . t) ("sXnm" . t) ("Xli") ("ofesX" . t) ("Xl ") ("Xfk" . t) ("Xlen" . t) ("nXnu " . t) (" sXndu" . t) ("Xmer" . t) ("Xtesi" . t) ("Xna") ("syX") (" Xtek" . t) ("kXz") (" Xlum " . t) ("Xmur" . t) (" kXk" . t) (" Xyk" . t) (" Xnde" . t) ("kXpr" . t) ("Xrle" . t) (" Xlumu" . t) ("sXn") ("ngXr" . t) ("Xnune" . t) ("kXse" . t) (" Xngo" . t) (" dXv" . t) (" Xnum" . t) ("pX") ("kXy " . t) ("Xylu" . t) (" Xlc" . t) (" Xldur" . t) ("Xnunde" . t) ("Xda") (" kXtu" . t) ("bXz") ("erXr" . t) ("Xren" . t) (" dXr" . t) ("gXl") ("Xnle" . t) ("ektXr" . t) (" Xrgu" . t) (" Xrne" . t) (" yXn" . t) (" Xd" . t) (" dXn" . t) (" bXl" . t) ("Xgre" . t) (" Xnc" . t) ("Xyle" . t) ("Xne" . t) ("Xz" . t) (" gX" . t) ("X") )
     (?s ("kut Xe" . t) ("a nurX" . t) ("lIXiyi") ("Xleriz") ("raXama" . t) ("de aX ") ("vard X" . t) ("irmeX " . t) ("gin Xo") ("k miX " . t) ("re fiX" . t) ("IXici ") ("oni Xe" . t) ("y yaXt") ("r gUlX") ("kafi X") ("UC Xu ") ("mum iX") ("i miX " . t) ("ce niX" . t) ("lal iX" . t) (" diXid" . t) ("Xalom " . t) ("a aXi " . t) ("a Xikl") ("lIlIXi") ("ce koX" . t) ("Xerket" . t) ("Xayand" . t) ("StU Xu") ("GuXuyl") ("hide X") ("Xtemil" . t) ("i Xovd" . t) ("lIr Xu") (" naXit" . t) ("e neXi") ("Xantar") ("at Xai") ("imi IX") ("nI Xea" . t) ("a k Xa") ("okum X") ("Sa Xok") ("bi IXi" . t) ("nU aXi" . t) ("puk iX" . t) ("tara X") (" hum X" . t) ("oli Xa" . t) ("83 baX") ("nU Xer") ("je baX" . t) ("nU eX ") ("k Xofo" . t) ("e Xak " . t) (" i Xad") ("e IXit") ("ir tuX" . t) ("vgat X") ("day Xu") ("nIXam ") ("IXitir" . t) ("Uk Xut" . t) ("or eXs" . t) ("yvan X") ("s miX " . t) ("ul beX" . t) ("yaXlad") ("rdu Xo") ("a aXiy") ("zUn Xi") ("ila iX") ("canlIX") ("mlayIX" . t) (" u yaX" . t) ("a poXu" . t) (" dilXe" . t) ("hurdaX") ("le duX") ("vefa X") ("r Xer ") ("n li X") ("e ma X" . t) ("oluXa ") ("55 yaX" . t) ("rtarIX" . t) ("lda Xu") ("Xkisis" . t) ("a CalX" . t) (" aGrIX") ("saGI X") ("yalleX" . t) ("ma eXk") ("leXem ") ("an leX" . t) ("deXtil" . t) ("kse Xu") ("saklaX") ("lafa X") ("is Xad" . t) ("ta a X" . t) ("beci X") ("me ayX") ("a neXi") ("git Xo") ("em eXk") ("Xahid " . t) ("tip aX") ("UktU X" . t) ("hak Xe" . t) ("tfak X") ("zade X") ("It beX" . t) ("t Xims" . t) ("GI aXt") ("e aXi " . t) ("SlI aX") ("i Xeke" . t) ("Gi paX") ("nlIXid") ("In Xex" . t) ("l beXl") ("ter Xo") ("e aXiy") ("vi yaX") ("tu baX" . t) (" Xive " . t) ("lina X") ("ruGu X") ("a iXli" . t) ("paXada" . t) ("pek aX" . t) ("sOz Xe") (" iXvel" . t) ("oklaXi") ("  gUlX") ("ah Xim" . t) ("ydar X") ("inan X") ("kIXtan" . t) ("sIk Xa") ("yanIXa") ("ak aXt") ("erdeX " . t) ("hta aX") (" Xadir" . t) ("ynir X") ("r aXa ") ("kCi Xu") ("ir a X") ("Cim Xu") ("udum X") ("kana X") ("r kloX" . t) ("Sah Xe" . t) ("ut aXk") ("k e Xo") ("um a X") ("mu muX" . t) ("boyXa " . t) ("z beXl") ("I 11 X" . t) ("dur Xo") ("Xoveni" . t) ("z taXa") ("Xenger") ("o kurX") ("tken X") ("ulayIX" . t) ("onla X") ("o karX" . t) ("Iz akX") ("Xlesti" . t) (" tarXi" . t) ("Xismik") ("boyu X") ("Xemaya" . t) ("cudu X") ("Sam Xu") (" ramuX" . t) (" han X") ("cU kiX" . t) ("ya aXt") ("nlUk X") ("poda X") ("iC akX") ("Xohben" . t) ("sI Xok") ("nlaXiy" . t) ("ski Xu") ("yaXlay") (" oy iX") ("ygulaX") ("Ximlik") (" al Xa") ("rISI X") ("IrI Xu") ("sOz Xo") ("r Xek " . t) ("ce kIX") ("Xansan") ("itiriX" . t) ("aXimiy" . t) ("kIXta " . t) ("niXant" . t) ("SI Xey") ("tlayIX" . t) ("yol Xe") ("tI paX") ("CUk Xu") (" ay Xu") ("Cine X") ("se keX") ("a birX" . t) ("di Xis") ("akarIX" . t) ("U manX" . t) ("en Xeh" . t) ("yuya X") ("ltI Xu") ("e iXka") ("enek X") ("ldI Xu") ("eriXe " . t) (" Xinci" . t) ("gI yaX") ("IXimiz" . t) ("n Xand") ("keleX " . t) ("yler X") ("garXi " . t) ("adaS X") ("ski Xo") ("t i Xa") ("zgeliX" . t) ("rUXen " . t) ("rdI Xu") ("en Xat") (" eniXt" . t) ("eraniX" . t) ("dUn Xa") ("e haXa") ("kanIXi") ("zeni X") ("aSI Xi") (" yaXiy" . t) ("dUXtu " . t) ("cu yaX" . t) ("amaXti" . t) (" kamaX" . t) ("vfik X") ("Xutunl") ("olaXi ") ("rizi X") (" en eX") ("zyIl X") ("er Xin") (" aXiri" . t) ("si Xin") ("ne aXt") ("yaklaX" . t) ("l keXi") ("Un kOX" . t) ("sayIXi") ("IXtir " . t) ("ISa Xu") ("laXtir" . t) ("rtti X") ("gOrUX " . t) ("  iXti") (" geliX" . t) ("oXunu ") ("nma Xu") ("Xiddd" . t) ("s eX ") ("Xisik" . t) ("embaX") (" bieX" . t) ("coXme") ("CIrIX" . t) ("mIXiy" . t) ("yeXar") ("UrneX" . t) ("alXim" . t) ("kUbaX") ("dataX") ("valIX") ("eXraf" . t) ("Xovul") (" raX ") ("laSIX" . t) (" eziX" . t) ("aiXet" . t) ("6 taX") ("Xanka" . t) ("kuXac") ("taXna" . t) ("oz eX") ("arkeX" . t) ("Xuyur" . t) ("Xtenk") ("mUXev" . t) ("imlaX") ("kavaX") ("niXim" . t) (" Xapo" . t) ("IpreX") ("aXisl" . t) ("yuXan") ("Xerhl" . t) ("lIyIX" . t) ("dUlXa" . t) ("Xehay") ("Xengi") ("Xarkk" . t) ("leXle" . t) ("aXrap" . t) ("daXki" . t) ("meXk " . t) ("bIXev" . t) ("ubeX " . t) (" Xakc" . t) ("aXaro" . t) ("raXer") ("aXere" . t) ("baXs " . t) ("nutuX" . t) ("Xinta" . t) ("Xeha ") (" iXev" . t) ("IG Xe") ("yaSIX" . t) ("uriX " . t) ("kiyiX" . t) (" OtUX" . t) ("taXab" . t) ("Xalk " . t) ("Xefaf" . t) ("uXin " . t) ("va aX") ("mIyIX") ("bIrIX") ("td Xt" . t) ("yh Xu") ("ll Xo" . t) ("iriXk" . t) ("ldaXa") ("inevX" . t) ("n CaX" . t) ("piXsi" . t) ("Xkodr" . t) ("nIXal" . t) ("koz X") ("luguX" . t) ("Xansk") ("S iXh" . t) ("tiXa " . t) ("menaX" . t) ("zabaX" . t) ("SavaX" . t) ("Xakse" . t) ("Ximov") ("aXmim" . t) ("SIyIX" . t) ("deXip" . t) ("olm X") ("hasaX") ("miXel" . t) ("Xenno" . t) (" kouX" . t) ("betiX") ("4 Xim" . t) ("z duX" . t) ("arXor" . t) ("tetiX") (" guX " . t) ("ornoX" . t) ("uke X") ("Xivir" . t) ("teXik" . t) ("Xlahl" . t) ("I Xei" . t) ("Xehi ") ("malaX") ("Xitta" . t) ("nnuXi" . t) ("haXem" . t) ("t Xe " . t) ("calaX") ("dediX" . t) ("uXtar" . t) ("nXlas" . t) ("suruX" . t) ("CiriX" . t) (" tUXu" . t) ("andeX") ("caroX" . t) ("p Xut") ("Xahim" . t) ("Xirfi" . t) ("aXalo" . t) ("OnleX") (" m aX") ("i c X" . t) ("Xongo" . t) ("i U X") ("Xuhed" . t) ("Xifay" . t) ("ee aX") ("39 Xu") ("siniX") ("uXtuy" . t) ("he iX") (" uXun" . t) ("zeniX" . t) ("c taX") ("guk X") ("Xirte" . t) ("ralIX") ("SetaX" . t) ("zkeX " . t) ("SaXan" . t) ("lalIX") ("hic X") ("mOnUX") ("y iXs" . t) ("It aX") ("ainiX") ("kroXo" . t) (" ibiX" . t) ("hlu X") ("sagaX") ("ciniX") ("Xuyuu" . t) ("h koX") ("kiXe " . t) ("Xahik" . t) ("jikiX" . t) ("GmIXi") ("mafiX" . t) ("canIX") ("luXti" . t) ("Xugun" . t) ("mUnXi" . t) (" dUyX" . t) (" unuX") (" niXi" . t) ("adeXl" . t) ("eXart") (" iriX") ("Xtimu" . t) ("911 X") ("Xangu") ("IltaX" . t) ("Xenor") ("Xakak" . t) (" iXey" . t) ("C ayX" . t) ("gUriX" . t) ("Xoyel" . t) ("75 Xe") ("ok X " . t) ("beyiX") ("bariX" . t) ("CiliX" . t) ("y muX") ("dIraX") ("Gu IX") ("yna X") ("eXebu" . t) ("tad X" . t) ("koniX" . t) ("Xkoli" . t) ("op Xo") ("ng Xu") ("IXins" . t) ("oXma ") (" lt X") ("susuX" . t) ("neXeb") ("geraX" . t) ("yaXma" . t) ("m I X") ("Xinto" . t) ("eviX ") ("ss iX") ("ngaXa" . t) ("gap X") ("tis X") ("OrkiX" . t) ("Xinsi") (" Xaze" . t) ("peniX") ("InIXa") ("luXab" . t) ("Ge Xu") ("reb X" . t) ("neXir" . t) ("lediX" . t) ("braXo" . t) ("zelXe" . t) ("eXtal" . t) ("Xetip" . t) ("Xaray") ("raXar" . t) ("ismiX") ("r ifX" . t) ("Xafii" . t) ("r Xud") ("geciX" . t) ("Xaki ") ("estiX") ("eS IX" . t) ("kUXe " . t) ("h Xak") ("kIbaX") ("msi X") ("halIX") ("ataXe" . t) ("CiXe " . t) ("4 Xer") ("ro Xu") ("Xenez" . t) ("kIzIX" . t) ("6 Xan") ("Xtuml") ("Xismo") ("000 X") ("Xihiz" . t) ("f Xat") ("leXek") ("taraX") ("rXahi" . t) (" leXe" . t) ("rUlUX" . t) ("dreXt") (" anuX" . t) ("kIt X") ("preXm" . t) ("chi X") ("hut X") ("peXen") ("t peX" . t) (" ahXa" . t) ("tleXt" . t) ("n ifX" . t) ("opluX" . t) ("eXeyd") ("fayaX") ("tIXiz") ("e oXi" . t) ("faXis" . t) ("uXurk" . t) ("Ximir") ("rdeXl" . t) ("ntraX") (" koXm" . t) ("aXhan" . t) ("oluXl" . t) ("zuluX" . t) ("UnUX " . t) ("uyuX " . t) ("our X") ("naXa ") ("uXurm" . t) ("miXil") ("e miX") ("e iXb" . t) ("Xbir ") ("iXinl" . t) ("bUcUX" . t) ("rC iX") ("gIdIX") ("reyXi" . t) ("taXak" . t) ("eSleX" . t) ("vgi X") ("kUrXa" . t) ("rmiXl" . t) ("rio X") ("laraX") ("Xabim") ("azmIX" . t) ("akXan") ("sokuX" . t) ("zeXin") ("emiXl" . t) ("Xtili") ("reXat" . t) (" 43 X") ("kiXan" . t) ("babaX") ("8 kiX" . t) ("ev Xu") ("fiXek" . t) ("Xumul" . t) ("UnleX" . t) ("p aXt") ("ritaX") ("omboX" . t) ("laXiz") ("Xagil" . t) ("eve X") ("boXa " . t) ("Xiga " . t) ("rXiya" . t) ("n Xih") ("CabaX") (" anaX") ("leXil" . t) ("varoX" . t) ("liXed") ("rkIXi") ("d Xen") ("S peX" . t) ("CeXin") ("iXmey" . t) ("nayaX") ("alliX") ("IXan " . t) ("miXe " . t) ("arIXa" . t) ("kiXis" . t) ("tesiX") ("Xkent" . t) ("riXim" . t) ("yeXim" . t) ("erleX" . t) ("sIraX") ("CalIX" . t) ("Xubw") ("piXp" . t) ("saaX") ("ziXa" . t) ("Xsaa" . t) ("iXre" . t) ("aiXn" . t) ("Xbar") ("nXah") ("Xirv" . t) ("Xnor" . t) ("yXec" . t) ("hU X") ("yIXm" . t) ("UraX") ("eyaX") ("I Xb" . t) ("jlIX") ("Xehl") ("hoXs" . t) ("Xkez" . t) ("Xomi" . t) ("abXe" . t) ("Xdig" . t) ("Xiru" . t) ("diXu" . t) ("GdOX" . t) ("UXir" . t) ("Xico") ("fiSX" . t) ("Xyin" . t) ("IXii" . t) ("crIX") ("uXey") ("OXer") ("Xhay" . t) ("yruX" . t) ("thaX") ("Xitc") ("utiX" . t) ("kahX") ("Xash") ("Xfan") ("Xenu" . t) ("beXd") ("Xenz" . t) ("uyX " . t) ("rpuX" . t) ("Xug " . t) ("gXor" . t) ("CkuX" . t) ("Xcii") ("pl X" . t) ("SikX" . t) ("Xuhp" . t) ("riXn" . t) (" pIX") ("nuXe" . t) ("Xasu") ("ayuX") ("uXba" . t) ("ukIX") ("IniX" . t) ("ryuX" . t) (" ilX" . t) ("Xiat") ("Xpay") ("Xkav" . t) ("keXo") ("yyuX") ("osaX") ("Xivg" . t) ("saXs") ("Xulg" . t) ("meXv" . t) ("Xeyc") ("omIX") ("egiX") ("SIXl" . t) ("ISIX" . t) ("ipaX" . t) ("GlIX") ("pIXl") ("aXgi" . t) ("rhaX") ("zUXu" . t) ("Ximt" . t) ("SapX" . t) ("Xvar") ("OXek") ("eXum" . t) ("uXuc" . t) ("daXd" . t) ("gUX " . t) ("nuXi") ("aXce" . t) ("ilXu" . t) ("Xapc" . t) ("tyaX") ("tyuX" . t) ("oXay" . t) ("guaX" . t) ("eXih") ("lnaX") ("zkuX" . t) ("yXab" . t) ("Xemu" . t) ("Xife") ("Xaso") ("iXoz" . t) ("speX") ("Xupa") ("bliX") ("Xyi " . t) ("Xney") ("Xfek") ("m3 X") ("eguX") ("hXar") ("vlaX") ("SviX" . t) ("eXam") ("oe X") (" yUX" . t) ("Xni " . t) ("SuXl" . t) ("vXam") ("braX") ("tuXi" . t) (" uXm") ("Xsay" . t) ("mpuX") ("nnoX" . t) ("tuXk") ("ttuX" . t) ("oXus" . t) ("oXup" . t) ("leaX") ("Xiku") ("Ximp") ("Xihl" . t) ("rraX") ("fuhX" . t) ("Xetb") ("smIX" . t) ("aXpo") ("aXuc" . t) ("ndUX") ("IsiX" . t) ("Xuuu" . t) ("uguX") ("vmiX" . t) ("Xtia") ("Xeyn") (" uSX" . t) ("uXuk" . t) ("IbaX" . t) ("SuX " . t) ("77 X") ("eXge" . t) ("pmiX" . t) ("Xsi ") ("Xeda") ("nmuX" . t) ("kiXo" . t) ("kmiX" . t) ("zmiX" . t) ("eXk ") ("ryaX") ("hXat") ("fliX") ("zbaX" . t) ("lmUX" . t) ("Xubi") ("Xset") ("iXab") ("UlaX") ("UnaX") ("UXva") ("iraX") ("Xai ") ("Xohr" . t) ("apuX") ("oXic") ("eXus") ("Xaac") ("iXay") ("aXem") ("uliX") ("Xeld") ("Xtis") ("graX") ("e Xt") ("binX") ("Xess") ("Xuro" . t) ("olXa") ("oXki") ("rUXv" . t) ("Xru " . t) ("uriX") ("rmUX" . t) ("tCIX") ("SmIX" . t) ("eXas") ("hiXa") ("inaX") ("SmUX" . t) ("rgiX") (" riX") ("umXu") ("cUXu") ("akiX") ("Xuri") ("ntIX") ("kaXm" . t) ("kXek") ("tlIX") ("Xizl") ("toXu") ("Xuzl") ("Xeci") ("lmaX") ("OXi") ("aX7" . t) ("bXl" . t) ("uX1" . t) ("mXl") ("axX" . t) ("Xtv") ("Xzm" . t) ("Xny") ("Xlm") ("Xsr") ("flX") ("fX ") ("Xbt") ("Xtj") ("uXn" . t) ("Xss") ("oIX") ("chX") ("Xty") ("Xuo") (" kX") ("lXh") ("Xkc") ("IzX") ("Xae") ("efX") ("utX") ("feX") ("nXu") (" Xk") ("Xaj") ("t in baXinda ") ("sunda baXina") ("in aXilmasiy") ("n ve baXini " . t) ("nlar yaXama ") ("vleri baXi" . t) ("eri baXinda ") ("Ginde yaXama") ("k onlarI iX" . t) ("kaldIrIXind" . t) ("slerin baXi") ("i yeni baXi") ("Unden baXin" . t) ("i de baXina" . t) ("Cindeki maX" . t) ("ile baXinin" . t) ("dan baXini " . t) ("masInda Xen" . t) ("seri nde iX" . t) ("a Cin in Xi" . t) ("u ve baXind" . t) ("erlerini aX") ("duGunu baXi") (" nin baXini" . t) ("e aXilmayac") ("iCtikleri X") ("Cin yaXama ") ("a dUnyada X") ("kilinin yaX") ("Iyla yaXama") ("srIn yarIX" . t) ("disini aXt") ("elecek yaX") ("dsi nin Xu") ("man baXind") ("on yarIXin" . t) ("Cin baXina") ("  baXindak") ("layI baXin") ("ra da baXi") ("n Once iXe") ("nlikle baX" . t) ("e anlaXin " . t) ("oyle bir X") ("  besiktaX") ("n besiktaX") ("dar baXina") ("or yaXama ") (" Cok yaXa " . t) ("k iCin Xok") ("alarI baXi") ("icilere Xu") ("Inda miloX" . t) ("i baXindak") ("dil yanlIX" . t) ("larIyla Xu") ("ak iCin Xu") ("e olan Xu ") ("alarInI Xu") ("steriXin " . t) ("hal gUreX") ("ap yanlIX" . t) ("Slerin aX") ("an baXkim" . t) ("na baXini") ("buraya Xu") ("ta baXina") ("eman kurX") ("bi baXind") (" kaldIrIX" . t) (" yeni iXe" . t) ("nin aXild") ("ama baXin") ("rI da Xu ") ("ra aXilac") ("el Xoyler" . t) ("yan baXin") (" dava Xu " . t) ("meyi baXi") ("re baXind") ("ane baXin" . t) ("stlar baX" . t) ("aSInda Xu") ("esiyle Xu") ("on yaXama") ("mer kaleX" . t) ("li baXina") ("r o nun X" . t) ("in yaXini") ("Syerini X") ("dinci baX") ("kInda yaX") ("o da baXi") ("a aXilmaz" . t) ("zaman Xen") ("lan baXin") ("ulusu baX" . t) ("lIGI baXi") ("her ne iX") ("nlarI Xu ") ("Ik aXilm" . t) ("en ekXi " . t) ("bile iXe" . t) ("sine Xut" . t) ("man Xik " . t) ("ep gOGUX" . t) ("eski taX") ("U baXina") ("s yaXin ") ("S yaXama") ("m ilk iX" . t) ("onun iXe" . t) (" aXmayal") ("n de iXe" . t) ("et Xansa") ("dece iXe" . t) ("ade Xik " . t) ("len Xam ") ("elim yaX" . t) ("rIn yaXi") ("I Xanlit") ("  bu Xu ") ("Siyi iXe" . t) ("pille iX" . t) ("rdi baXi") ("ganI yaX") ("an Xaka ") ("re aXilm") ("naya baX") ("sene baX" . t) ("smini aX") ("ki taXi ") ("m yaXin ") ("a gene X") ("ereden X") ("kiden Xu") ("rdeki Xu") ("azin baX") ("mun Xeri" . t) ("cdet baX") ("la aXilm" . t) ("man iXme" . t) ("hyol iXe" . t) ("can Xen ") ("sIr da X") ("daha Xu ") ("bun baXi") ("I beXte " . t) (" an kurX") ("emen iXe" . t) ("zli Xirk" . t) ("ir eXin " . t) ("p de baX" . t) ("Once iXe" . t) ("ak miloX" . t) (" bin yaX" . t) ("um baXin") ("SCiyi iX" . t) ("nlar kaX") ("u baXina") ("ller aXi" . t) ("arasI Xu") ("k beXte " . t) ("sIz baXi") ("asan meX" . t) ("yasa taX") ("u daki X") ("le yarIX" . t) ("zor kaX" . t) ("blo Xu " . t) ("yaraXan" . t) ("Gur kOX") (" Su iXe" . t) ("met akX" . t) ("U faSiX" . t) ("anI iX ") ("GI baX ") ("vrim Xe" . t) ("GI Xik " . t) (" aXimiz" . t) (" Xanda " . t) ("yetiXin" . t) (" aXinda") ("Xarkisy") ("haXani " . t) ("on baX ") ("piXtim " . t) (" ka laX" . t) ("a Xoke " . t) ("aha iXe" . t) ("tanIXin") (" araXiy" . t) ("gemi Xu") ("Ska iXe" . t) ("san aX " . t) ("masabaX" . t) ("e iXimd" . t) ("kle iXe" . t) ("er baX ") ("ap baXi") (" aXimi " . t) ("nli Xu ") ("ti kurX") ("Gu yaXi") ("ok yaX ") ("y de Xu") ("na aXar") ("n baXal" . t) ("eye Xut" . t) ("sse baX" . t) ("Uk yaX ") ("alI aXa") ("Xevketl" . t) ("In taXl" . t) ("pa baXi") ("Xahabet" . t) ("yikli X") ("I Xoke " . t) ("al Xen " . t) ("en Xis " . t) ("amIn Xu") ("InI peX" . t) ("lle baX" . t) ("han kOX") ("Unya Xu") ("alI Xu " . t) ("  iXmen" . t) ("ir Xokt" . t) ("nan Xu ") ("azIlIXi") ("Ina aXt") ("na aXan") ("Ik kurX") ("ek Xan " . t) ("en ayXi") ("nI bahX" . t) ("hane Xu" . t) ("riz aXi" . t) ("trafI X") ("Ci baX ") ("SarIlIX") ("ce yaXl" . t) ("de yaXl" . t) ("gende X") ("skin Xi") ("taXarak" . t) ("r kayIX" . t) ("  baXim" . t) ("m baXim" . t) ("ste baX" . t) ("Xevkini" . t) ("baXindi") ("are baX" . t) ("e aXma ") ("tme yaX") ("ebe baX" . t) ("kten Xu") ("aXlaniy" . t) ("in kaXl" . t) (" tonkuX" . t) ("dur yaX") ("llar Xu") ("an Xisl") ("IndaXin") ("I aXmal" . t) (" ne iXi" . t) (" Xutun ") ("e Xutu") ("Xutunu " . t) ("temiz X") ("Xecerel" . t) ("en erXe" . t) ("aXarsa " . t) ("i Xeydi") ("en beXt") ("yaXamiz") ("GU ne iX") ("i ne iXe") (" ne iXe" . t) ("na bahX" . t) ("aXiyan " . t) ("d baXin") ("aXardi " . t) ("rIn peX" . t) ("akXamis") (" suXa " . t) ("Xatiro" . t) ("dI niX" . t) ("m miX " . t) ("n Xom " . t) (" ekXit" . t) ("hap aX") ("iel Xa" . t) ("di niX" . t) ("paXakl") ("Xaril " . t) ("cevanX" . t) ("y ariX" . t) ("tiliXi" . t) ("piXik " . t) ("taXis ") (" iXkin" . t) (" aXmaz") ("e aXsa" . t) ("Xendir" . t) ("Xarhoy" . t) ("maviX " . t) ("kaXeyl" . t) ("Xarkik") ("olibaX") (" eliXi" . t) ("t Xama" . t) ("k Xikt" . t) ("t Xik " . t) ("nlaXa ") ("e Xeyd") ("Xoylek" . t) ("aXkul ") ("cuzlaX") ("yaraXl" . t) ("Xovuyo") ("Xiril " . t) ("uzlu X") ("hteriX") ("p miX " . t) ("kiXin ") (" kIXiy") ("siliXl" . t) (" tIraX" . t) ("kalmiX") ("kadreX" . t) (" Xeniz" . t) ("r Xal " . t) ("kkalIX") ("igiriX") ("a Xas ") (" Xikid" . t) ("kXili " . t) ("l alaX" . t) ("ne aXm") ("nI eX ") ("mUze X") ("Xkonse" . t) ("  Xar ") ("epreXe" . t) (" Xemis" . t) ("na fiX" . t) ("ur Xun" . t) (" deXiy" . t) (" deXer" . t) ("ki aX ") (" biXi " . t) ("el avX") ("Ga Xov") ("azalIX" . t) ("beXler" . t) ("faltaX" . t) ("IXitan" . t) ("fa Xut" . t) ("ikalIX") ("ap Xap" . t) ("Xehven") ("mla Xu") (" traXi" . t) (" ayXin" . t) (" Xande" . t) ("l Xut " . t) ("Xermin" . t) ("ldaXin") ("of Xen" . t) (" atlaX") (" az Xu") ("marXiy" . t) ("damIXi") (" kadIX") ("iz aXm") ("arakeX" . t) ("z Xas ") ("din Xo") ("un arX") (" Xenti" . t) (" Xort " . t) (" paXay" . t) ("l baX ") ("aca aX") (" maraX" . t) ("Xaplak" . t) ("leXele") ("yaXsa " . t) ("taXliy") ("ltIraX" . t) ("nti Xu") ("mail X") ("baXars") ("fiS aX") (" iXti " . t) ("IXilik" . t) ("saim X") ("deXilm" . t) (" nI aX" . t) ("l kurX") ("rli Xu") (" temiX") ("Une Xu") ("leXemi" . t) ("I Xip " . t) ("ddileX" . t) ("baXsa ") ("eltraX" . t) (" reXim") ("rgun X") (" aXin ") ("18 yaX" . t) ("cer Xa") ("Xenli ") ("zelleX" . t) ("aSarIX") ("e ulaX" . t) ("SiktaX" . t) ("hIXir" . t) ("Xaftt" . t) ("Xuhut" . t) (" teXn" . t) ("Xuand" . t) (" yumX" . t) ("zereX" . t) ("COrUX" . t) ("Xbaya") ("iapaX") ("a Xb " . t) ("  CiX" . t) ("Xamon" . t) (" adIX") (" Xeca" . t) ("monaX") ("areXa" . t) ("Xutuy" . t) ("Xeydo") ("gItIX") ("Xidet" . t) ("basIX" . t) ("menXa" . t) ("tasiX" . t) ("rdaXa") ("lahoX") ("inkiX" . t) ("zanIX" . t) ("akmuX") ("kaXes" . t) ("inXat" . t) ("Xmany") ("uyuXl" . t) ("Xendu" . t) ("UXrik" . t) (" iXer" . t) (" Xuh " . t) ("Xeyy " . t) ("tIXim" . t) ("  Xoo" . t) ("tutaX" . t) ("ahaX ") ("yoveX" . t) ("yavuX" . t) ("kai X" . t) ("palIX") ("tepiX" . t) ("kaXer" . t) (" maXi") ("rkaX " . t) ("haXa " . t) ("Xbiht" . t) ("hlaXl") ("libeX" . t) ("tIrIX") ("lunuX" . t) ("Xivey" . t) ("Xikec") ("bediX" . t) ("Xambr" . t) ("baSaX" . t) ("tt IX") ("tibaX") ("Xtahb") ("umpaX") ("o aXi") ("Xovup") ("beXa ") ("ekkaX" . t) (" Xad " . t) (" Xaas" . t) ("la tuX" . t) (" tuX ") (" aXas") ("celeX") ("SUnUX" . t) ("kuXti") (" aiXe" . t) ("Xakad" . t) (" i X " . t) ("OXem ") (" ho X" . t) ("oka X") ("Xeyyy" . t) (" CakX" . t) ("kUp X") ("Xippa" . t) (" Xipi" . t) ("Xahiz" . t) ("tleXs" . t) ("okleX") ("ronXi" . t) ("lIXim" . t) (" laXm" . t) ("Xaffa" . t) (" mIXt") (" taXy" . t) ("zeXe ") ("Oy aX") (" iXen") (" Xih " . t) (" Xukl") ("p duX") ("m 7 X") ("UzleX" . t) ("paXab" . t) ("iXlin") ("amboX") ("aliXm") ("koluX" . t) ("hXete" . t) ("oplaX") ("diXis" . t) ("Xikag" . t) ("6 niX") ("Xafag" . t) ("Xaziy" . t) (" fiXl" . t) ("kamIX" . t) ("Xivel" . t) ("ynarX") ("ynaXt" . t) ("IndiX" . t) (" eciX" . t) ("haXla" . t) ("nXall" . t) ("aXdir" . t) ("tiXma") ("p kaX") ("urmuX" . t) ("daXim" . t) ("ehveX" . t) ("Xela ") ("naXin") (" leXi" . t) ("iXmin") ("gIzIX") ("aXtam") ("r peX" . t) ("chriX") (" pekX" . t) ("iXmi ") (" olaX") ("Xatis") ("kleXt" . t) ("iXile" . t) ("Xubl") ("vyaX") ("nvaX") ("C X " . t) ("Xnag" . t) ("OXur" . t) ("goaX") ("Xesh" . t) ("iXov") ("Xezl" . t) ("iaXe" . t) ("zeXt" . t) ("haaX") ("aluX") ("Xass") ("IXaf") ("Xakr" . t) ("IXiv" . t) ("UXat" . t) ("Xviy") ("Xarc") ("zbeX" . t) ("Xamc" . t) ("Xeto") ("iXai") ("iCXa" . t) ("Xcie") ("Xubs") (" nIX") ("SXaf" . t) ("ruXs") ("tUSX" . t) ("ytUX" . t) ("SkOX" . t) ("pUXo" . t) ("SipX" . t) ("buXa") ("aXe ") ("laXh") ("daXa" . t) ("khoX") ("Xnin" . t) ("oXin") ("Xcev" . t) ("ilaX") ("SaaX") ("mlIX") ("erXt") ("lhaX") ("fXaa" . t) ("obUX") ("Xehr" . t) ("mevX") ("Xing") ("Xeyu") ("aXap") ("Xay ") (" uXt") ("boXi") ("apiX") ("Xlim") (" siX") ("asiX") ("breX") ("mXen") ("SbaX" . t) ("umuX" . t) ("aXhi") ("kraX") ("Xica") ("q X") ("kXc") ("Xbc") ("Xmd" . t) ("dyX") ("jaX") ("Xf ") ("Xie") ("Xo ") ("Xea") (" oX") ("cIX") ("seX") ("Xep") ("hyol un baXi") (" nIn yaXama") ("ken baXini ") ("yanlar Xu ") ("deri fatoX") ("indeki Xu ") (" metin kOX") ("lerden Xu ") ("lar baXina") ("Xemalarini" . t) ("ndi baXini" . t) ("ler baXina") ("may I baX") ("ettin Xen" . t) ("a koXtum " . t) ("Gil baXin") ("eti baXin") ("eden baXi") ("zIlI baXi") ("un baXini" . t) ("rInI baXi") ("nelin iXe" . t) ("para baXi") ("in yanlIX" . t) ("e ve Xu ") ("met Xen " . t) ("resim iX" . t) ("a haXim ") ("e haXim ") ("st sUrUX" . t) ("la iXim " . t) ("SIma Xu ") ("Ci yarIX" . t) ("z ve Xu ") ("zca baXi") (" aXiliyo" . t) ("In ekXi " . t) ("n Xeydi ") ("Gi yarIX" . t) ("a haXir " . t) ("hem baXi") ("a yaXlan") ("te yarIX" . t) ("  Xundan" . t) ("mi baXin") ("ayak baX") ("ece Xik " . t) ("ar aXilm" . t) ("  yanlIX" . t) ("Xisinda " . t) ("uldan iX" . t) ("e yanlIX" . t) ("por baXi") ("gut Xen" . t) ("u Xutu " . t) ("Xoyleym" . t) ("beXten " . t) ("bah iXe" . t) (" IXini " . t) ("ne yaX ") ("el Xik " . t) (" kantaX" . t) ("sI Xam ") ("tle iXe" . t) ("nI aXka") (" Xiklig" . t) ("6 yarIX" . t) ("ice Xu ") ("l ve Xu") ("m Xuna " . t) (" iXteki" . t) ("Ika baX") ("k Xuna " . t) ("el Xeke") ("ne Xis " . t) ("ziz ekX" . t) ("ayandaX") ("Xirkeli") ("Xarkis ") ("ele iXe" . t) ("k Xirk " . t) ("saG baX") ("Ur baXi") ("us baXi") ("z Xuna " . t) ("an beXt") ("cU kurX") ("Xekvac" . t) (" akkaX" . t) ("Xarkoy" . t) ("da aX ") ("Xeyder") ("Xoktan" . t) ("pis Xu") (" yumaX" . t) (" uXsal") ("Xantan") ("kandiX" . t) (" tebaX") ("GuXuna") ("jak eX") ("yarImX" . t) ("I Xas ") ("yanarX") ("kuXuyo") ("Xavata" . t) ("Xasinl" . t) ("laXam ") (" diXiy" . t) ("ndiriX" . t) ("yboluX" . t) ("l Xam ") ("baltaX") (" rOveX" . t) ("niXanc" . t) ("atIk X") ("Xokta " . t) ("niXtik") ("va Xu ") (" parIX") ("a aXip") ("e Xove") (" seyiX") (" meXin" . t) ("tre Xu") (" eXten" . t) ("in aXt") (" kIXik") ("Ip iXe" . t) ("IXalim" . t) ("taXlad" . t) (" kIXip") ("let Xu") ("k taXlam") ("taXlam" . t) (" aXmal") ("Il aXi" . t) (" Xisti" . t) ("sen Xo") ("Xaksak" . t) ("leXel ") ("miXlig" . t) ("Xiklar" . t) ("iyileX" . t) ("apIXin") ("araXti" . t) ("konuXt" . t) ("aXkisi") ("mayIX ") ("yaXli " . t) ("Xlika") ("Xenca" . t) ("araXs" . t) ("traXa" . t) ("lpaX ") ("Xavki" . t) ("Xteru") ("i bXk" . t) ("rusiX" . t) (" IXim" . t) ("paXak" . t) (" neX " . t) ("iXist" . t) ("aXane" . t) ("C aX ") ("0 aXa") ("ataXt" . t) ("Xvili" . t) ("Xovda" . t) ("UveyX" . t) ("Xuhub" . t) ("gedaX") ("fatoX" . t) ("lagaX" . t) ("elkIX") ("SikaX" . t) (" Xenb" . t) ("yiyiX" . t) ("Xindu") ("aXado" . t) ("iXmer" . t) ("yuXul" . t) ("aXsor" . t) ("uXamb" . t) ("Xarkl" . t) ("kaXli" . t) ("Xifai" . t) ("abiXe" . t) (" Xuym" . t) ("dUnUX" . t) (" Xuka") ("Xubab") ("4 Xu ") ("Xambl") (" uXa ") ("Xeyis") ("efriX" . t) ("rtUXe" . t) ("CamaX" . t) ("Xelik" . t) ("OktaX" . t) ("kuXar") ("nXira" . t) ("kIrIX" . t) ("U kaX") ("yaSXa" . t) ("keSiX" . t) ("diXer" . t) ("mibeX" . t) ("yeXe ") ("sabiX" . t) ("Xkill" . t) ("Xerh " . t) ("fataX") ("maaaX" . t) ("Xiven" . t) ("tIXir" . t) ("varIX" . t) ("yanuX") ("Xele ") (" aXev" . t) ("rataX" . t) ("yeXte") ("ahriX" . t) (" alIX" . t) ("Xerri" . t) ("Xayia" . t) ("aXant" . t) ("e peX" . t) ("iriXt" . t) (" Ximd" . t) ("oXman") (" maXt") ("aXlat" . t) ("Xikta" . t) (" yUkX") ("iXtan") (" IXd") ("mXor" . t) ("GdiX" . t) ("thoX") (" SeX" . t) (" rIX") ("duXl" . t) ("kaXc") ("lapX" . t) ("Xish" . t) ("SbeX" . t) ("Xpem") ("cmiX") ("iXl " . t) ("ahXo" . t) ("zaX ") ("taXg" . t) ("oooX" . t) ("llIX") ("aXle") ("yaXm") ("Xkad" . t) ("Xehe") ("Xmat") ("cUX " . t) ("Xsut") ("triX") ("neXc") ("uvaX") ("puXt" . t) ("phoX") ("SmuX" . t) ("efiX") ("aGuX") ("iCiX" . t) ("Xmit") ("iteX") ("uXut" . t) ("oliX") ("baXl" . t) ("IXf") ("OX ") ("IaX") ("iXz") ("ouX") ("auX") ("cuX") ("ceX") ("Xon") ("Xq") ("ile yaXama ") ("iden yaXam" . t) ("ci yaXama") (" diye iXe" . t) ("ili yaXin") ("aile baXi" . t) ("ri baXina") ("i duruXu") ("aki Xik " . t) ("Se baXin" . t) ("I ve Xu ") ("n yaXin ") ("prak Xu ") ("e yaXlan") ("Gine Xu ") ("GIr baXa") ("sI baXin") ("ik yarIX" . t) (" sarIXin" . t) ("ek yarIX" . t) ("eklere X") ("ki baXin") ("u yanlIX" . t) ("ara aXt") ("ve baX ") ("hiC Xu ") ("raGI aX") ("en Xane" . t) ("e Xerai" . t) ("le haXi" . t) ("stekleX") ("n Xara " . t) ("ail a X") ("n Xahi " . t) ("mek Xu ") ("kart aX") ("baXarla") ("tanIXir" . t) ("rIna aX") ("Xarkiyo") ("baXiniz" . t) ("SlaXa ") ("eXirin") ("kaXkar" . t) (" moXe " . t) ("na aXm") ("taXlas" . t) ("taXark" . t) ("IXtirt" . t) ("haXin " . t) (" Xurda" . t) ("Xirke ") ("faXit ") ("haXiml") ("d yaXi") ("rt Xut" . t) ("CIklaX") ("ce aXt") ("Xahase" . t) (" dalIX" . t) ("rtemiX") ("iveriX") ("ulya X" . t) ("Xenses" . t) (" finiX" . t) ("le i X" . t) ("OrtUXt" . t) (" Xemil" . t) ("kalleX" . t) (" a Xev") (" tInIX") ("zanlIX") ("rlaXa ") ("rundaX") ("okuyuX" . t) ("takIXi") ("Is a X") (" kaXi " . t) ("ydoGuX") ("Xeydis") ("laXiyo" . t) (" mIXs") ("nureX" . t) ("Xmeka" . t) ("eXarp" . t) ("aXtun" . t) ("OnkaX" . t) ("Xakag" . t) ("Xarto") (" iXyu" . t) (" piXe" . t) ("talIX") ("mahXe" . t) ("UrUX " . t) ("aXime") ("huXu " . t) ("Xubap") (" Xeny" . t) ("Xifah" . t) (" taXp" . t) ("Xahha" . t) ("paXas" . t) ("kotaX") ("Xefir") ("Xevka" . t) (" eSXe" . t) ("Xerht" . t) ("nayIX" . t) ("Xmann") ("priXt" . t) ("beXir" . t) ("mabaX" . t) ("Xtirh") ("Xubar") (" Xuks") ("SayIX" . t) ("Xikir" . t) ("nanIX" . t) (" aloX" . t) ("iXeme" . t) (" Xato" . t) ("aXsiz" . t) ("GlaXa") ("paXan" . t) ("Xsek " . t) (" okuX") ("Xabiy") ("leXip" . t) (" SakX" . t) ("emXir" . t) ("variX") ("tutuX" . t) ("Xira ") (" Xtl" . t) ("oXav") ("Xsie") ("oboX") ("SlIX") ("SaXe") ("vXal") ("mtaX") ("ruXo") ("shaX") ("nuXk" . t) ("mUXk" . t) ("fyaX") ("ruXi") ("taXb" . t) ("kiXn" . t) ("IyaX") ("eXic") ("pXir" . t) ("UXer" . t) ("rSIX") ("Xgal" . t) ("iXtl") ("kkuX" . t) ("lbaX" . t) ("rasInda baXin") ("n Xutunda " . t) ("yarak iXe" . t) ("  yaXama ") ("u yaXama ") ("re yarIX" . t) ("can Xunu") ("Cin yaX ") ("dIS baXi") ("dUn baXi") ("el baXin") ("a ve Xu ") ("ne baXa ") (" marXa " . t) ("her iXe" . t) (" Xilan " . t) ("hir kOX") ("kaXigi " . t) ("onuXun " . t) (" aXilar") (" Xanlim") ("Cok iXe" . t) (" aXilip" . t) ("yaXadir") ("taXland" . t) ("rt baX ") ("  ekXi " . t) ("  yaXin") ("Xullah" . t) ("oleyiX") ("rtabaX") ("  koX ") (" baXis") ("Xereme" . t) ("Xikki " . t) ("ve iXe" . t) ("ait aX") ("Xamari" . t) (" kIXi " . t) ("amanaX" . t) ("lI Xu ") ("mUXtek" . t) ("i Xarv" . t) ("armaX " . t) ("eman X") ("Xterih") ("hIXiml" . t) (" aXarl") ("zveriX") ("keXis " . t) ("skolaX") ("baXim ") ("im Xab") ("Xokuyl" . t) ("miXsin" . t) ("uyanIX" . t) ("rik Xu") ("lk beX" . t) ("Xurani" . t) ("birXey" . t) ("y Xere" . t) ("Xakar " . t) ("betleX" . t) ("paylaX" . t) ("rUkUX" . t) ("Xenku" . t) ("lakuX" . t) (" eXip") ("cayiX" . t) (" CiXi" . t) ("oulaX") ("ekeX " . t) ("o Xun") (" Xilt" . t) ("dOGUX" . t) ("Xkire") ("kiriX" . t) ("rciX " . t) ("Xakka" . t) ("timaX") ("mIXi " . t) ("hi Xu") (" raXm") ("Xeyeh") ("kaXar" . t) ("atraX") ("IXinc" . t) (" Xti " . t) ("Xalte" . t) ("Xahap" . t) ("ediX " . t) ("Xives" . t) ("s kIX") ("nuluX" . t) ("Xataf" . t) ("gUlUX" . t) ("ontaX") (" eleX" . t) ("Xevkl" . t) ("hadiX") ("kiXd" . t) ("guXe" . t) ("OniX" . t) ("Xmav") ("Xahb" . t) ("Xuke") ("aXao" . t) (" daX") ("zoXi" . t) ("ddaX") ("Xofb" . t) ("Xevl" . t) ("yeX ") ("eyXa" . t) (" iXc" . t) (" dIX" . t) ("Xdu" . t) ("orX") ("en yaXama ") ("  baXinda ") ("ken Xen ") (" Xiklik " . t) ("vara aX") ("kdire X" . t) ("n Xutu " . t) ("n aXild" . t) ("sel ekX" . t) ("yol Xu ") ("len Xu ") ("m yarIX" . t) ("Xuheyd" . t) ("Xakaci" . t) ("boXta " . t) ("ton Xu") ("Xilili" . t) ("Ximsir" . t) (" aXtir") ("Xarkit") ("rdak X") ("tlaXa ") ("s baX ") (" arXin" . t) ("rdaXin") ("mUXur" . t) ("ukaXe" . t) ("aXalt" . t) ("ifXa " . t) ("nakaX" . t) ("InmeX" . t) ("labaX" . t) ("vebaX") ("keXan" . t) ("onXim" . t) ("Xirre" . t) (" Xahp" . t) ("Xkemb" . t) (" elaX") ("didiX" . t) ("trbaX") ("sOGUX" . t) ("hu Xa" . t) ("Xabi ") ("Xevar" . t) ("Guk X") ("Xehir" . t) ("aXiye") (" irX" . t) ("hXa ") ("hrIX") ("ferX") ("oXid") ("IsaX") ("aXoc" . t) ("kteX") ("Xuay" . t) ("Xyen") ("laXy") ("draX") ("Xs ") ("eiX") ("suX") (" yeni yaXama") ("In baXinin " . t) ("ya baXini") ("basa baX") ("tI baXin") ("cI baXin") (" Xisler") ("Xendil" . t) ("eklanX" . t) ("mastaX" . t) ("etiXin") (" beleX" . t) ("menekX" . t) ("taXtik") ("g Xam ") ("tabaXi" . t) (" diXim" . t) (" neXte" . t) (" kalIX" . t) ("SanlIX") ("iXter ") (" meXe " . t) ("rkadaX" . t) ("almuX") ("Xampu" . t) ("baXkl") (" inX " . t) (" eXe " . t) ("Xiris" . t) ("Xsoy " . t) ("dalaX" . t) ("mUXuz" . t) ("fadoX" . t) ("yabaX" . t) ("traXl" . t) ("keXli" . t) ("rlIXi") (" narX") ("niXli" . t) ("eXkal" . t) ("aXkil") ("arXim" . t) (" abaX") ("rgaXa" . t) ("Xaniz") ("aXima" . t) ("pekiX" . t) ("yahX" . t) ("Xahm" . t) ("Xuby") ("viXn" . t) ("ldiX" . t) (" CoX" . t) ("kveX" . t) ("amiX") ("Xuso" . t) ("nbaX" . t) (" nuX") ("spaX") ("Xade") ("nyaX") ("sIX") ("xaX") ("cIX") ("dan baXina") ("ni baXina") (" akXama " . t) ("  bu iXe") ("ruk Xen" . t) ("mandaXi") ("yaXayis" . t) ("g yarIX" . t) ("rek iXe" . t) ("v yarIX" . t) ("layIXin" . t) ("aXile " . t) (" rakIX") (" iXhan" . t) (" taXa " . t) ("aXayin" . t) (" Xenal" . t) ("taXla " . t) ("dinleX") ("dUXtur") ("ankuX" . t) ("yalIX") ("eXite") ("Xukut") ("n aX ") ("Xenka" . t) (" Xar " . t) (" Xisk" . t) ("pIXir" . t) ("ahaXk" . t) ("UlXen" . t) ("UkerX" . t) ("Xinim") ("Xartr") ("ayXen" . t) ("OvaX" . t) ("amUX") ("Xanv" . t) ("uXas") ("Xces" . t) ("Xiad") ("muaX") (" IXa") ("laXk") ("amuX") ("Xubu") ("bIX") ("ir yanlIX" . t) ("iz baXin") ("k ve Xu ") ("n beXte " . t) ("ran kurX") (" Xahan " . t) (" niXani" . t) ("Xenel " . t) ("Xamata" . t) ("baXabi") ("Xovmen" . t) ("marXla" . t) ("iXtiga" . t) (" Xadan" . t) ("la iXe" . t) ("Xalvar" . t) (" mayIX") ("kateX" . t) ("estaX" . t) (" aXko" . t) ("OkkeX" . t) ("baXel") ("faXil") ("aykuX" . t) ("kunuX" . t) (" Xanz" . t) ("panIX" . t) ("natIX") ("artiX") ("iXime" . t) ("Xevv" . t) ("Xzam" . t) (" saX") ("hdaX") ("ovaX") ("nzeX" . t) ("Xad ") ("aSIX") ("diXb" . t) ("bUXr" . t) ("tmIX" . t) ("vXir" . t) ("iyaX") ("Xic ") ("aIX") ("mXa") ("waX") ("e baXindan" . t) ("lIk yarIX" . t) ("rak baXin") ("man aXim" . t) ("bir Xu ") ("et paXa" . t) ("t yarIX" . t) ("l yarIX" . t) ("baXark") ("Ir neX" . t) ("titreX" . t) (" seviX" . t) ("iniXin" . t) ("leXeme" . t) (" yaGIX" . t) ("uXkin " . t) ("Xahak" . t) ("hibaX") ("Xifal" . t) ("Xakay" . t) ("Xiraz" . t) ("dabaX" . t) ("deXik" . t) (" Xang" . t) ("pIXil" . t) ("leXeb" . t) (" neXe" . t) ("iriX " . t) ("Xarab" . t) ("Xenay" . t) (" uluX") ("jerX") ("IdaX") ("hSiX" . t) ("InIX" . t) ("laXu") ("teXr" . t) ("Xehp") ("kiXo" . t) ("meXk") ("paXt") ("hmuX") ("boXl" . t) ("Xeo") ("ciX") ("an baXini") ("ve yarIX" . t) ("  baXina") ("ra baXin") (" Xanlik") ("Xarkint") ("e aXilm" . t) ("an Xen " . t) ("rk baXi") ("beXin ") (" akXit" . t) ("UkeniX" . t) (" kaXiy" . t) ("konuX " . t) ("birleX" . t) ("rIXil" . t) ("mpraX") ("Xortl" . t) (" fiXi" . t) (" itiX" . t) (" Xips" . t) ("Xemas" . t) ("eXanl" . t) ("metiX") ("dolaX" . t) ("danIX" . t) ("Xural" . t) ("OkXi" . t) ("kaXg" . t) ("ShaX" . t) ("Xeft" . t) ("kbeX" . t) ("hhaX") ("Xcas" . t) ("beXm") ("Xso") ("da baXinda ") (" el Xar" . t) ("steriX " . t) ("vanda X") ("Xerbet" . t) (" Xentu" . t) ("Xahidi" . t) ("Xtirah") (" biXey" . t) (" aXisi" . t) ("Xmeke" . t) ("kopuX" . t) ("Xeyid") ("eXbas" . t) ("Xuray" . t) ("tokuX" . t) ("laXak") ("iflaX") ("miXim" . t) ("ohoX") ("koXo") ("aXaf") ("IXak") (" UXe" . t) (" Xia" . t) ("Xubj") ("uXog" . t) ("Xunc" . t) ("Xmir" . t) ("UXf" . t) ("UmX") ("me yarIX" . t) ("ener Xen" . t) ("Xoyledir" . t) ("y OlCUX" . t) ("raXid " . t) ("ambaXi") (" Xunun" . t) ("laXali" . t) (" Xahla" . t) ("Xanar " . t) ("menteX" . t) ("CarXi " . t) ("nakkaX" . t) (" Xule " . t) ("marXin" . t) ("ziliX" . t) ("mekeX" . t) (" Xike" . t) ("baXci") (" Xemd" . t) (" duX " . t) ("o Xu ") (" Xamd" . t) ("Xampa" . t) ("igarX" . t) ("Xtiya") ("kaCIX" . t) ("OtuX" . t) ("mUXs" . t) ("IvaX") ("steriXl" . t) ("beXliyo") (" aliXa" . t) (" bi Xi" . t) ("Xirkec") (" kaXin" . t) ("etiXi ") ("bahXis" . t) (" aXtim") ("GIXtan") ("Xamar " . t) (" eliX " . t) ("soruX " . t) ("Xardan" . t) ("leXere" . t) ("diXil" . t) ("taXde" . t) ("Xerhi" . t) ("Xakas" . t) ("beXim") ("tiXam" . t) (" Xarl" . t) ("aXkid") (" kuXm") ("Xoven" . t) ("eXint") ("iXm ") ("Xgut") ("Xiog" . t) ("ofiX") ("rak yarIX" . t) ("Xeyhan ") (" tariX" . t) ("Xanta ") ("iniXi " . t) (" turXu" . t) (" arXiz") (" aXir ") ("kansaX") (" diXe" . t) ("UXtem") ("kesiX" . t) ("Xkolu" . t) ("diliX" . t) ("Xkek" . t) (" UXu" . t) ("priX") ("Xayd") ("dX") ("en Xen " . t) ("bir Xut" . t) ("Xeydao") ("malIXi") ("maraXl" . t) ("Xantiy" . t) ("Xarman" . t) (" iXiy" . t) ("rakuX" . t) ("  iXe" . t) ("Xniko" . t) ("Xseld") ("Xifa " . t) ("obaX") ("ekuX" . t) ("nhaX") ("fzIX") ("IXip" . t) (" aXilan ") ("nim iXi" . t) ("Xerafe" . t) ("Xahade" . t) ("peSkeX" . t) (" aXird") ("muXum" . t) ("rmiXs" . t) ("ulaX " . t) ("beXbe") ("bOlUX" . t) ("belaX") ("Xken " . t) ("idaX ") (" naXi") ("Xeym") (" IXt") ("OpUX" . t) ("Xanc") (" Xilini " . t) ("uk yarIX" . t) ("Xokunu" . t) (" diXin" . t) (" Xinas" . t) ("madaX") ("iniXe" . t) ("yeXil" . t) (" kaX " . t) ("urXit" . t) ("baXac") ("ksaX") ("mbUX" . t) ("oXim" . t) ("coXa" . t) ("abuX") ("Xokl" . t) ("Xh ") ("Xt ") ("nataXa" . t) (" kuXtu") ("Xaramp" . t) ("k aXma") (" Xelal" . t) (" aXiyo" . t) ("ekiliX" . t) (" Xizo" . t) ("klIXi") (" kliX" . t) ("abaX " . t) (" bolX" . t) ("baaX") (" kUX") ("uXsa" . t) (" CeX" . t) (" Xile " . t) (" aXans") (" Xabl" . t) ("aXaye") ("Xark " . t) ("poXet" . t) (" aXig" . t) (" iXpo" . t) ("leniX" . t) ("aXme" . t) ("eraX") (" Xc") (" eXiyor") ("Xoyleyd" . t) ("Xensoy" . t) (" kaXir") (" manX " . t) (" ediX" . t) ("raXit" . t) ("UXsa" . t) (" eXo" . t) ("fuX") ("OneliX" . t) ("emiXs" . t) ("tisaX") ("baXip") (" taXt" . t) ("leXir" . t) ("CekiX" . t) ("menXe" . t) ("aXkt" . t) ("eXbe" . t) ("Xahe" . t) (" Xoka " . t) ("SantaX" . t) (" aXirl") (" eXeg" . t) (" aXip" . t) ("dikiX" . t) ("muXuz" . t) ("Xefil") ("uzlaX" . t) (" afX" . t) ("glaX") ("boX " . t) (" Xakala" . t) ("rakaX " . t) ("aXayip" . t) ("akXama") ("baXmi") ("kUrXa" . t) ("ruXen" . t) ("piXl") ("vdaX") ("oXul" . t) ("vUX" . t) ("IXo") ("Xmo") ("IrmanIX" . t) ("Xenata" . t) ("Ximar" . t) ("teniX") ("leXim" . t) (" eXd" . t) ("iXah" . t) ("Xovu" . t) ("Xkir" . t) ("nuXa" . t) ("gaX ") ("nmiX" . t) ("Xamil " . t) ("kaynaX" . t) (" Xili " . t) (" Xape" . t) (" diXl" . t) ("Xeyy") ("biX") ("ma yarIX" . t) ("l kOXe ") ("e baXin") ("lanIX" . t) ("yokuX" . t) ("UrXi" . t) ("Xovl" . t) ("ppaX") ("Xeyf") ("lkIX" . t) ("sarX") ("peX ") ("caX") ("varoluX" . t) ("Xalli " . t) (" iXimd") ("eXale" . t) ("piXki" . t) ("paXal" . t) ("duruX" . t) (" flaX" . t) ("yanaX" . t) ("miXiz" . t) ("sunuX" . t) ("Xri") (" araX ") (" keleX" . t) ("kavuX" . t) ("yaXs") (" IXk") (" Xahane" . t) (" aXka" . t) (" Xuyd" . t) ("CeliX" . t) (" Xeng" . t) ("yXeg" . t) ("doGuXund") ("UXum" . t) ("oXte") ("baXarak") (" Xerit" . t) ("rIXir" . t) ("uXsun" . t) (" okXa" . t) ("eXev") ("Xarj" . t) (" IXs") ("Xova" . t) (" yaXasa" . t) ("Xenes " . t) ("Xeyit") ("manaX") ("kiXer" . t) ("taXan" . t) (" iliX" . t) ("reaX") ("daXiniz ") ("UndeX " . t) (" diXi " . t) ("UlUXu" . t) ("koXg") ("lyaX") ("baGIX" . t) ("hiXl") ("iXir" . t) ("Xaban " . t) ("orbaX") ("peXte" . t) ("broXu" . t) ("oXnak" . t) (" Xaka " . t) ("laXinc" . t) ("Xurad" . t) (" uXan") ("inXas" . t) ("Xuur" . t) ("Xansas") ("koXtum") ("atruX" . t) ("memiX" . t) ("Xubv") ("Xefk" . t) ("hoXt" . t) ("edaXi") (" mIXi") ("lmuX" . t) (" iXid" . t) ("uXup " . t) ("Xto") (" haXim" . t) ("tiXar" . t) ("rkiXi" . t) ("Xukun") ("abbaX") (" tuX" . t) ("naX ") (" miX") (" iniX " . t) ("rXeydi") ("leXin ") ("yerarX" . t) ("IXinl" . t) (" Xisir" . t) ("riliX" . t) ("iXtah" . t) (" atIX" . t) ("eXre" . t) (" eXin ") ("kaXif" . t) ("mIXim" . t) (" Xisl" . t) ("savX") ("nmUX" . t) ("pInar X") (" paXam" . t) (" nakX" . t) ("coXtu" . t) ("IXu") ("oXp") ("iaX") (" baXire") (" eXsiz" . t) ("Xuras" . t) (" Xism" . t) ("ahXa" . t) ("SmiX" . t) ("baXinc") ("Xutla" . t) ("eXita") ("bitiX" . t) ("amuX") ("ngladeX" . t) (" reXa" . t) ("keXif" . t) ("n aXilm" . t) (" baXk ") ("Xanta" . t) ("nbeX" . t) ("niXanl" . t) ("leXiyo" . t) (" Xerid" . t) (" aXin" . t) ("aXasin " . t) (" Xura " . t) (" fiXe" . t) ("uraX") ("Xubas") ("uhuX" . t) ("Xebn" . t) ("sX") (" tiXo" . t) ("naaX" . t) ("tay ekX" . t) ("gandaX") ("raXut" . t) (" afiX" . t) (" eXek" . t) ("OrUnUX" . t) (" faX ") (" eXt") ("Xoray " . t) ("asayiX" . t) (" taXr" . t) ("OkUX" . t) ("bir iXe" . t) (" Xoku " . t) ("baXiyo") ("eXkiya" . t) (" Xayet" . t) ("iXen " . t) ("staX") ("Xtr") ("Xifo " . t) ("niXte" . t) ("hendiX") (" OzdeX" . t) (" haXh" . t) ("leXec" . t) ("rttaX" . t) ("gevX" . t) ("Xarap" . t) (" diX " . t) ("steXe") (" Xefl" . t) ("baXan") ("taXe" . t) ("mIXiz" . t) ("rIXim" . t) ("eXet") ("tbaX ") ("SpeX" . t) (" karmaXa" . t) (" aXkla" . t) ("IlIXi " . t) ("Xiirt") ("gX") (" kuruX" . t) (" bu iXe" . t) (" giXe" . t) ("boXs") ("lIXiniz") (" Ximse" . t) ("derviX" . t) ("Xakir" . t) ("Xansu") ("ipariX" . t) ("efkoX" . t) ("fahiX" . t) ("baXam") ("uXas") ("omiX") ("Xolen" . t) ("narXi" . t) ("Xafak" . t) (" iXa ") ("yavaX" . t) (" Xam " . t) ("meXh" . t) (" Xm") ("Xasa ") ("teXel") ("meXc") (" Xov " . t) (" faXi" . t) ("Xayl") ("marXi " . t) (" Xer " . t) ("branX" . t) ("aydaXi") (" eXm") (" teXc") (" haX") (" SimX" . t) ("onuXl" . t) (" iXit" . t) ("tmiX" . t) ("serviX") (" Xef " . t) (" aXti" . t) (" IXil" . t) (" iXli" . t) ("aXayi") ("yaXe") ("fIX") (" telaX" . t) ("Xah " . t) ("kIXl" . t) ("Xifr" . t) ("Xkiya") (" aXila" . t) ("ettiX" . t) ("laXiyl") (" eXel" . t) ("mayIXi" . t) ("armuX") ("leXen " . t) ("Xahit" . t) ("kaX ") (" Xudur " . t) ("yaXada") ("SadaX") (" dOX" . t) ("CavuX" . t) ("Xinl") (" vuruX" . t) ("mUXle" . t) ("lmiX" . t) (" kumaX" . t) ("oruXa") ("koXk") ("Xems" . t) ("taXk" . t) ("oXta") ("Xeno" . t) (" taXar " . t) (" bileX" . t) (" Xefi" . t) ("ireniX" . t) (" iXimi" . t) ("vranIX" . t) ("kreX" . t) ("OvanX" . t) ("dehX" . t) ("yaXaya ") ("leXti" . t) ("oGuX" . t) ("UXav" . t) ("Xirnak" . t) (" Xise" . t) ("IXiyo" . t) ("lIXi ") ("baXma") ("ftiX" . t) (" eX " . t) (" laX") ("hemX" . t) ("Xohr" . t) ("IXe") ("Xapka" . t) ("buluX" . t) ("Xeff" . t) ("IXp") ("taXli" . t) (" arXi" . t) ("Xaibe" . t) ("vahX" . t) ("Xevket " . t) ("Xket") ("kIX " . t) ("yaXti") (" muXa") ("Xirin" . t) ("Xallah" . t) (" IXl") ("Xerif" . t) ("Xebek" . t) (" eXir") ("Xch") (" eriX" . t) ("iraX") ("imaX " . t) (" neXe" . t) ("rXemb" . t) ("avXa" . t) ("manXet" . t) ("eriXa" . t) ("ssaX") ("ektaX" . t) (" adaXi") ("ayXe " . t) ("varoX" . t) ("Xkir" . t) ("argaX" . t) ("inXa " . t) (" paX ") ("Xahis" . t) (" goXa" . t) ("OzyaX" . t) ("biliX" . t) ("nuXur" . t) ("ahIX") ("barIX" . t) (" iXten " . t) ("maX ") ("OXt") ("uCuX" . t) ("kseliX" . t) ("eplaX") ("eXgu" . t) (" plaX") (" baXil") ("Xabe") (" Xanli" . t) (" Xota" . t) (" kurXun" . t) (" avuX") ("UmUX" . t) (" a X " . t) ("keXke" . t) ("nleX" . t) (" Xeya") (" Xenl" . t) ("laXi ") ("ivaX") ("leX ") (" teXh" . t) ("tuluX" . t) ("eXf" . t) ("Xmar") ("kuXur") ("yaXag") (" Xok " . t) ("Xadis") ("sOyleXi" . t) (" Xunu " . t) ("rayIX" . t) ("iXver" . t) ("Xuk" . t) (" Xair" . t) ("Xubay") ("ombaX") ("anX") ("aXanin") ("eyiX" . t) (" SiX" . t) ("gUreX" . t) ("boXna") ("USUX" . t) ("IXin " . t) ("IXig" . t) (" ali Xen" . t) ("Xevki " . t) ("gidiX" . t) ("baXinin") ("UrkeX" . t) ("beXle") ("baXit") ("IkIX" . t) ("akIX" . t) ("CmiX" . t) ("meXr" . t) ("Xyer" . t) ("eXya" . t) ("Xeref" . t) (" aXki" . t) ("muXla" . t) ("Xahs" . t) ("nuXul" . t) ("iXg" . t) ("laXin") ("rUyUX" . t) ("veriX" . t) ("suX") ("thiX" . t) ("oXku" . t) (" aXk " . t) ("Xuphe" . t) (" CarX" . t) ("maaX" . t) (" uGraX" . t) ("Xuyor" . t) ("laX ") ("baXti") ("taXlar" . t) (" SaX" . t) ("teXar" . t) ("omXu" . t) ("beXt") ("Xofor" . t) (" keX") ("Xeker" . t) ("mUXtu" . t) (" satIX" . t) ("Xkenc" . t) (" esaX") ("nXaa" . t) (" rUX" . t) ("UXter" . t) (" eXl" . t) (" klaX") (" Xii" . t) ("geCiX" . t) ("Xeyr") (" endiXe" . t) ("siXl") ("aXik" . t) ("teXe" . t) ("odaX") ("iXsiz" . t) ("kleX" . t) ("Xeyir") ("rleX" . t) ("teXv" . t) (" mayIX") ("nlayIX" . t) ("Xener" . t) ("teXkil" . t) ("Xikaye" . t) (" oluX" . t) (" kuX" . t) (" olaX") ("etiX" . t) ("Xra") ("paXa " . t) (" Xunl" . t) (" geliX" . t) ("Xidde" . t) (" peX" . t) (" ateX" . t) ("uXal") ("yaXas") ("liXl") (" kOX" . t) ("yaXak") (" iXi " . t) ("Xahin" . t) ("hoX" . t) ("kardeX" . t) (" yeX" . t) ("yaXa ") (" boX" . t) (" eXi" . t) (" Xans" . t) (" Xas" . t) (" geniX" . t) ("UneX" . t) ("Xeria" . t) (" akXam" . t) ("rXey" . t) ("oXman") ("Xarki" . t) (" iXin" . t) (" Xekl" . t) ("abaX") (" iXa" . t) ("artIX" . t) ("savaX" . t) (" iXm") ("mUX " . t) ("lIX" . t) ("Xampi" . t) (" iXb" . t) (" koX" . t) (" Xub" . t) ("Xart" . t) ("IXik" . t) ("aXir" . t) (" iXte " . t) (" baXin ") ("reXm") ("OnUX" . t) ("uXa" . t) ("Xci" . t) ("aXki") ("Xyo") ("Xeh" . t) ("Xal") (" aXa" . t) ("eXit" . t) ("miXt" . t) ("Xekil" . t) ("ruluX" . t) (" giriX" . t) ("brIX") (" beX" . t) (" Xu " . t) ("daX" . t) (" kIX") ("muX " . t) ("Xirke" . t) ("Xoyle " . t) (" iX " . t) (" taXi" . t) (" Xey" . t) ("GiX" . t) (" gOrUX" . t) ("laX" . t) ("Ximdi" . t) ("dIX" . t) ("IXi") ("liXk" . t) (" yaX" . t) ("aX " . t) (" kiXi" . t) ("iXle" . t) ("uXtu" . t) ("miX " . t) (" dUX" . t) (" karXi" . t) ("Xtir" . t) ("Xm" . t) ("IX" . t) ("baX" . t) ("X") )
     (?u ("Xctugu") (" ay sX" . t) ("fXtur " . t) ("Xysuz ") ("Gi rXs") ("an Xnv" . t) ("Xldeni") ("dIn Xn" . t) ("i kXcu" . t) ("43 sX " . t) ("Xcunda") ("g kulX" . t) (" aC kX") ("Xrunda") ("lI tXt") ("pon bX" . t) ("ok bXy" . t) ("z abdX") ("mamXlu") ("Xllah ") ("im sXl" . t) ("ne gXn" . t) ("Xstafa") (" en bX" . t) ("bXlet" . t) ("CustX" . t) ("ep lX" . t) ("Us yX" . t) ("as X " . t) ("tXtki" . t) (" fXru" . t) ("hU sX" . t) ("c itX") ("i tX " . t) ("n lXx" . t) ("u Xs " . t) ("SundX" . t) ("lm X " . t) ("m Xs " . t) ("okXme") ("gOzXc") ("zangX" . t) ("Xrtum" . t) ("S sXz" . t) ("Xtaas") ("Xktio") (" nXsu") (" mayX") ("atarX" . t) ("CayXs" . t) (" ayhX" . t) ("bu X " . t) ("Ors X" . t) ("orsXd" . t) ("ergXt") ("Xrats") ("cXmul" . t) ("Xslam" . t) ("Xnsan") ("mXstt") ("Xltad") ("Xnett" . t) ("m sXk") ("Xlmut") ("CXku " . t) ("evarX" . t) ("lXylu" . t) ("thXri" . t) ("rakX ") ("jektX" . t) ("Xrsad" . t) ("alXle") ("u iCX") ("ttXrs" . t) ("65 X " . t) (" bXsl") ("Ul Xs") ("kXsuf" . t) ("Xteki") ("4 tX " . t) ("a kX " . t) ("rUkX ") ("kUslX" . t) ("rtikX" . t) ("mXsub" . t) (" Xndu" . t) ("uritX") ("OnktX" . t) ("sXlie" . t) ("cUdXn") ("m Xsk" . t) ("ec tX" . t) ("mnibX") ("Ol dX" . t) ("nU X " . t) ("Xnita") ("Oy lX" . t) ("bXkat" . t) ("yad X" . t) (" itsX" . t) ("kU zX" . t) ("ogXnk") (" cUlX") ("cXlus" . t) ("lXkun") ("iyedX" . t) ("GangX" . t) ("pXste" . t) ("sXste" . t) (" Xrin" . t) ("yergX") ("i Xld" . t) ("zz tX" . t) ("lXsse" . t) ("adOlX") ("3 nX " . t) ("bambX") ("kXsey") ("i Xr ") (" trXk" . t) ("yIndX" . t) ("mad X") ("GardX" . t) ("Ok mX" . t) (" rUcX") ("tXsev" . t) ("hXku " . t) (" Xsst" . t) ("hulXl" . t) ("S dXo" . t) ("gge X" . t) (" Xyke" . t) ("U alX" . t) ("et X " . t) ("rC gX") ("Xrgem" . t) ("ingXs") ("Xvero") ("ei kX") ("mXkur") ("Xiti " . t) ("Xrba ") ("sXtre" . t) ("13 tX" . t) ("hXmet" . t) ("Xhlef") ("UC X " . t) ("sfatX" . t) ("Xmmuh" . t) ("enusX" . t) ("mXhr " . t) ("UslXk" . t) (" Xsur" . t) ("sXmel") ("ok zX" . t) ("0 yX " . t) ("gXlli") ("lXzun") ("Xtlur" . t) (" 0 tX") ("k Xz " . t) ("Xctuu" . t) ("huldX" . t) ("Xrkua") ("ak X " . t) ("sXkay") ("sXled") ("tUpsX" . t) ("h dXr") ("Xhuri") ("tol X" . t) ("erkXn" . t) ("bXrud" . t) ("jOr X" . t) ("hXsev" . t) (" bXrl") ("ue cX") ("StXyu" . t) ("n lXm" . t) ("Xliyy" . t) (" yXne") ("Xresh") (" cXr " . t) ("vandX") ("Xnifi") ("Xngus" . t) ("Xrita") ("mi X ") ("Xvete" . t) ("tXsib" . t) ("Ci Xs" . t) ("wandX") ("g Xnv" . t) ("hi Xn") (" klXm") (" tUSX") ("tXyug") ("n tX " . t) (" g mX") (" nXss" . t) ("bi X ") ("rm X " . t) ("mkXm " . t) (" I lX") (" bXta") ("olXme") ("Xtlaa" . t) ("uIp X") ("dis X") (" orgX") ("dr zX" . t) (" fXnu" . t) ("mI Xb" . t) ("n yX " . t) ("yrXl " . t) ("irk X" . t) ("Uks X" . t) ("duh X" . t) ("zallX" . t) (" yXve" . t) ("abakX" . t) (" bXto") ("ptXn " . t) ("l Xsu") ("Uh mX" . t) ("m Xnc" . t) ("g yXn") ("i hX " . t) ("Xveti" . t) ("satXk") ("tXnet" . t) ("bXruy" . t) ("tXzud") ("3 nXn" . t) ("kXrts" . t) ("Xrruo" . t) ("a mX " . t) ("kap X") ("  Xlt") ("hXkul" . t) ("3 yX " . t) ("Off X" . t) ("Xrtee") ("Ut kX") ("gXlug") ("s mX " . t) ("Ul lX" . t) ("mXski") ("r dXl") ("Xtsu " . t) ("dXkas") ("tUk X" . t) ("mXsar") ("Xsusm" . t) (" m X " . t) ("tf nX" . t) ("r Xlt") ("rks X" . t) ("prokX" . t) ("mXril") ("Xruks" . t) ("jI Xc") ("be lX" . t) ("kabbX") (" gXye") ("Xroyo") ("hi CX") (" Xzga") ("kXrtt" . t) ("rikXt" . t) ("UC lX" . t) (" kXp " . t) ("zut X") ("Xyluo") ("a dX " . t) ("Ulk X" . t) ("izamX" . t) ("zeynX" . t) ("yUz X" . t) ("rU jX") ("ko tX" . t) ("ns Xs" . t) ("Ukm X" . t) ("Xruri") ("di X ") ("g sXp") (" mXk ") ("asXre") ("Sun X" . t) ("erg X" . t) ("sellX" . t) ("Xtayi") ("s Xsl") ("Xlali") ("e rXb" . t) ("r Xss" . t) ("rls X" . t) ("bdulX" . t) ("k h X" . t) ("y tXb") ("ytemX" . t) ("e tX " . t) ("gXrba") ("IS pX") ("sXylu" . t) ("mXcu ") ("  mX " . t) ("lorX " . t) (" Xcuy") ("yekXm") ("ee tX" . t) ("gs bX") (" indX") ("gXri ") ("m Xnv" . t) ("Ip Xn" . t) ("UrtCX" . t) ("Xzari" . t) ("rU hX" . t) (" hXru") ("polXn" . t) ("Xlca ") ("ot lX") ("kXlel") ("mXbil") ("gXrke") ("Xterl" . t) ("mXzlu") ("Se Xm" . t) (" hUdX") ("n rX ") ("r pXt") ("e Xhu" . t) ("lt lX" . t) ("ova X" . t) ("kXrse" . t) ("to sX") ("Xskum") ("Xdusu" . t) ("Xretc" . t) ("r izX" . t) ("kXlut" . t) ("laykX" . t) ("rmatX" . t) ("rIS X") ("ze Xs" . t) ("kXmbe" . t) ("rXtuk" . t) (" Xcus") ("Xbeyr") ("ef Xn" . t) ("rkXte" . t) ("Xlas ") ("tI X " . t) ("aribX") ("kulXy") ("orlXr" . t) ("n sXk" . t) ("Xturo" . t) ("kXbiz" . t) ("l p X" . t) ("Xzaya") ("m alX" . t) ("ul gX" . t) ("rn mX" . t) ("Xnsel" . t) ("mXsab" . t) ("tU tX" . t) ("C kXs") ("n Xf " . t) ("m Xct" . t) ("fi Xc") ("eS Xn" . t) ("Xdus ") ("sormX") ("s dXr") ("Xrge " . t) ("Xrkos") ("ore X") ("k dX " . t) ("sla X") ("00 fX" . t) ("mXral") ("age X") ("tXnc ") ("mXhen" . t) ("SaygX" . t) ("elXcl" . t) ("Xmdan") ("l alX" . t) ("lektX" . t) ("ur rX") ("mXrsa") ("UtXne" . t) ("nSUmX") ("Xlak ") ("su gX" . t) ("Xrsan") ("mXrid" . t) ("igXre") ("a gX ") (" kXre" . t) (" kXnu" . t) ("mXssa") ("Xvenc" . t) ("Xrmes" . t) ("Xrgul") ("epeX" . t) ("acXm" . t) ("Xrrt" . t) ("Xmob") ("anXp" . t) ("Xfam" . t) ("pXrn" . t) ("nnXk") ("rtdX") ("fUcX") ("fXcu" . t) ("rtcX" . t) ("mXmm") ("mXif" . t) ("cz X" . t) ("lXrr" . t) ("nyXa" . t) ("ulCX") ("Xsef" . t) ("Xsfa") ("lksX" . t) ("cXpe") ("OSrX" . t) (" Xnt" . t) ("gXbb") ("hinX") ("OStX" . t) ("kekX") ("mehX" . t) ("agX ") ("mXlh") ("Xdev" . t) (" aSX") ("grXt" . t) ("UclX" . t) ("rIsX" . t) ("OlgX" . t) ("Xbid" . t) ("rbrX" . t) ("hXnk" . t) ("Xhek") ("Xssy") ("Xtc ") ("sn X" . t) ("rlyX" . t) ("nXkr") ("Xlot" . t) ("Xleg") (" sXo" . t) ("tesX" . t) ("Xkyu" . t) ("Xloj" . t) ("dXed") ("rcXb" . t) ("UysX" . t) ("zdeX" . t) ("jXpo" . t) ("OtlX" . t) ("q sX" . t) ("lXkk") ("aXsk" . t) ("tXpe") ("holX" . t) ("tXem" . t) ("etdX" . t) ("Xndk") ("tXbt" . t) ("OrnX" . t) ("Xsir" . t) ("kalX" . t) ("Xrds") ("ybXk" . t) ("fXzz") ("Xrua") ("genX") ("UrpX" . t) ("Xzbu") ("x lX") ("jXre") ("tCXo") ("bb X ") ("b X " . t) ("ehXz" . t) ("UnnX" . t) (" Xnn" . t) ("Xbut" . t) ("alXc") ("dUfX" . t) ("hXkt" . t) ("zbXk" . t) (" Xsd") (" Xrb") ("tezX" . t) ("Xsei") ("lptX") ("UhtX" . t) (" Xcd" . t) ("Xfad" . t) ("hXla" . t) ("UmmX" . t) ("tXnr" . t) ("dXbe" . t) ("nesX" . t) ("yXrr" . t) ("Xhih" . t) ("Xlts") ("hXup" . t) ("fagX") ("pidX") ("inXs" . t) ("dekX") ("Xnia") ("UtcX" . t) (" g X" . t) ("SidX" . t) ("kClX" . t) ("otCX") ("irXl" . t) ("yerX" . t) ("Xmld") (" Xry") (" yXu" . t) ("o pX") ("UzkX" . t) (" Xzk" . t) ("Xkbu") ("Xzo ") ("kkXn" . t) ("ddXp" . t) (" sgX") ("vXke" . t) ("visX") ("ItrX" . t) ("rXto") ("Co X") ("gelX" . t) ("cekX") ("adgX") ("CXrc") ("Xnug" . t) ("OrcX" . t) ("eygX" . t) ("cinX") ("Om X" . t) ("sb X" . t) ("anCX") ("irXp" . t) (" CXt") ("nbXk" . t) ("U2nX" . t) ("Xrro") ("fXme" . t) ("eptX") ("gXth") ("Xgar") ("Ub X" . t) ("dXvu" . t) ("yadX" . t) ("OtsX" . t) ("ww X") ("Xtei") ("ntXk" . t) ("Xlek" . t) ("d pX") ("Xttn") ("Xrru") ("d Xp") (" Xin" . t) ("erXf" . t) ("Xnsi" . t) ("Od X" . t) ("lXke") ("cXrm" . t) ("I Xk") ("akXd" . t) ("Xrio") ("vrXb" . t) ("kubX") (" Xke" . t) ("rXdd" . t) ("IldX") ("Xyme" . t) ("eobX") ("eatX") ("Xset") ("ebXz" . t) ("rcXr") ("Xldi") ("nXmb") ("Xrop") ("mXhn" . t) ("Xckn") (" CXp") ("  Xh" . t) ("9 rX" . t) ("cetX" . t) ("sXpa") ("Xkev") ("aCbX" . t) ("bylX") ("Xyap" . t) (" ngX") ("OC X" . t) ("Xnim") ("Xkak") ("vvXl" . t) ("tUfX" . t) ("sXts" . t) ("ecXm" . t) ("gerX" . t) ("I Xu" . t) ("Xsol") ("3 jX") ("grgX") ("Xnny") ("3 Xs") ("pXsr" . t) (" imX" . t) ("ayXl" . t) (" agX") (" pXn") ("nefX" . t) ("cidX" . t) ("yazX" . t) (" Xrm") ("etXb" . t) ("mXnk") ("Xebe") ("Xsi ") ("anXd" . t) ("eGXz" . t) ("imiX" . t) ("ksXb") (" rX " . t) ("CXyd") ("Xcar") ("pXso" . t) ("Xpus" . t) ("fasX") ("anhX" . t) ("lalX" . t) ("yhXl" . t) ("bXy " . t) ("sikX" . t) ("radX") ("bXlf") ("mXve" . t) ("fsXr" . t) ("gayX" . t) ("edXc") ("nkXt") ("Xths") ("anzX") ("Xlp ") ("Xrkh") ("urkX") ("umbX") ("accX" . t) ("aldX") (" Xlg" . t) ("OCsX" . t) ("Xlna" . t) ("iltX" . t) (" hyX") ("ebbX" . t) ("ddXt" . t) ("aulX" . t) ("Xkti" . t) ("batX") ("lXbr") ("Xrpr" . t) ("Xsee") (" tXv") ("jXl " . t) ("Xgi ") ("rXc ") ("dakX") ("OmmX" . t) ("Xth ") ("CXle" . t) ("Xbuz") ("fXz ") ("ozXn") ("Xnam") ("udXk") ("sokX") ("Xbai") ("kXmk") ("prXn" . t) ("obXs" . t) ("adXf" . t) ("Xgay") ("nSXm" . t) ("orXl") ("ekXl" . t) ("Xfla") ("lXla") ("Xra ") ("eyXp" . t) ("prXl" . t) ("Xsto") ("urmX") ("sXtu" . t) ("OrpX" . t) ("ozXk") ("Xsem" . t) ("orXc") ("vXc ") ("cXrr") ("Xrri" . t) ("Xkru" . t) ("mXt ") ("Xzan") ("unsX") ("oksX") ("udXr") ("bXtc" . t) (" Xfa") ("Xhar") (" UzX" . t) ("uStX") ("ulXs") ("sXna") ("Xtma") ("oplX") ("Xkla") ("hUkX" . t) (" olX") ("Xzig" . t) ("kurX") ("lkXr") ("fdX" . t) ("mCX") ("iGX" . t) ("zGX" . t) ("CCX") ("OfX" . t) ("Xfh") ("dnX" . t) ("Xbc" . t) ("CcX" . t) ("Xkv") ("Xua") ("Xyn" . t) ("Xhh" . t) ("Xtw") ("UvX" . t) ("GaX" . t) ("lSX" . t) ("Xmn") ("Xhy" . t) ("aiX") ("byX" . t) ("Xyz" . t) ("hXv" . t) ("Xgh") ("aXy" . t) ("jXn") (" Xo" . t) ("acX") ("pXz") ("CyX" . t) ("mnX") ("icX") ("eaX") ("fXa") ("laX") ("Xtk") ("ocX") ("sXc") ("UyX" . t) ("OnX" . t) ("n konsensXs ") ("Uk bir tXr ") ("sI Xnvanini" . t) ("yla tXrban ") ("k tXrkcell") ("ler tXrunu") ("  diGer Xc" . t) ("ara bir dX") ("i iki tXr ") ("minde tXrb") ("nI Xslup ") ("taki tXrb") ("Xmenalti ") ("i tXrkcel") ("I Xnvani " . t) ("cak kXrsu" . t) ("mada tXr " . t) ("yi enstrX") ("inin tXrb") (" nIn tXrb") ("lan tXtun" . t) ("Xniversia") ("ine kXrt ") ("terini dX" . t) ("  bir kXr") ("Xverturle" . t) ("usion tX" . t) ("In usXl " . t) ("go tribX") ("Xkuneti ") ("n bXyum ") ("z sXrat ") ("ttin kXr") ("yen ambX" . t) ("i bXyur ") ("aya tXrb") ("li tXrba") ("han abdX") ("eki Xcu ") ("Cok tXr " . t) ("ir ergXn") ("tU bir X" . t) ("kan kXrt") ("de ergXn") ("I tXtun " . t) ("r Xnvani" . t) ("uran kXr") ("lu ergX") ("Xrator " . t) ("en kXl " . t) ("si Xzuy") ("bu tXmu") ("mir mXr") ("Xvette " . t) ("et ergX") ("ar kXl " . t) ("bin kXs" . t) ("l tXtun" . t) ("hXkumuz") (" tXruyo" . t) ("in ambX" . t) ("iyet Xn" . t) ("a Xcunu" . t) ("Ik tXru" . t) ("a kXsuy" . t) ("zi kXrt") ("adet sX" . t) ("  bXyur") ("mle kXs" . t) ("ve mXz ") ("Um dXr " . t) ("di tXru" . t) ("bXrundi") ("e ve Xs" . t) ("Inar kX" . t) ("I tXru " . t) ("Ur mXsu" . t) ("tmen mX") ("rdIm kX") ("lk tXru") ("a mXsah") ("an Xcun" . t) ("cU kXrs") ("r kondX") ("at tXru" . t) ("Xsunuyo" . t) ("mon sX") ("Xkutuy") (" o mXd") ("oole X") ("n sXr ") ("cla pX") ("re kXb" . t) ("0 tXr " . t) ("k sXs " . t) ("birt X" . t) ("makulX" . t) ("bXzul ") ("UC mX " . t) ("Xrtcuk") ("dXslu ") ("eux nX" . t) ("e 3 sX" . t) ("  sUtX" . t) ("bXyurl" . t) ("gXlham") ("r sXs " . t) ("lkolsX" . t) ("Xverno") (" akXsu" . t) ("sI Xn " . t) (" mXzu ") ("Xtena ") (" dXrda" . t) ("gUl sX") ("ney Xc") ("Xbapla" . t) ("koldXr" . t) (" gXru ") (" Xctur" . t) ("as mXs") ("Xrtceb") ("oyle X") ("Ur dX " . t) ("ara X " . t) ("Xrdish") ("e Xzuy") ("Xrtaji") ("s ta X" . t) ("suC mX") ("kXstuk" . t) ("sul mX" . t) ("sus nX" . t) ("i ambX" . t) (" kXcu ") ("t mXz ") ("bXrunl") ("kbuldX" . t) ("i mXz ") ("g tXru") ("ton tX" . t) ("Xtture" . t) ("Xralis" . t) ("Xcunde" . t) ("zor mX") ("n Xnva") ("sIk sX") ("Xtunde" . t) ("ir Xr ") ("troldX" . t) ("Xruyle" . t) ("lkollX" . t) ("tXrce " . t) ("ari Xn") ("kOr mX" . t) ("r Xzuy") ("Si yXn") ("na tXt") ("I tXtu") ("st sXp") ("5 lXk ") (" Xnet" . t) ("naryX" . t) (" gXsa" . t) (" ad X" . t) ("insXl" . t) ("a sXh") ("i Xz " . t) ("Xgsas" . t) ("gercX" . t) ("me zX" . t) (" cXss" . t) ("rXnin" . t) ("ktXtu" . t) ("  alX" . t) ("bXlem") ("eur X" . t) ("i alX" . t) ("tasX " . t) ("U Xct" . t) (" gXts") ("I Xs " . t) ("algXl" . t) ("3 tX " . t) (" tXrt" . t) ("UrzX " . t) ("UnCtX" . t) ("UltmX" . t) ("UrCtX" . t) ("t Xs " . t) ("dOksX" . t) ("UnC X" . t) (" kXld" . t) ("Xluku") ("fXlut" . t) ("k alX" . t) ("4 nXn" . t) (" sXzd" . t) (" Xzur" . t) (" takX") ("mXhel") (" Xsud" . t) ("oollX") (" akXl" . t) ("z Xnv" . t) ("atXm ") ("by tX" . t) (" Xmmi" . t) ("itXtu" . t) ("Xlaym" . t) (" erXs" . t) ("r alX" . t) ("otokX" . t) ("Xtupa" . t) ("pXrde" . t) ("alXll" . t) ("hXmas" . t) ("rgXme") ("Oln X" . t) ("i zXh" . t) (" yXn " . t) ("bXzus" . t) ("sXder" . t) ("aytXl" . t) ("emXrt" . t) ("mXlar") ("Up Xn" . t) ("Xsri ") ("mXst ") ("lXgan") ("tekX ") ("izanX" . t) ("rollX" . t) ("gulsX" . t) ("tXrud" . t) ("ulXz " . t) ("ssXsu" . t) ("gXyan") ("GUslX" . t) ("rdesX" . t) ("io tX" . t) ("Xtter") (" pXr " . t) (" Xnir") ("stXtu" . t) ("Xklum" . t) ("mXtas") ("d e X" . t) ("bXcus" . t) ("Xlien" . t) ("evalX" . t) ("dUstX") ("Xtune" . t) ("Xcune" . t) ("Xstal") (" mXth" . t) ("Xstas") (" Xrka") ("Xsta ") ("amulX" . t) (" yXmu") ("mXste" . t) ("Xrula") ("Xnda ") ("rXze") ("mXpa") ("eilX" . t) ("upCX") ("hXrt") ("stXv" . t) ("inXn" . t) ("renX") ("Xchn" . t) ("anXz" . t) ("tXpo") ("kbXk" . t) ("kXsp" . t) ("orfX") ("tXh " . t) ("enXr") ("udXz") (" Xrc") ("trX " . t) ("OydX" . t) ("gogX") ("hr X" . t) ("OzXg") ("lCtX" . t) ("uXzu" . t) ("OGrX" . t) ("UfrX" . t) ("O yX" . t) ("dXrz" . t) (" Xvi") ("ogXz") ("rl X" . t) ("lliX") ("litX") ("sXlo" . t) ("zXc " . t) ("bXlk") ("Xkku" . t) ("yXpo" . t) ("UptX" . t) (" lXy") ("Xchi") ("IndX") ("Xns ") (" lXp") ("UrrX" . t) ("CXlh") ("UySX" . t) ("lpsX" . t) ("dXnb") ("ugXl") ("mXto") ("bXko") ("utgX") ("Xlia") ("mXpp") ("mXnt") ("Xfte" . t) ("kXsy" . t) ("dXng") ("apCX") ("hU X" . t) ("Xnth") ("egXs") ("OlsX" . t) ("evvX" . t) ("dXld" . t) ("rCmX" . t) ("yXde" . t) ("bXht" . t) (" Xrs") ("skXl" . t) (" lXm") ("Xli ") ("Xgab") ("bXge" . t) ("zsXy") (" Xsa") ("Xtat") ("Xlre" . t) ("untX") ("vizX" . t) ("dXls" . t) ("cXlc" . t) ("CXgi") ("togX") ("ombX") ("ailX" . t) (" Xgd" . t) ("akXp") ("virX" . t) ("Xfli" . t) ("hXum" . t) ("OpmX" . t) ("Xch ") (" Xri") ("nXsr") ("Xsli" . t) ("dizX" . t) ("sXns") ("kkXr" . t) ("dXlg" . t) ("ekkX" . t) (" Xyd") ("nXll" . t) (" yXc" . t) ("Xcci") ("CXrp") ("Xla ") ("fXne") ("GanX" . t) ("Xtme" . t) ("rubX") ("kutX") ("yUzX" . t) ("uygX") ("okXy") (" uzX") (" Xca") (" Xza") (" dXy") ("Xsle" . t) ("mXu") ("gXo") ("lXi") ("lXh") ("kdX" . t) ("Xrj") ("mXb" . t) (" Xh") ("Xg ") ("thX") ("OkX" . t) ("Xen") ("apX") (" Xg") ("rXf") ("OX" . t) ("de konsensX") (" la tribX") ("nIn Xcu ") ("i bXyuka") ("r kXrsu " . t) ("iki tXr " . t) ("i tXtun " . t) ("in dXrul" . t) ("ra sXres") ("anI kXrt") ("da ergXn") ("bir tXru" . t) ("Xrsunun " . t) ("z tXtun" . t) ("rk tXr " . t) ("t usXlu" . t) ("m tXru " . t) ("ka tXr " . t) ("Urk tX " . t) ("ve sUtX" . t) ("de kXl " . t) ("nkulXnu" . t) ("ya tXru") ("ali kXr") ("ne ergX") ("un Xcu ") ("ir mXz ") ("mXltes") ("Oz mX " . t) ("emerrX" . t) ("rgXner") (" sXlun" . t) ("nI Xnv" . t) ("mXhada" . t) ("ci Xnv" . t) ("Ur mXy" . t) ("S tXru" . t) ("Une Xn" . t) (" hXlle" . t) ("or mXz" . t) ("ir Xs " . t) ("Un dX " . t) ("a Xnu " . t) ("US mXy" . t) ("r sXty" . t) ("m kXm " . t) (" blXm " . t) ("letlX " . t) (" tXrsa" . t) (" tXne ") ("r Xcu ") ("mer Xn" . t) ("n sXzu" . t) ("Xnder " . t) ("Xlucul") ("Xnden " . t) ("i mamX") ("Xlunk" . t) ("Xrks ") (" atXt" . t) ("tXfey") (" nXne") ("lXsiy" . t) ("mlubX" . t) ("bXcur" . t) ("gUrsX") ("sXspa" . t) ("sXvey" . t) ("n alX" . t) ("halXs" . t) ("klubX" . t) ("luldX" . t) ("cXre ") ("U mXy" . t) (" Xcum" . t) (" zUlX") (" onXc" . t) ("CXkun" . t) ("kXsup" . t) ("dXdul") (" volX" . t) (" dXke") ("sargX") (" Xsus" . t) ("tXrik" . t) ("Xtedi") ("z Xs " . t) ("gUm X" . t) ("Xsamb") ("Xlka ") (" fXr " . t) (" mXlu") ("ndXsu") ("f mX " . t) (" tXll" . t) ("guldX" . t) ("tXkiy" . t) ("4 sX " . t) ("bXgru" . t) ("zXhre" . t) ("merkX" . t) (" matX") ("rtsXn" . t) (" dXmd" . t) ("Xnker") ("U lX " . t) ("revX " . t) (" Xnay" . t) ("tXman") (" bXs ") ("ChulX" . t) ("Urt X" . t) ("Xllat" . t) ("ude X" . t) ("mXre ") ("kulXm") ("Xndek" . t) ("Xslum" . t) ("OGdX" . t) ("aSXs" . t) (" Xci" . t) ("lXzz") ("fXhr" . t) ("Of X" . t) ("Xcko" . t) ("ikXr" . t) ("sXny") ("tCXk") ("nitX") ("OstX" . t) ("Xseu") ("nsXt" . t) ("dXnn") ("yyXl" . t) ("trXb" . t) ("ifXs" . t) ("Ov X" . t) ("mXnz") ("II X" . t) ("Xmuk" . t) ("alyX") (" CXc") ("kadX" . t) ("lsXy") ("tXbl" . t) ("Xbab" . t) ("UGrX" . t) ("tXko" . t) ("rOtX") ("Xloz" . t) ("eytX" . t) ("Xmtu") ("ufCX") ("ogX ") ("ebXl" . t) ("dXlv" . t) ("uzsX") ("Xdle" . t) ("rXks" . t) ("timX") ("Xks " . t) ("effX" . t) ("dXna") ("Xbat") (" Xyu") ("ultX") ("hXri") ("Xnle" . t) ("pdX" . t) ("jmX" . t) ("lGX" . t) ("Xju") ("Xev") ("Xbj" . t) ("UdX" . t) ("z kXsur " . t) (" kXsmus " . t) (" mXslug") ("Xratind") ("ngi tXr" . t) ("irmi kX" . t) ("Xzelge" . t) ("den wX" . t) ("Xstafi" . t) ("tXzunu") ("ak Xn " . t) (" yXnu " . t) (" kXpun" . t) ("bXker ") ("im gXl" . t) ("o mXz ") ("esulX " . t) ("Um mX " . t) ("da Xs " . t) ("Xpert ") ("bXyur " . t) ("sUrXr ") ("vertXr" . t) ("n fXtu" . t) ("Xnvanl" . t) ("nlU Xn" . t) (" Xzun ") ("Xstura") (" Xys " . t) ("Urn X" . t) ("gXreb") ("karbX" . t) ("fUnXn") ("nXmay" . t) ("gh X " . t) ("3 lX " . t) ("nurgX" . t) (" mXsh") ("prosX" . t) ("lm Xn" . t) ("dXvel" . t) (" pXri" . t) (" akXn" . t) ("tXriy" . t) ("masaX" . t) (" zXbu" . t) (" tXbe" . t) ("lahX " . t) ("aullX" . t) (" Xnuv" . t) ("ilatX" . t) ("i Xs " . t) (" Xnsu") ("Ust X" . t) ("Xnune" . t) ("Xnv " . t) ("zXht" . t) ("Xkaf" . t) ("sXke") ("dXmt" . t) ("dXnh") ("jXpi" . t) ("jXly" . t) ("UflX" . t) ("absX" . t) ("Xnna") ("dXmb" . t) (" lXa") ("zsX ") ("inXb" . t) ("sXpp") (" nXv" . t) ("usCX") ("Xhle" . t) (" msX" . t) ("bXka") ("UsmX" . t) ("yamX") ("Xkem" . t) ("Xsa ") ("ulXc") ("urXy") ("Xmku" . t) ("Xzle" . t) ("yavX") ("Xnca") ("cXt ") ("Xfuk") ("Xnla") ("Xnut") (" Xya") ("Xtan") ("sorX") ("OSX" . t) ("aCX") ("jdX") ("kvX" . t) ("gXg") ("lXj") ("Xmp") ("gXj") ("ChX") ("Xgd") ("kbX") ("mXj" . t) ("fkX") ("Xe ") ("GdX") ("osX") ("unX") ("Xltimato" . t) ("nbir sX") ("alip yX" . t) ("ni tXr " . t) ("Xratina") ("  tXtun" . t) ("kulubX" . t) ("d dXst") ("Ul mX " . t) ("Xllen ") ("tXzumu") (" mXnis") ("Xcuzle" . t) (" idolX" . t) ("Xratim") ("him kX") ("paul X" . t) ("ropolX" . t) (" pXlum" . t) ("fUtXr ") ("U ergX") ("Xnunde" . t) ("mXsur" . t) ("le X " . t) (" kakX" . t) ("UsttX" . t) ("eessX" . t) ("urolX") ("ngXcu" . t) ("UrkmX" . t) ("UstsX" . t) ("elamX" . t) ("kXner") ("n Xs " . t) ("n Xck" . t) ("lXkar" . t) ("on lX") ("OrtmX" . t) (" Xsut" . t) (" sXme" . t) (" tXl " . t) ("mettX" . t) ("U ydX" . t) ("kulXn") (" kXse" . t) ("nnXm" . t) ("efXj" . t) ("Xpsa") ("Xlaz" . t) (" ytX" . t) ("bXsc") ("Xlf ") ("ksXr" . t) ("mXrp") ("dXsa") ("kakX") ("UzcX" . t) ("OttX" . t) ("Xnga") ("Xdde" . t) ("mXrn") ("ssXl" . t) ("pXtu" . t) ("Xrie") ("Xtta") ("Xnid") ("Xrga") ("Xysa") ("Xcur") ("Xyle" . t) ("fXzu") (" lXs") ("angX") ("kanX") ("uSkX") ("Xma ") (" iX" . t) ("zrX" . t) ("Xx") (" celik gX") ("e tXrunu") ("ne sUtX" . t) ("trol Xn" . t) ("ynI tXr" . t) (" Xnunu " . t) ("iki Xcu") ("z kXrt ") ("an tXru" . t) ("da kXl " . t) ("ban sX" . t) ("Xbyanc" . t) (" Xsume" . t) ("natXre") ("tXtunu" . t) ("Uk mX " . t) ("lu mXd" . t) ("or mXd" . t) ("Xrley ") ("US mX " . t) ("Xpero") ("Xccac" . t) ("rpolX" . t) ("dXrbu" . t) ("utXre") ("atXru" . t) ("irolX") ("t bXb" . t) ("gravX" . t) ("altXn") ("hrolX") ("UnClX" . t) ("Xngor" . t) ("Xlasy" . t) ("mXrta") (" mXca" . t) ("Xlar ") ("ptXs" . t) ("Xkoi") ("rXku" . t) ("yfXs" . t) ("evXk" . t) ("lugX") ("eykX" . t) ("Xkto" . t) ("UplX" . t) ("bogX") ("arbX") ("OCmX" . t) ("Xzir") ("Xnio") ("UymX" . t) ("idXg" . t) ("ezzX" . t) ("Ut X" . t) ("Xphi") ("easX" . t) ("rrXr" . t) ("bXtl") ("adXr") ("UlgX" . t) ("silX" . t) ("Xban") ("OllX" . t) (" Xla") ("gXk") ("OsX" . t) ("nXh") ("Xty") ("UnX" . t) ("e tXtun " . t) ("okol Xn" . t) ("jale kX") ("ik tXru" . t) ("Xsturi") (" kXstur" . t) ("CUksX ") ("jXrgen" . t) ("hakkXm" . t) ("Guk dX") (" mXska") (" orXs" . t) ("erolX") (" bXse") (" yXnl" . t) ("kXbra" . t) ("rXsta") ("m s X" . t) ("alkXt" . t) ("y tXn") ("OrttX" . t) ("babXr" . t) ("a Xn " . t) ("mXdan") ("enstX" . t) (" zXbe" . t) ("Xrmen" . t) ("tXzu ") (" Xzmu" . t) ("UyUkX") ("UlttX" . t) (" mXnd") ("mXzda") ("pagX") ("ezXk" . t) ("plXt" . t) ("Xdir" . t) (" ktX" . t) ("uylX") ("Xrmo" . t) ("Xzma") (" ulX") ("OvmX" . t) ("UCX" . t) ("onX") ("eX") (" o tXr " . t) ("I ergXn") (" bXrum" . t) ("Xtuncu" . t) ("uS mXd") (" kollX") ("ontXr" . t) ("Xzull") ("ekabX" . t) (" Xsuy" . t) ("sXtop") ("amdXl" . t) ("Xles ") (" a X " . t) ("Xruc ") ("pol X" . t) ("ntXre") (" Xsen" . t) ("mXck") ("etXs" . t) ("ardX") (" gXs") ("mXh " . t) (" Xrh") ("Xlse" . t) ("zXpp" . t) ("orCX") ("sXrv") ("gOzX" . t) ("Xzr" . t) ("fXl") ("Xgg") ("Xtr") ("rXh") ("oGX") (" ileri Xc") ("konsensX" . t) ("ld tribX") (" en Xc ") ("oportX" . t) ("I kXl " . t) ("songXl" . t) ("e Xcun" . t) ("Xlale" . t) ("Xngu " . t) ("lkolX" . t) ("hsulX" . t) ("sollX") ("zXraf" . t) ("rk Xy") ("mXden" . t) ("yollX") (" hXda" . t) ("Xther") ("ehlX" . t) ("gXy ") ("zXre") ("Xcok" . t) ("dXlm" . t) ("Xhru" . t) ("UlcX" . t) ("OnsX" . t) ("O nX" . t) ("Xlko") ("Xtad") (" Xrn") ("kodX") (" Xsu") ("oX") ("kXskunu") ("sXratla") ("le Xn " . t) ("kXrsul" . t) ("tXlay" . t) (" akXz" . t) ("Xmeyr" . t) ("4 lX " . t) ("sXha " . t) (" mXmu") ("mUhrX" . t) ("UrktX" . t) ("mXrah") ("Xben ") (" endX" . t) ("Xzuyo" . t) ("sXnge" . t) ("mXteb") ("elXl" . t) ("SamX" . t) ("vekX") ("Xpu " . t) ("Xtaf") ("OCtX" . t) (" ncX" . t) ("dXlc" . t) ("hXlk") (" nXz" . t) ("UlbX" . t) ("Xrak") ("Xlag") ("Xrnb" . t) ("Xna ") ("cXh" . t) ("Xniversity") ("gun mXd") ("dXrumlu" . t) ("mXkted") ("morgXl" . t) ("tXrbo") ("golsX" . t) ("argXn") ("amXrs" . t) ("rns X" . t) ("bXket") ("Xckag" . t) ("nyatX" . t) ("Ur X " . t) ("dugX") ("aahX" . t) ("OynX" . t) ("kXkr" . t) ("kstX" . t) ("ortX") ("Xpi") ("Xdi") ("u mXdur ") ("konsXl" . t) ("Ogh Xn" . t) ("hXmani" . t) ("gUC Xn" . t) ("zelgX" . t) (" encX" . t) (" Xrug") (" sXva" . t) ("Uk X " . t) (" kupX" . t) ("Xyuk " . t) ("Xlet") ("ktXs" . t) ("IrtX" . t) ("CXr ") ("tXli" . t) ("uzgX") ("mXrr") ("latX") ("UzmX" . t) ("Xzyo" . t) ("Xsal") ("zXg" . t) ("an ergXn") ("in Xcu ") (" sXsu " . t) ("mXteme") ("U dXr " . t) ("drolX") ("UslX " . t) ("sXluk" . t) ("Xrtaj" . t) (" rXst" . t) ("Xson") ("darX" . t) ("tXgi" . t) ("Ol X" . t) ("oSXr" . t) (" nXa" . t) ("Xta ") ("Xlam") ("Xsme" . t) ("Xcp" . t) ("bXrun ") ("kapsX" . t) ("Xlema") ("kXlah" . t) (" mXrd") ("USsXn" . t) ("kulX ") ("mXdo") ("lXft") ("logX") ("zatX" . t) ("Xsso") ("9 lX") ("Xng ") ("Xcle" . t) ("Xoz" . t) ("OcX" . t) ("fUtXrs") (" kXtug" . t) ("trolsX" . t) (" satX" . t) ("US X" . t) ("bXsh") (" Xtu" . t) ("UtXf") ("evlX" . t) ("brXn") ("Xzme" . t) ("ssXm" . t) ("Xple" . t) (" SXl") ("Xcb" . t) ("rfX" . t) ("fXturs" . t) ("Ur mX " . t) ("bXyurk" . t) ("0 kXsu" . t) (" Xrum") (" tXte" . t) (" tXba" . t) ("OSk X" . t) ("hXrma") ("kXkur" . t) ("etXl " . t) ("Uz X " . t) ("hXrsi") ("bXsi") ("ebXs") (" lXd") ("itXt") ("pXf " . t) (" Xca") ("cXmbus" . t) ("Xrkish") ("Um Xn " . t) ("ayakX" . t) ("00 lX" . t) (" mXsu") ("mXmy") ("uSCX") ("esgX") ("UtCX" . t) ("Xvi" . t) ("Xlb" . t) ("otX") ("UX" . t) ("ok mXd") ("tXrunu" . t) ("gollX" . t) ("UrttX" . t) (" Xnis") ("hXngu" . t) ("kXlc" . t) (" jXb" . t) ("nXsh" . t) ("UtmX" . t) ("Xsti") ("usX") (" Xcunun" . t) ("a bXrun" . t) ("Or Xn" . t) (" aygX" . t) ("evalX" . t) ("Xnver" . t) ("edavX" . t) ("Xraf") ("Xzip") ("modXl" . t) ("Xrkey") ("suCXs" . t) (" bulX") ("cXpp" . t) (" Xl " . t) ("UksX" . t) ("uydX") (" Xcy" . t) ("rkXk" . t) ("Xpac") ("Xyg") (" gXlu ") (" zulmX" . t) ("bdXl " . t) (" tXk " . t) ("Xrsat" . t) ("ozgX") ("Oy X" . t) ("bXku" . t) ("OmdX" . t) ("sUkX") ("Xlti") ("flXt" . t) ("Xsla") ("oyX") ("onktX" . t) ("Un X " . t) (" kXrk" . t) (" Xcu " . t) ("rbXs") ("i X " . t) ("OptX" . t) (" rXc" . t) ("sXe" . t) (" mXsluk") ("kXskun" . t) ("ekolX" . t) ("COzmX" . t) ("baSmX" . t) ("UtsX" . t) ("Xfur" . t) (" kXz") ("SdX" . t) (" Xnusa" . t) (" Xnic") ("settX" . t) (" dXrt" . t) ("ampXs" . t) ("kostX" . t) ("zXmr" . t) ("UCtX" . t) (" fXsu" . t) ("UmbX" . t) ("lfX" . t) ("UrklX" . t) ("nipX" . t) ("bXre") ("gXst") ("Xleb" . t) ("okCX") ("dokXman" . t) ("hUznX" . t) ("gXrup") ("zarX") (" dXe" . t) ("Xbv" . t) ("oCX") (" kXlle" . t) (" mXml") (" tXku" . t) (" kXle") ("fUsX") ("brXt" . t) ("Xzz" . t) (" ne tXr" . t) ("223 X") ("rolcX" . t) ("Xrune" . t) (" zXri" . t) ("herkX" . t) ("Xstah" . t) ("UsXr") ("UnsX" . t) ("iki tXrl") (" sXslu" . t) (" Xmme" . t) (" cXru" . t) (" Xfl" . t) ("OlcX" . t) ("mXsia" . t) ("mXsi") ("Xrub") ("hCX") (" Xvey" . t) (" lXn") (" klX" . t) (" CXl") (" lXc") ("UhX" . t) ("Xpe" . t) (" Xzel") ("sUslX" . t) ("hXzn" . t) ("UmdX" . t) ("oX") (" mXstak" . t) ("Uz mX " . t) (" Xnes") ("raSX" . t) ("cXbb" . t) (" etX" . t) ("UmcX" . t) ("OplX" . t) ("Xrad") (" mXhur" . t) ("ohl X" . t) ("Xstad" . t) (" rXsd" . t) (" kamX") ("sedX" . t) ("OkmX" . t) ("0 lXk ") ("zulXm" . t) (" sXk" . t) ("arolX") (" Xto" . t) ("Xsev") ("kXme" . t) (" Xzum" . t) ("USkX" . t) ("Xlisla" . t) (" kXlli" . t) ("mbolX" . t) ("kXrtc" . t) ("OksXz" . t) ("lUzX") (" nXk" . t) ("Xlge" . t) ("Xlha" . t) ("UCsX" . t) ("Uk Xn " . t) ("OGsX" . t) ("Us X" . t) ("Xlf" . t) ("hXrda") ("edXk" . t) ("aX") (" pXru" . t) ("skXd" . t) ("dXme" . t) ("Xti") ("e bXrun" . t) ("Ur Xn" . t) (" Xzd" . t) ("UrbX" . t) ("OzdX" . t) ("U yX " . t) ("kXrdi" . t) ("Xrle" . t) (" Xmra" . t) ("Oz X" . t) (" Xslu ") ("Un mX " . t) ("Xzaf") ("UyX" . t) ("Xnet") ("UsbX" . t) ("kXrsus" . t) (" tXcc" . t) (" mXy") ("rXce") ("zahX" . t) ("Xrsude" . t) ("altXs" . t) (" mXs ") ("Xtle" . t) ("Uz Xn " . t) ("kXle ") ("OrsX" . t) (" Xlu") ("hXsr" . t) ("sulsX" . t) ("bXyur") (" tXy" . t) ("CXb") ("Xrunde" . t) ("ilgX" . t) ("strXma" . t) (" Xsku" . t) ("kXrsuy" . t) ("rodXk" . t) ("OvdX" . t) ("U mX " . t) ("pXsku" . t) ("ongX") ("Xndee") ("Xsn" . t) ("zsX" . t) ("kXtuk" . t) ("rabXk" . t) ("tfX " . t) ("Xrf") ("r tXr " . t) ("UsnX" . t) ("rtXk" . t) (" usulX" . t) (" Xzuc" . t) ("CXmr") ("Xx") ("Xnsa" . t) ("UlsX" . t) ("Xdurn") ("sUtXn") ("UstlX" . t) ("hXsam" . t) ("UrtX" . t) ("rXtb" . t) ("UpX" . t) ("UzdX" . t) ("kabulX" . t) ("mXts") (" nXr") ("Ok X" . t) ("bXlt" . t) ("iyanX" . t) ("esadX" . t) ("UftX" . t) ("Un Xn " . t) ("UrcX" . t) ("sansX" . t) (" cXz" . t) ("oylX") ("OlmX" . t) (" eymXr " . t) ("Xhim" . t) ("Xrbet") ("UkrX" . t) ("tokolX" . t) (" dXdu" . t) ("ollX " . t) ("tXrde" . t) ("ktXe" . t) ("Xnited") ("cavX" . t) ("OpX" . t) ("hXzun" . t) ("erXv" . t) ("OrtlX" . t) ("Xtuph" . t) ("katX" . t) ("UssX" . t) ("tXdy" . t) ("Xrtle" . t) (" tXbi" . t) ("kXtah" . t) ("bXtt") ("UydX" . t) ("virX" . t) ("Xsa ") ("Xva") ("UtlX" . t) ("OnmX" . t) ("00 X" . t) ("OktX" . t) ("sXmer" . t) (" jXri" . t) ("Xi") (" Xssu" . t) ("Xcg" . t) ("Xrla") ("OSkX" . t) ("OklX" . t) (" bXk" . t) ("SgXl") (" lX ") ("uyX") ("hXly" . t) ("UttX" . t) ("OmrX" . t) ("umX") (" mXm ") ("sXnn" . t) ("reddX" . t) ("sXret") ("popXl" . t) ("golcX" . t) ("UkmX" . t) ("gXe") (" Xra") ("UktX" . t) ("UmsX" . t) ("abX") ("Xcte" . t) ("3 X" . t) ("dtX" . t) ("kXba" . t) ("hhX" . t) ("USlX" . t) ("ungX") ("Xgl") ("tXzu" . t) ("UlkX" . t) ("UskX" . t) ("elCX") ("mXtf") ("Xkse" . t) ("Xzunt" . t) ("UrmX" . t) ("ercXm" . t) ("opCX") (" CXk") (" Xslu" . t) (" dXk" . t) (" rXy" . t) ("ObX" . t) ("akX " . t) ("tCX ") ("rXstu " . t) ("ekX" . t) ("4 X" . t) ("UrkX" . t) (" Xclu" . t) ("Xci") ("Xsv" . t) ("Xtab") ("UfXr" . t) ("UrsX" . t) ("Xkm" . t) ("OGX" . t) ("ukCX") ("Xne" . t) ("kXf" . t) (" eyX" . t) ("tXrb" . t) ("Ul X" . t) ("OncX" . t) ("dXz" . t) ("gXrur") ("Xzul" . t) (" kXrt " . t) ("ribX" . t) ("hUcX") ("UzlX" . t) ("OnlX" . t) ("OvX" . t) ("yor mX") ("OrlX" . t) (" Xnal" . t) ("USmX" . t) (" vUcX") (" vXc" . t) ("Xmle" . t) (" SXk" . t) (" hXc" . t) ("tatX" . t) ("itX" . t) ("UllX" . t) ("ekkX" . t) (" sXt" . t) (" tXp" . t) ("OrmX" . t) (" golX" . t) ("ecrX" . t) ("Xph" . t) ("tXsia" . t) ("Xkle" . t) ("lgX") ("komXn" . t) ("UmlX" . t) ("UnmX" . t) (" hXr" . t) ("OykX" . t) ("ordX") ("Xsle" . t) ("UlmX" . t) (" dXg" . t) ("dXrust" . t) ("Xhe" . t) ("Xfe" . t) ("mXrat") ("mXl" . t) ("Xny" . t) ("OzlX" . t) (" sXp" . t) ("anXstu" . t) ("hXsey" . t) ("OrtX" . t) ("Urk X" . t) ("OprX" . t) ("UklX" . t) ("UmrX" . t) ("mXmc") ("Xzg" . t) ("OmX" . t) ("Xka") ("sXri") (" lX" . t) ("UbX" . t) (" Xmi" . t) ("OyX" . t) ("OkX" . t) ("bXs" . t) ("OzcX" . t) ("lbXm" . t) ("orgX") ("UntX" . t) ("Xce" . t) ("u tXr " . t) ("Xa") ("rolX" . t) ("kXz") ("U nX" . t) ("bXro" . t) (" Xcunc" . t) ("OndX" . t) (" mX ") ("mUslX" . t) (" nXf" . t) (" tXke" . t) ("enX" . t) (" Xr" . t) ("UldX" . t) ("tXrl" . t) ("uCX") ("UmkX" . t) (" kulX" . t) ("UClX" . t) ("UncX" . t) ("Xcr" . t) ("UndX" . t) ("OdX" . t) ("Xsta") ("mXtl") (" Xnl" . t) ("OldX" . t) ("UcX" . t) ("UyX" . t) ("urgX") ("OrdX" . t) ("UStX" . t) ("UltX" . t) (" Xni" . t) ("ylX" . t) ("UstX" . t) ("OtX" . t) (" yXru" . t) ("kXcu" . t) ("UsX" . t) ("kXlt" . t) ("UzX" . t) ("UnlX" . t) ("Xle" . t) ("UdX" . t) ("Xh") (" Xc " . t) ("UrdX" . t) ("UlX" . t) (" mX" . t) (" Xst" . t) ("UrlX" . t) (" tXm" . t) ("UnkX" . t) ("Xye" . t) (" bXt" . t) ("CX" . t) ("OlX" . t) (" sXr" . t) ("UtX" . t) ("OzX" . t) ("ygX") ("UmX" . t) ("UGX" . t) ("OnX" . t) ("USX" . t) ("hXkum" . t) ("yXz" . t) ("dXs" . t) (" dXn" . t) ("UkX" . t) ("Xlk" . t) ("bXyu" . t) ("UrX" . t) ("UnX" . t) ("Xre" . t) ("OrX" . t) ("yXk" . t) ("Xze" . t) ("tXrk" . t) ("gX" . t) ("X") )
     ))
  "These are the decision lists.  There is one decision list for each
of the letters 'c', 'g', 'i', 'o', 's', 'u'.  The format is pretty
self explanatory: each string is a pattern with the target character
replaced by an 'X'.  All other characters are lowercased except for
the turkish characters to the left of the X, which are indicated by
uppercase ascii equivalents.  If the string is followed by a '. t',
e.g. (\"gerX\" . t), the program will replace the target character with
its Turkish version.  If there is no '. t', e.g. (\"nXi\"), the
character will not be replaced.  The first matching pattern is used to
decide what to do."
  )

(provide 'turkish)
;;; turkish.el ends here
